﻿--[[
****************************************************************************************
AckisRecipeList v0.5
02 October 2007
(Written for live servers v2.2.0.7272)

Author: Ackis on Gurubashi US Horde
****************************************************************************************
Description:
	Scans a currently open tradeskill window, and displays a list of missing recipes (along with how to
	get them) in the chat window or a seperate window.

Notes:
	Currently my first add-on.  It is a learning experience for myself and there will be bugs and other
	problems that crop up during the development cycle.

Known Issues:
	If headings are closed, they do not expand properly when scanning a trade skill (they will
		expand but the recipes under them will not be included in the scan).
	If "have materials" is checked, only recipes that show up will be scanned.
	Data for skills needs to be updated, specifically:
		-Blacksmithing
		-Beast Training
		-Leatherworking
		-Tailoring
		-Engineering
		-Jewelcrafting
	Trade skill speciality is not being filtered.
	Too many globals in the add-on
	Too much of the add-on is exposed (global functions) (is local func bob same as func addon:bob?)

Where to contact me:
	Contact me via e-mail (see TOC), on the WoW Ace Forums, or even in-game (if I'm not raiding)
	http://www.wowace.com/forums/index.php?topic=8670.0

What I need:
	Any missing recipe names from scans along with how to aquire them.

Credits:
	Ideas for the mod came from FGTradeLacker (original mod no longer updated, however someone has
	taken over updating the recipes for it)
	Ace2 community for listening to my questions on the IRC channel and helping me out.
	Add-ons suchs as Spellbinder, FGTradelacker which I reviewed code on how to figure out things

****************************************************************************************
]]

local Crayon	= AceLibrary("LibCrayon-3.0");
local BTS		= AceLibrary("Babble-Tradeskill-2.2");
local BFAC		= AceLibrary("Babble-Faction-2.2");
local BCLASS	= AceLibrary("Babble-Class-2.2");
local L			= AceLibrary("AceLocale-2.2"):new("AckisRecipeList");

AckisRecipeList = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0");

-- Namespace for an array containing recipes
local RecipeListing = nil;
local MissingRecipeListing = nil;
local SkillType = nil;
local FoundRecipes = nil;
local NumberOfRecipes = nil;
local AckisRecipeListFrame  = nil;
local TabSpace = "    ";

-- Command line options for the mod.
-- Allows you to filter which recipes to display based on faction, class, profession speciality, rare raid recipes, and current/max skill level

local command_options = {
    type = "group",
    args =
	{
		scan =
		{
			type = "execute",
			name = "scan",
			desc = L["SCAN"],
			func = "AckisRecipeList_SCAN",
			order = 1,
		},
		guiscan =
		{
			type = "execute",
			name = "guiscan",
			desc = L["GUISCAN"],
			func = "AckisRecipeList_GUISCAN",
			order = 2,
		},
    	title =
		{
    		type = "header",
    		name = L["ARL_CONFIG_HEADER"],
    		order = 3,
    	},
        display =
		{
            type = "group",
			name = "display",
			desc = L["DISPLAY_OPTIONS"],
			order = 4,
			args =
				{
				factions =
					{
                    name      = "faction",
                    desc      = L["FACTION_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllFactions",
                    set       = "ToggleAllFactions",
                    order     = 1,
					},
				classes =
					{
                    name      = "classes",
                    desc      = L["CLASS_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllClasses",
                    set       = "ToggleAllClasses",
                    order     = 2,
					},
				specialities =
					{
                    name      = "specialities",
                    desc      = L["SPECIALITY_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllSpecialities",
                    set       = "ToggleAllSpecialities",
                    order     = 3,
					},
				raid =
					{
                    name      = "raid",
                    desc      = L["RAID_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllRaid",
                    set       = "ToggleAllRaid",
                    order     = 4,
					},
				skill =
					{
                    name      = "skill",
                    desc      = L["SKILL_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllSkill",
                    set       = "ToggleAllSkill",
                    order     = 5,
					}
				}
		},
		sorting =
		{
			name      = "sort",
			desc      = L["SORT_OPTIONS"],
			type      = "text",
			validate  = { L["SORT_Name"], L["SORT_Skill"], L["SORT_Unsorted"] },
			get       = "GetAllSorting",
			set       = function(name) AckisRecipeList:ToggleAllSorting(name) end,
			order     = 5,
		}
	}
}


--[[

	Saved variables functions

]]--

-- Initialize the database and set the default options

AckisRecipeList:RegisterDB("AckisRecipeListDB", "AckisRecipeListDBPC");

-- Set default options, which are to include everything in the scan
AckisRecipeList:RegisterDefaults("profile",
	{
    faction = true,
	classes = true,
	specialities = true,
	raid = true,
	skill = true,
	sorting = "Unsorted",
	}
);

-- Returns the  value of the Sorting variable in the database.

function AckisRecipeList:GetAllSorting()

	return AckisRecipeList.db.profile.sorting;

end

-- Toggles the boolean value of the AllFactions variable in the database.

function AckisRecipeList:ToggleAllSorting(NewValue)

	AckisRecipeList.db.profile.sorting = NewValue;

end


-- Returns the boolean value of the AllFactions variable in the database.

function AckisRecipeList:GetAllFactions()

	return AckisRecipeList.db.profile.faction;

end

-- Toggles the boolean value of the AllFactions variable in the database.

function AckisRecipeList:ToggleAllFactions()

	AckisRecipeList.db.profile.faction = not AckisRecipeList.db.profile.faction;

end

-- Returns the boolean value of the AllClasses variable in the database.

function AckisRecipeList:GetAllClasses()

	return AckisRecipeList.db.profile.classes;

end

-- Sets the boolean value of the AllClasses variable in the database.

function AckisRecipeList:ToggleAllClasses()

	AckisRecipeList.db.profile.classes = not AckisRecipeList.db.profile.classes;

end

-- Returns the boolean value of the AllSpecialities variable in the database.

function AckisRecipeList:GetAllSpecialities()

	return AckisRecipeList.db.profile.specialities;

end

-- Sets the boolean value of the AllSpecialities variable in the database.

function AckisRecipeList:ToggleAllSpecialities()

	AckisRecipeList.db.profile.specialities = not AckisRecipeList.db.profile.specialities;

end

-- Returns the boolean value of the AllRaid variable in the database.

function AckisRecipeList:GetAllRaid()

	return AckisRecipeList.db.profile.raid;

end

-- Sets the boolean value of the AllRaid variable in the database.

function AckisRecipeList:ToggleAllRaid()

	AckisRecipeList.db.profile.raid = not AckisRecipeList.db.profile.raid;

end

-- Returns the value of the AllSkill variable in the database.

function AckisRecipeList:GetAllSkill()

	return AckisRecipeList.db.profile.skill;

end

-- Sets the boolean value of the AllSkill variable in the database.

function AckisRecipeList:ToggleAllSkill()

	AckisRecipeList.db.profile.skill = not AckisRecipeList.db.profile.skill;

end

--[[

	Reset functions

]]--

-- Empties the RecipeList table

local function ARL_ResetRecipeList()

	if ( RecipeListing ~= nil) then

		local CurrentRecipe = next(RecipeListing, nil);

		while (CurrentRecipe ~= nil) do

			RecipeListing[ CurrentRecipe ][ "Level" ] = nil;
			RecipeListing[ CurrentRecipe ][ "Acquire" ] = nil;
			RecipeListing[ CurrentRecipe ][ "Speciality" ] = nil;		
			RecipeListing[ CurrentRecipe ][ "Known" ] = nil;

			local OldRecipe = CurrentRecipe;

			-- Move on to the next entry in the table
			CurrentRecipe = next(RecipeListing, CurrentRecipe);

			RecipeListing[ OldRecipe ] = nil;

		end

	end

	RecipeList = nil;

end

-- Empties the MissingRecipeList table

local function ARL_ResetMissingRecipeList()

	if ( MissingRecipeListing ~= nil) then

		local CurrentRecipe = next(MissingRecipeListing, nil);

		while (CurrentRecipe ~= nil) do

			MissingRecipeListing[ CurrentRecipe ][ "Level" ] = nil;
			MissingRecipeListing[ CurrentRecipe ][ "Acquire" ] = nil;
			MissingRecipeListing[ CurrentRecipe ][ "Speciality" ] = nil;		
			MissingRecipeListing[ CurrentRecipe ][ "Known" ] = nil;

			local OldRecipe = CurrentRecipe;

			-- Move on to the next entry in the table
			CurrentRecipe = next(MissingRecipeListing, CurrentRecipe);

			MissingRecipeListing[ OldRecipe ] = nil;

		end

	end

	MissingRecipeListing = nil;

end

-- Reset all variables

local function ARL_ResetVariables()

	ARL_ResetRecipeList();
	--ARL_ResetMissingRecipeList();

	SkillType = nil;
	FoundRecipes = nil;
	NumberOfRecipes = nil;

end

-- Initializes the initial recipe array, reseting it completely.

local function ARL_InitializeRecipeArray()

	-- Reset namespace to be empty
	RecipeListing = {};
	MissingRecipeListing = {};
  
	-- Sets the total number of recipes to 0.
	NumberOfRecipes = 0;

	-- Sets the number of found recipes to 0.
	FoundRecipes = 0;

end

--[[

	Initialization functions

]]--

-- When the add-on is enabled, register slash commands, and which events to watch

function AckisRecipeList:OnEnable()

	-- Add slash commands
	self:RegisterChatCommand(L["LONG_COMMAND"], L["SHORT_COMMAND"], command_options);

	-- Make addon respond to the tradeskill and crafting windows being shown
	self:RegisterEvent("TRADE_SKILL_SHOW");
	self:RegisterEvent("CRAFT_SHOW");

	-- Addon responds to tradeskill and crafting windows being closed.
	self:RegisterEvent("CRAFT_CLOSE");
	self:RegisterEvent("TRADE_SKILL_CLOSE");

end

-- Hides the frame if the mod gets disabled

function AckisRecipeList:OnDisable()

	ARL_ResetVariables();

	if AckisRecipeListFrame then

		AckisRecipeListFrame:Hide();

	end

end

-- Watch for the trade skill window to be shown, add all specific trade skills to an array, then scan the trade skill window for all recipes.

function AckisRecipeList:TRADE_SKILL_SHOW()

	SkillType = "Trade";

end

-- Clean up tables from memory when trade skill window is closed

function AckisRecipeList:TRADE_SKILL_CLOSE()

	ARL_ResetVariables();

end

-- Watch for the craft skill window to be shown, add all specific trade skills to an array, then scan the craft skill window for all recipes.

function AckisRecipeList:CRAFT_SHOW()

	SkillType = "Craft";

end

-- Clean up tables from memory when craft window is closed

function AckisRecipeList:CRAFT_CLOSE()

	ARL_ResetVariables();

end

--[[

	Tradeskill functions

]]--

-- Adds a specifc recipe to the recipe list array.  Also provides information regarding recipe level, if there is any trade skill recipe speciality, how to aquire the recipe, and if the recipe is known or not.

local function addTradeSkill(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, RecipeKnown)

	-- Creates a table in the RecipeListing table storing all information about a recipe
	RecipeListing[ RecipeName ] = {};
	RecipeListing[ RecipeName ][ "Level" ] = RecipeLevel;
	RecipeListing[ RecipeName ][ "Acquire" ] = RecipeAquire;
	RecipeListing[ RecipeName ][ "Speciality" ] = RecipeSpeciality;

	if (RecipeKnown == nil) then

		RecipeListing[ RecipeName ][ "Known" ] = false;

	else

		RecipeListing[ RecipeName ][ "Known" ] = RecipeKnown;

	end

	-- Increment the total number of recipes added to the list
	NumberOfRecipes = NumberOfRecipes + 1;

end

-- Modifies recipe array if a recipe is found, setting the Known flag as true.

function AckisRecipeList:foundTradeSkill(RecipeName)

	RecipeListing[ RecipeName ][ "Known" ] = true;

	-- Increase found count
	FoundRecipes = FoundRecipes + 1;

end

-- Checks to see if a recipe is known or not.  If the recipe is not in the database, output it to chat.

function AckisRecipeList:CheckRecipe(RecipeName)

	if ( RecipeListing[ RecipeName ] ) then

		-- Update array that recipe was found
		AckisRecipeList:foundTradeSkill(RecipeName);
	
	else

		-- Notify users in chat that skill is missing from the database.
		AckisRecipeList:printMissingSkill(RecipeName);

	end

end

-- Check to see if recipe should be displayed or not

function AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel)

	-- Variable to determine if recipe is to be displayed or not, assume yes
	local displayRecipe = true;

	-- Display hard to obtain raid recipes
	if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == "Raid" ) then

		if ( not AckisRecipeList:GetAllRaid() ) then

			displayRecipe = false;

		end

	end

	-- Display all faction recipes
	local playerFaction, _ = UnitFactionGroup("player");

	if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == playerFaction ) then

		if ( not AckisRecipeList:GetAllFactions() ) then

			displayRecipe = false;

		end

	end

	-- Display all class type recipes
	local playerClass, _ = UnitClass("player");

	if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == playerClass ) then

		if ( not AckisRecipeList:GetAllClasses() ) then

			displayRecipe = false;

		end

	end

	-- Display all skill levels
	if ( MissingRecipeListing[ RecipeName ][ "Level" ] > CurrentProfessionLevel ) then

		if ( not AckisRecipeList:GetAllSkill() ) then

			displayRecipe = false;

		end

	end

	-- Display all specialities (ie: Primal Mooncloth, Spellcloth, etc.)  (NOT IMPLEMENTED YET)
	if ( not AckisRecipeList:GetAllSpecialities() ) then

		displayRecipe = true;

	end

	return displayRecipe;

end

-- Returns the number of recipes missing

function AckisRecipeList:GetNumMissingRecipes()

	return NumberOfRecipes - FoundRecipes;

end

--[[

	Output functions

]]--

-- Prints out to chat a message stating that a current recipe is missing from the internal database.

function AckisRecipeList:printMissingSkill(RecipeName)

	DEFAULT_CHAT_FRAME:AddMessage( Crayon:Red( RecipeName ) .. Crayon:White( L["MissingFromDB"] ) );

end

-- Prints out to chat the recipe and where it can be found.

function AckisRecipeList:PrintRecipeInfo(RecipeName)

	local RecipeMessage1 = Crayon:Purple( L["MissingRecipePrefix"] );
	local RecipeMessage2 = Crayon:Green( L["MissingRecipe"]:format (RecipeName, MissingRecipeListing[ RecipeName ][ "Level" ]) );

	if (MissingRecipeListing[ RecipeName ][ "Acquire" ] ~= nil) then

		local RecipeMessage3 = Crayon:White( L["MissingRecipeAcquire"]:format ( MissingRecipeListing[ RecipeName ][ "Acquire" ] ));

		DEFAULT_CHAT_FRAME:AddMessage(RecipeMessage1 .. RecipeMessage2 .. RecipeMessage3);

	else

		DEFAULT_CHAT_FRAME:AddMessage(RecipeMessage1 .. RecipeMessage2);

	end

end

-- Identifies that a scan is occuring in chat

function AckisRecipeList:InitiateScan(CurrentProfession, CurrentProfessionLevel)

	-- Identify scan occuring in chat
	DEFAULT_CHAT_FRAME:AddMessage( Crayon:Purple( L["InitiateScan"]:format( CurrentProfession, CurrentProfessionLevel ) ) );

end

-- Displays a summary of known recipes, total recipes and percentages.

function AckisRecipeList:PrintRecipeListSummary()

	DEFAULT_CHAT_FRAME:AddMessage( Crayon:Purple( L["RecipeListSummary"]:format(FoundRecipes, NumberOfRecipes, math.floor( FoundRecipes / NumberOfRecipes * 100 ), AckisRecipeList:GetNumMissingRecipes() ) ) );

end

-- Determines which recipes are known and which are not known, printing them out to the chat frame.

function AckisRecipeList:DisplayRecipeResults(CurrentProfessionLevel, SortedList)

	-- Parse the MissingRecipeListing, printing out the entries
	if ( MissingRecipeListing ~= nil ) then

		-- No sorting at all
		if ( SortedList == nil ) then

			local RecipeName = next(MissingRecipeListing, nil);

			while ( RecipeName ~= nil ) do

				if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel) ) then

					AckisRecipeList:PrintRecipeInfo(RecipeName);

				end

				-- Move on to the next entry in the table
				RecipeName = next(MissingRecipeListing, RecipeName);
	
			end

		else

			for i, RecipeName in ipairs(SortedList) do

				if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel) ) then

					AckisRecipeList:PrintRecipeInfo(RecipeName);

				end

			end

		end

	end

	AckisRecipeList:PrintRecipeListSummary();

end

--[[

	Sorting Functions

]]--

-- Returns true if a Recipe1 has a lower skill level than Recipe2

local function ARL_SortMissingSkill(Recipe1, Recipe2)

	return MissingRecipeListing[ Recipe1 ][ "Level" ] < MissingRecipeListing[ Recipe2 ][ "Level" ];

end

-- Returns true if a Recipe1 come before Recipe2 in the alphabet

local function ARL_SortMissingName(Recipe1, Recipe2)

	return Recipe1 < Recipe2;

end

-- Sorts the MissingRecipeListing with the given sorting function

function AckisRecipeList:SortMissingRecipes(SortFunction)

	local TempRecipeSort = {};

	-- Get all the indexes of the MissingRecipeListing
	for n in pairs( MissingRecipeListing ) do

		table.insert(TempRecipeSort, n);

	end

	-- Sort the indexes according to the function
	table.sort(TempRecipeSort, SortFunction)

	return TempRecipeSort;

end 

--[[

	Recipe Array Functions

]]--

-- Initializes the array adding all Alchemy recipes.  As of 2.2 there are 178 recipes.

local function ARL_InitAlchemy()

	ARL_InitializeRecipeArray();

	-- Original Game Recipes
	addTradeSkill( L["Minor Healing Potion"], 1, L["Trainer"] );
	addTradeSkill( L["Elixir of Lion's Strength"], 1, L["Trainer"] );
	addTradeSkill( L["Elixir of Minor Defense"], 1, L["Trainer"] );
	addTradeSkill( L["Weak Troll's Blood Potion"], 15, L["Trainer"] );
	addTradeSkill( L["Minor Mana Potion"], 25, L["Trainer"] );
	addTradeSkill( L["Minor Rejuvenation Potion"], 40, L["Trainer"] );
	addTradeSkill( L["Elixir of Minor Agility"], 50, L["UWD"] );
	addTradeSkill( L["Discolored Healing Potion"], 50, L["Discolored Healing Potion Obt"], BFAC["Horde"] );
	addTradeSkill( L["Elixir of Minor Fortitude"], 50, L["Trainer"] );
	addTradeSkill( L["Lesser Healing Potion"], 55, L["Trainer"] );
	addTradeSkill( L["Rage Potion"], 60, L["Vendor"] );
	addTradeSkill( L["Swiftness Potion"], 60, L["UWD"] );
	addTradeSkill( L["Blackmouth Oil"], 80, L["Trainer"] );
	addTradeSkill( L["Elixir of Wisdom"], 90, L["Trainer"] );
	addTradeSkill( L["Elixir of Water Breathing"], 90, L["Trainer"] );
	addTradeSkill( L["Elixir of Giant Growth"], 90, L["UWD"] );
	addTradeSkill( L["Holy Protection Potion"], 100, L[L["Vendor"]] );
	addTradeSkill( L["Swim Speed Potion"], 100, L["Trainer"] );
	addTradeSkill( L["Minor Magic Resistance Potion"], 110, L["UWD"] );
	addTradeSkill( L["Healing Potion"], 110, L["Trainer"] );
	addTradeSkill( L["Lesser Mana Potion"], 120, L["Trainer"] );
	addTradeSkill( L["Potion of Curing"], 120, L["UWD"] );
	addTradeSkill( L["Strong Troll's Blood Potion"], 125, L["Trainer"] );
	addTradeSkill( L["Elixir of Defense"], 130, L["Trainer"] );
	addTradeSkill( L["Fire Oil"], 130, L["Trainer"] );
	addTradeSkill( L["Shadow Protection Potion"], 135, L["Vendor"] );
	addTradeSkill( L["Elixir of Lesser Agility"], 140, L["UWD"] );
	addTradeSkill( L["Elixir of Firepower"], 140, L["Trainer"] );
	addTradeSkill( L["Elixir of Ogre's Strength"], 150, L["UWD"] );
	addTradeSkill( L["Free Action Potion"], 150, L["Vendor"] );
	addTradeSkill( L["Greater Healing Potion"], 155, L["Trainer"] );
	addTradeSkill( L["Mana Potion"], 160, L["Trainer"] );
	addTradeSkill( L["Lesser Invisibility Potion"], 165, L["Trainer"] );
	addTradeSkill( L["Shadow Oil"], 165, L["Vendor"] );
	addTradeSkill( L["Fire Protection Potion"], 165, L["Vendor"] );
	addTradeSkill( L["Elixir of Fortitude"], 175, L["UWD"] );
	addTradeSkill( L["Great Rage Potion"], 175, L["Vendor"] );
	addTradeSkill( L["Mighty Troll's Blood Potion"], 180, L["Mighty Trolls Blood Potion Obt"] );
	addTradeSkill( L["Elixir of Agility"], 185, L["Trainer"] );
	addTradeSkill( L["Frost Protection Potion"], 190, L["Vendor"] );
	addTradeSkill( L["Nature Protection Potion"], 190, L["Vendor"] );
	addTradeSkill( L["Elixir of Frost Power"], 190, L["WintersVeil"], L["Seasonal"] );
	addTradeSkill( L["Elixir of Detect Lesser Invisibility"], 195, L["UWD"] );
	addTradeSkill( L["Elixir of Greater Defense"], 195, L["Trainer"] );
	addTradeSkill( L["Frost Oil"], 200, L["Vendor"] );
	addTradeSkill( L["Catseye Elixir"], 200, L["Trainer"] );
	addTradeSkill( L["Oil of Immolation"], 205, L["Trainer"] );
	addTradeSkill( L["Greater Mana Potion"], 205, L["Trainer"] );
	addTradeSkill( L["Magic Resistance Potion"], 210, L["UWD"] );
	addTradeSkill( L["Goblin Rocket Fuel"], 210, L["Vendor"] );
	addTradeSkill( L["Lesser Stoneshield Potion"], 215, L["Lesser Stoneshield Potion Obt"] );
	addTradeSkill( L["Restorative Potion"], 215, L["Restorative Potion Obt"] );
	addTradeSkill( L["Superior Healing Potion"], 215, L["Trainer"] );
	addTradeSkill( L["Elixir of Greater Water Breathing"], 215, L["Trainer"] );
	addTradeSkill( L["Wildvine Potion"], 225, L["Wildvine Potion Obt"] );
	addTradeSkill( L["Philosopher's Stone"], 225, L["Vendor"] );
	addTradeSkill( L["Transmute: Iron to Gold"], 225, L["Vendor"] );
	addTradeSkill( L["Transmute: Mithril to Truesilver"], 225, L["Vendor"] );
	addTradeSkill( L["Elixir of Detect Undead"], 230, L["Trainer"] );
	addTradeSkill( L["Dreamless Sleep Potion"], 230, L["Trainer"] );
	addTradeSkill( L["Arcane Elixir"], 235, L["Trainer"] );
	addTradeSkill( L["Invisibility Potion"], 235, L["UWD"] );
	addTradeSkill( L["Elixir of Greater Intellect"], 235, L["Trainer"] );
	addTradeSkill( L["Gift of Arthas"], 240, L["Gift of Arthas Obt"] );
	addTradeSkill( L["Elixir of Greater Agility"], 240, L["Trainer"] );
	addTradeSkill( L["Elixir of Dream Vision"], 240, L["UWD"] );
	addTradeSkill( L["Elixir of Giants"], 245, L["UWD"] );
	addTradeSkill( L["Ghost Dye"], 245, L["Vendor"] );
	addTradeSkill( L["Elixir of Shadow Power"], 250, L["Vendor"] );
	addTradeSkill( L["Elixir of Demonslaying"], 250, L["Vendor"] );
	addTradeSkill( L["Elixir of Detect Demon"], 250, L["Trainer"] );
	addTradeSkill( L["Stonescale Oil"], 250, L["Trainer"] );
	addTradeSkill( L["Limited Invulnerability Potion"], 250, L["UWD"] );
	addTradeSkill( L["Elixir of Greater Firepower"], 250, L["Elixir of Greater Firepower Obt"] );
	addTradeSkill( L["Mighty Rage Potion"], 255, L["Mighty Rage Potion Obt"] );
	addTradeSkill( L["Superior Mana Potion"], 260, L["Vendor"] );
	addTradeSkill( L["Elixir of Superior Defense"], 265, L["Vendor"] );
	addTradeSkill( L["Elixir of the Sages"], 270, L["Elixir of the Sages Obt"] );
	addTradeSkill( L["Transmute: Arcanite"], 275, L["Vendor"] );
	addTradeSkill( L["Major Healing Potion"], 275, L["Vendor"] );
	addTradeSkill( L["Elixir of Brute Force"], 275, L["Elixir of Brute Force Obt"] );
	addTradeSkill( L["Transmute: Air to Fire"], 275, ("%s: %s"):format( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] );
	addTradeSkill( L["Transmute: Earth to Water"], 275, ("%s: %s"):format( BFAC["Friendly"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] );
	addTradeSkill( L["Transmute: Earth to Life"], 275, L["UWD"] );
	addTradeSkill( L["Transmute: Fire to Earth"], 275, L["Vendor"] );
	addTradeSkill( L["Transmute: Undeath to Water"], 275, L["UWD"] );
	addTradeSkill( L["Transmute: Water to Air"], 275, L["Vendor"] );
	addTradeSkill( L["Transmute: Water to Undeath"], 275, L["UWD"] );
	addTradeSkill( L["Transmute: Life to Earth"], 275, L["UWD"] );
	addTradeSkill( L["Mageblood Potion"], 275, ("%s: %s"):format( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] );
	addTradeSkill( L["Greater Dreamless Sleep Potion"], 275, ("%s: %s"):format( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] );
	addTradeSkill( L["Greater Stoneshield Potion"], 280, L["UWD"] );
	addTradeSkill( L["Elixir of the Mongoose"], 280, L["Elixir of the Mongoose Obt"] );
	addTradeSkill( L["Purification Potion"], 285, L["UWD"] );
	addTradeSkill( L["Greater Arcane Elixir"], 285, L["UWD"] );
	addTradeSkill( L["Living Action Potion"], 285, ("%s: %s"):format( BFAC["Exalted"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] );
	addTradeSkill( L["Greater Fire Protection Potion"], 290, L["Greater Fire Protection Potion Obt"] );
	addTradeSkill( L["Greater Frost Protection Potion"], 290, L["Greater Frost Protection Potion Obt"] );
	addTradeSkill( L["Greater Nature Protection Potion"], 290, L["Greater Nature Protection Potion Obt"] );
	addTradeSkill( L["Greater Arcane Protection Potion"], 290, L["Greater Arcane Protection Potion Obt"] );
	addTradeSkill( L["Greater Shadow Protection Potion"], 290, L["Greater Shadow Protection Potion Obt"] );
	addTradeSkill( L["Major Troll's Blood Potion"], 290, ("%s: %s"):format( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] );
	addTradeSkill( L["Major Mana Potion"], 295, L["Major Mana Potion Obt"] );
	addTradeSkill( L["Flask of Petrification"], 300, L["UWD"] );
	addTradeSkill( L["Flask of the Titans"], 300, L["Flask of the Titans Obt"] );
	addTradeSkill( L["Flask of Distilled Wisdom"], 300, L["Flask of Distilled Wisdom Obt"] );
	addTradeSkill( L["Flask of Supreme Power"], 300, L["Flask of Supreme Power Obt"] );
	addTradeSkill( L["Flask of Chromatic Resistance"], 300, L["Flask of Chromatic Resistance Obt"] );
	addTradeSkill( L["Major Rejuvenation Potion"], 300, L["Major Rejuvenation Potion Obt"], L["Raid"] );
	addTradeSkill( L["Transmute: Elemental Fire"], 300, ("%s: %s"):format( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] );
	addTradeSkill( L["Gurubashi Mojo Madness"], 300, L["Gurubashi Mojo Madness Obt"] );

	-- Burning Crusade Recipes
	addTradeSkill( L["Adept's Elixir"], 300, L["Trainer"] );
	addTradeSkill( L["Onslaught Elixir"], 300, L["Trainer"] );
	addTradeSkill( L["Volatile Healing Potion"], 300, L["Trainer"] );
	addTradeSkill( L["Elixir of Camouflage"], 305, L["Vendor"] );
	addTradeSkill( L["Elixir of Major Strength"], 305, L["Trainer"] );
	addTradeSkill( L["Elixir of Healing Power"], 310, L["Trainer"] );
	addTradeSkill( L["Elixir of Major Fortitude"], 310, L["Trainer"] );
	addTradeSkill( L["Unstable Mana Potion"], 310, L["Trainer"] );
	addTradeSkill( L["Sneaking Potion"], 315, L["Vendor"] );
	addTradeSkill( L["Elixir of Mastery"], 315, L["Trainer"] );
	addTradeSkill( L["Elixir of Draenic Wisdom"], 320, L["Trainer"] );
	addTradeSkill( L["Elixir of Major Frost Power"], 320, L["Vendor"] );
	addTradeSkill( L["Insane Strength Potion"], 320, L["UWD"] );
	addTradeSkill( L["Earthen Elixir"], 320, ("%s: %s"):format( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] );
	addTradeSkill( L["Elixir of the Searching Eye"], 325, L["UWD"] );
	addTradeSkill( L["Mercurial Stone"], 325, L["Trainer"] );
	addTradeSkill( L["Super Healing Potion"], 325, L["Trainer"] );
	addTradeSkill( L["Elixir of Major Agility"], 330, ("(A) %s: %s\n    (H) %s: %s"):format( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Honored"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] );
	addTradeSkill( L["Elixir of Ironskin"], 330, L["Vendor"], "PVP" );
	addTradeSkill( L["Shrouding Potion"], 335, ("%s: %s"):format( BFAC["Exalted"], BFAC["Sporeggar"] ), BFAC["Sporeggar"] );
	addTradeSkill( L["Fel Strength Elixir"], 335, L["Fel Strength Elixir Obt"] );
	addTradeSkill( L["Super Mana Potion"], 340, L["Vendor"] );
	addTradeSkill( L["Elixir of Major Firepower"], 345, ("%s: %s"):format( BFAC["Revered"], BFAC["The Scryers"]), BFAC["The Scryers"] );
	addTradeSkill( L["Elixir of Major Defense"], 345, L["Vendor"] );
	addTradeSkill( L["Fel Regeneration Potion"], 345, L["Fel Regeneration Potion Obt"] );
	addTradeSkill( L["Elixir of Major Shadow Power"], 350, ("%s: %s"):format( BFAC["Revered"], BFAC["Lower City"]), BFAC["Lower City"] );
	addTradeSkill( L["Major Dreamless Sleep Potion"], 350, L["Vendor"] );
	addTradeSkill( L["Heroic Potion"], 350, L["UWD"] );
	addTradeSkill( L["Haste Potion"], 350, L["UWD"] );
	addTradeSkill( L["Destruction Potion"], 350, L["UWD"] );
	addTradeSkill( L["Transmute: Primal Air to Fire"], 350, ("%s: %s"):format( BFAC["Revered"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] );
	addTradeSkill( L["Transmute: Primal Earth to Water"], 350, ("%s: %s"):format( BFAC["Revered"], BFAC["Sporeggar"] ), BFAC["Sporeggar"] );
	addTradeSkill( L["Transmute: Primal Fire to Earth"], 350, ("(A) %s: %s\n    (H) %s: %s"):format( BFAC["Revered"], BFAC["Kurenai"], BFAC["Revered"], BFAC["The Mag'har"] ), BFAC["The Mag'har"] );
	addTradeSkill( L["Transmute: Primal Water to Air"], 350, ("%s: %s"):format( BFAC["Revered"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] );
	addTradeSkill( L["Transmute: Primal Might"], 350, L["Vendor"] );
	addTradeSkill( L["Transmute: Earthstorm Diamond"], 350, ("%s: %s"):format( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] );
	addTradeSkill( L["Transmute: Skyfire Diamond"], 350, ("(A) %s: %s\n    (H) %s: %s"):format( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Honored"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] );
	addTradeSkill( L["Alchemist's Stone"], 350, L["Trainer"] );
	addTradeSkill( L["Elixir of Major Mageblood"], 355, L["UWD"] );
	addTradeSkill( L["Major Arcane Protection Potion"], 360, L["Major Arcane Protection Potion Obt"] );
	addTradeSkill( L["Major Fire Protection Potion"], 360, L["Major Fire Protection Potion Obt"] );
	addTradeSkill( L["Major Frost Protection Potion"], 360, L["Major Frost Protection Potion Obt"] );
	addTradeSkill( L["Major Holy Protection Potion"], 360, L["Major Holy Protection Potion Obt"] );
	addTradeSkill( L["Major Nature Protection Potion"], 360, ("%s: %s"):format( BFAC["Exalted"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] );
	addTradeSkill( L["Major Shadow Protection Potion"], 360, L["Major Shadow Protection Potion Obt"] );
	addTradeSkill( L["Fel Mana Potion"], 360, L["Fel Mana Potion Obt"] );
	addTradeSkill( L["Elixir of Empowerment"], 365, L["UWD"] );
	addTradeSkill( L["Ironshield Potion"], 365, L["Ironshield Potion Obt"] );
	addTradeSkill( L["Flask of Chromatic Wonder"], 375, ("%s: %s"):format( BFAC["Honored"], BFAC["The Violet Eye"] ), BFAC["The Violet Eye"] );

	-- Burning Crusade Discovery Recipes
	addTradeSkill( L["Transmute: Primal Fire to Mana"], 350, L["Discovery - Transmutes"], L["Discovery"] );
	addTradeSkill( L["Transmute: Primal Shadow to Water"], 350, L["Discovery - Transmutes"], L["Discovery"] );
	addTradeSkill( L["Transmute: Primal Life to Earth"], 350, L["Discovery - Transmutes"], L["Discovery"] );
	addTradeSkill( L["Transmute: Primal Earth to Life"], 350, L["Discovery - Transmutes"], L["Discovery"] );
	addTradeSkill( L["Transmute: Primal Mana to Fire"], 350, L["Discovery - Transmutes"], L["Discovery"] );
	addTradeSkill( L["Transmute: Primal Water to Shadow"], 350, L["Discovery - Transmutes"], L["Discovery"] );
	addTradeSkill( L["Flask of Fortification"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] );
	addTradeSkill( L["Flask of Mighty Restoration"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] );
	addTradeSkill( L["Flask of Relentless Assault"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] );
	addTradeSkill( L["Flask of Blinding Light"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] );
	addTradeSkill( L["Flask of Pure Death"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] );	
	addTradeSkill( L["Super Rejuvenation Potion"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] );
	addTradeSkill( L["Cauldron of Major Arcane Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] );
	addTradeSkill( L["Cauldron of Major Fire Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] );
	addTradeSkill( L["Cauldron of Major Frost Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] );
	addTradeSkill( L["Cauldron of Major Nature Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] );
	addTradeSkill( L["Cauldron of Major Shadow Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] );

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Beast Training Abilities.  As of 2.2 there are

local function ARL_InitBeastTraining()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Avoidance (Rank 1)", 30, L["Trainer"] );
	addTradeSkill( "Avoidance (Rank 2)", 60, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 1)", 10, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 2)", 12, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 3)", 18, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 4)", 24, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 5)", 30, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 6)", 36, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 7)", 42, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 8)", 48, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 9)", 54, L["Trainer"] );
	addTradeSkill( "Great Stamina (Rank 10)", 60, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 1)", 10, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 2)", 12, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 3)", 18, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 4)", 24, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 5)", 30, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 6)", 36, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 7)", 42, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 8)", 48, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 9)", 54, L["Trainer"] );
	addTradeSkill( "Natural Armor (Rank 10)", 60, L["Trainer"] );
	addTradeSkill( "Arcane Resistance (Rank 1)", 20, L["Trainer"] );
	addTradeSkill( "Arcane Resistance (Rank 2)", 30, L["Trainer"] );
	addTradeSkill( "Arcane Resistance (Rank 3)", 40, L["Trainer"] );
	addTradeSkill( "Arcane Resistance (Rank 4)", 50, L["Trainer"] );
	addTradeSkill( "Arcane Resistance (Rank 5)", 60, L["Trainer"] );
	addTradeSkill( "Fire Resistance (Rank 1)", 20, L["Trainer"] );
	addTradeSkill( "Fire Resistance (Rank 2)", 30, L["Trainer"] );
	addTradeSkill( "Fire Resistance (Rank 3)", 40, L["Trainer"] );
	addTradeSkill( "Fire Resistance (Rank 4)", 50, L["Trainer"] );
	addTradeSkill( "Fire Resistance (Rank 5)", 60, L["Trainer"] );
	addTradeSkill( "Frost Resistance (Rank 1)", 20, L["Trainer"] );
	addTradeSkill( "Frost Resistance (Rank 2)", 30, L["Trainer"] );
	addTradeSkill( "Frost Resistance (Rank 3)", 40, L["Trainer"] );
	addTradeSkill( "Frost Resistance (Rank 4)", 50, L["Trainer"] );
	addTradeSkill( "Frost Resistance (Rank 5)", 60, L["Trainer"] );
	addTradeSkill( "Nature Resistance (Rank 1)", 20, L["Trainer"] );
	addTradeSkill( "Nature Resistance (Rank 2)", 30, L["Trainer"] );
	addTradeSkill( "Nature Resistance (Rank 3)", 40, L["Trainer"] );
	addTradeSkill( "Nature Resistance (Rank 4)", 50, L["Trainer"] );
	addTradeSkill( "Nature Resistance (Rank 5)", 60, L["Trainer"] );
	addTradeSkill( "Shadow Resistance (Rank 1)", 20, L["Trainer"] );
	addTradeSkill( "Shadow Resistance (Rank 2)", 30, L["Trainer"] );
	addTradeSkill( "Shadow Resistance (Rank 3)", 40, L["Trainer"] );
	addTradeSkill( "Shadow Resistance (Rank 4)", 50, L["Trainer"] );
	addTradeSkill( "Shadow Resistance (Rank 5)", 60, L["Trainer"] );
	addTradeSkill( "Cobra Reflexes ()", 30, L["Trainer"] );
	addTradeSkill( "Gore (Rank 1)", 1 );
	addTradeSkill( "Gore (Rank 2)", 8 );
	addTradeSkill( "Growl (Rank 1)", 10 );
	addTradeSkill( "Growl (Rank 2)", 10 );
	addTradeSkill( "Growl (Rank 3)", 20 );
	addTradeSkill( "Growl (Rank 4)", 30 );
	addTradeSkill( "Growl (Rank 5)", 40 );
	addTradeSkill( "Growl (Rank 6)", 50 );
	addTradeSkill( "Growl (Rank 7)", 60 );
	addTradeSkill( "Bite (Rank 1)", 10 );
	addTradeSkill( "Bite (Rank 2)", 10 );
	addTradeSkill( "Bite (Rank 3)", 16 );
	addTradeSkill( "Bite (Rank 4)", 24 );
	addTradeSkill( "Bite (Rank 5)", 32 );
	addTradeSkill( "Bite (Rank 6)", 40 );
	addTradeSkill( "Bite (Rank 7)", 48 );
	addTradeSkill( "Bite (Rank 8)", 56 );
	addTradeSkill( "Claw (Rank 1)", 10 );
	addTradeSkill( "Claw (Rank 2)", 10 );
	addTradeSkill( "Claw (Rank 3)", 16 );
	addTradeSkill( "Claw (Rank 4)", 24 );
	addTradeSkill( "Claw (Rank 5)", 32 );
	addTradeSkill( "Claw (Rank 6)", 40 );
	addTradeSkill( "Claw (Rank 7)", 48 );
	addTradeSkill( "Claw (Rank 8)", 56 );
	addTradeSkill( "Cower (Rank 1)", 10 );
	addTradeSkill( "Cower (Rank 2)", 15 );
	addTradeSkill( "Cower (Rank 3)", 25 );
	addTradeSkill( "Cower (Rank 4)", 35 );
	addTradeSkill( "Cower (Rank 5)", 45 );
	addTradeSkill( "Cower (Rank 6)", 55 );
	addTradeSkill( "Dash (Rank 1)", 30 );
	addTradeSkill( "Dash (Rank 2)", 40 );
	addTradeSkill( "Dash (Rank 3)", 50 );
	addTradeSkill( "Dive (Rank 1)", 30 );
	addTradeSkill( "Dive (Rank 2)", 40 );
	addTradeSkill( "Dive (Rank 3)", 50 );
	addTradeSkill( "Fire Breath (Rank 1)", 1 );
	addTradeSkill( "Furious Howl (Rank 1)", 10 );
	addTradeSkill( "Furious Howl (Rank 2)", 24 );
	addTradeSkill( "Furious Howl (Rank 3)", 40 );
	addTradeSkill( "Furious Howl (Rank 4)", 56 );
	addTradeSkill( "Screech (Rank 1)", 10 );
	addTradeSkill( "Screech (Rank 2)", 24 );
	addTradeSkill( "Screech (Rank 3)", 40 );
	addTradeSkill( "Screech (Rank 4)", 56 );
	--addTrade( "Lightning Breath (Rank 1)", 10 ) There is no Rank 1 Lightning Breath
	addTradeSkill( "Lightning Breath (Rank 2)", 12 );
	addTradeSkill( "Lightning Breath (Rank 3)", 24 );
	addTradeSkill( "Lightning Breath (Rank 4)", 36 );
	addTradeSkill( "Lightning Breath (Rank 5)", 48 );
	addTradeSkill( "Lightning Breath (Rank 6)", 60 );
	addTradeSkill( "Scorpid Poison (Rank 1)", 10 );
	addTradeSkill( "Scorpid Poison (Rank 2)", 24 );
	addTradeSkill( "Scorpid Poison (Rank 3)", 40 );
	addTradeSkill( "Scorpid Poison (Rank 4)", 56 );
	addTradeSkill( "Prowl (Rank 1)", 30 );
	addTradeSkill( "Prowl (Rank 2)", 40 );
	addTradeSkill( "Prowl (Rank 3)", 50 );
	addTradeSkill( "Charge (Rank 1)", 10 );
	addTradeSkill( "Charge (Rank 2)", 12 );
	addTradeSkill( "Charge (Rank 3)", 24 );
	--addTrade( "Charge (Rank 4)", XX ); There is no Rank 4 Charge!
	addTradeSkill( "Charge (Rank 5)", 42 );
	addTradeSkill( "Charge (Rank 6)", 60 );
	addTradeSkill( "Shell Shield (Rank 1)", 20 );
	addTradeSkill( "Thunderstomp (Rank 1)", 30 );
	addTradeSkill( "Thunderstomp (Rank 2)", 40 );
	addTradeSkill( "Thunderstomp (Rank 3)", 50 );
	
end

-- Initializes the array adding all Blacksmithing recipes.  As of 2.2 there are

local function ARL_InitBlackSmith()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Rough Sharpening Stone", 1, L["Trainer"] );
	addTradeSkill( "Copper Bracers", 1, L["Trainer"] );
	addTradeSkill( "Rough Copper Vest", 1, L["Trainer"] );
	addTradeSkill( "Copper Chain Pants", 1, L["Trainer"] );
	addTradeSkill( "Copper Mace", 15, L["Trainer"] );
	addTradeSkill( "Copper Chain Boots", 20, L["Trainer"] );
	addTradeSkill( "Copper Axe", 20, L["Trainer"] );
	addTradeSkill( "Rough Weightstone", 25, L["Trainer"] );
	addTradeSkill( "Rough Grinding Stone", 25, L["Trainer"] );
	addTradeSkill( "Copper Shortsword", 25, L["Trainer"] );
	addTradeSkill( "Copper Dagger", 30, L["Trainer"] );
	addTradeSkill( "Copper Claymore", 30, L["Trainer"] );
	addTradeSkill( "Copper Battle Axe", 35, L["Trainer"] );
	addTradeSkill( "Copper Chain Vest", 35, "Uncommon World Drop or alliance blacksmithing quest that totally isn't worth it" );
	addTradeSkill( "Copper Chain Belt", 35, L["Trainer"] );
	addTradeSkill( "Runed Copper Gauntlets", 40, L["Trainer"] );
	addTradeSkill( "Runed Copper Pants", 45, L["Trainer"] );
	addTradeSkill( "Gemmed Copper Gauntlets", 60, L["UWD"] );
	addTradeSkill( "Coarse Weightstone", 65, L["Trainer"] );
	addTradeSkill( "Heavy Copper Maul", 65, L["Trainer"] );
	addTradeSkill( "Coarse Sharpening Stone", 65, L["Trainer"] );
	addTradeSkill( "Coarse Grinding Stone", 75, L["Trainer"] );
	addTradeSkill( "Runed Copper Breastplate", 80, L["UWD"] );
	addTradeSkill( "Runed Copper Bracers", 90, L["Trainer"] );
	addTradeSkill( "Thick War Axe", 90, L["Trainer"] );
	addTradeSkill( "Runed Copper Belt", 90, L["Trainer"] );
	addTradeSkill( "Heavy Copper Broadsword", 95, L["Trainer"] );
	addTradeSkill( "Rough Bronze Boots", 95, L["Trainer"] );
	addTradeSkill( "Big Bronze Knife", 100, L["Trainer"] );
	addTradeSkill( "Silver Rod", 100, L["Trainer"] );
	addTradeSkill( "Ironforge Breastplate", 100, "From Alliance Quest Gearing Redridge", BFAC["Alliance"]);
	addTradeSkill( "Silver Skeleton Key", 100, L["Trainer"] );
	addTradeSkill( "Thick Bronze Darts", 100, "Unknown");
	addTradeSkill( "Rough Bronze Leggings", 105, L["Trainer"] );
	addTradeSkill( "Rough Bronze Cuirass", 105, L["Trainer"] );
	addTradeSkill( "Rough Bronze Shoulders", 110, L["Trainer"] );
	addTradeSkill( "Bronze Mace", 110, L["Trainer"] );
	addTradeSkill( "Pearl-handled Dagger", 115, L["Trainer"] );
	addTradeSkill( "Bronze Axe", 115, L["Trainer"] );
	addTradeSkill( "Bronze Shortsword", 120, L["Trainer"] );
	addTradeSkill( "Patterned Bronze Bracers", 120, L["Trainer"] );
	addTradeSkill( "Heavy Weightstone", 125, L["Trainer"] );
	addTradeSkill( "Deadly Bronze Poniard", 125, L["UWD"] );
	addTradeSkill( "Silvered Bronze Shoulders", 125, L["UWD"] );
	addTradeSkill( "Heavy Grinding Stone", 125, L["Trainer"] );
	addTradeSkill( "Bronze Warhammer", 125, L["Trainer"] );
	addTradeSkill( "Heavy Sharpening Stone", 125, L["Trainer"] );
	addTradeSkill( "Heavy Bronze Mace", 130, L["Trainer"] );
	addTradeSkill( "Silvered Bronze Boots", 130, L["Trainer"] );
	addTradeSkill( "Silvered Bronze Breastplate", 130, L["UWD"] );
	addTradeSkill( "Bronze Greatsword", 130, L["Trainer"] );
	addTradeSkill( "Silvered Bronze Gauntlets", 135, L["Trainer"] );
	addTradeSkill( "Bronze Battle Axe", 135, L["Trainer"] );
	addTradeSkill( "Iridescent Hammer", 140, L["UWD"] );
	addTradeSkill( "Mighty Iron Hammer", 145, L["UWD"] );
	addTradeSkill( "Green Iron Boots", 145, L["UWD"] );
	addTradeSkill( "Shining Silver Breastplate", 145, L["Trainer"] );
	addTradeSkill( "Green Iron Gauntlets", 150, L["UWD"] );
	addTradeSkill( "Iron Shield Spike", 150, L["UWD"] );
	addTradeSkill( "Iron Buckle", 150, L["Trainer"] );
	addTradeSkill( "Golden Rod", 150, L["Trainer"] );
	addTradeSkill( "Golden Skeleton Key", 150, L["Trainer"] );
	addTradeSkill( "Solid Iron Maul", 155, L["Vendor"] );
	addTradeSkill( "Green Iron Leggings", 155, L["Trainer"] );
	addTradeSkill( "Silvered Bronze Leggings", 155, L["UWD"] );
	addTradeSkill( "Hardened Iron Shortsword", 160, L["Vendor"] );
	addTradeSkill( "Green Iron Shoulders", 160, L["UWD"] );
	addTradeSkill( "Barbaric Iron Shoulders", 160, "Quest reward from Horde Quest On Iron Pauldroms from Omokk Omosh (Orgrimmar)", BFAC["Horde"] );
	addTradeSkill( "Barbaric Iron Breastplate", 160, "Quest reward from Horde Quest Barbaric Battlements from Omokk Omosh (Orgrimmar)", BFAC["Horde"] );
	addTradeSkill( "Green Iron Bracers", 165, L["Trainer"] );
	addTradeSkill( "Iron Counterweight", 165, L["UWD"] );
	addTradeSkill( "Golden Iron Destroyer", 170, L["UWD"] );
	addTradeSkill( "Green Iron Helm", 170, L["Trainer"] );
	addTradeSkill( "Golden Scale Leggings", 170, L["UWD"] );
	addTradeSkill( "Jade Serpentblade", 175, L["UWD"] );
	addTradeSkill( "Golden Scale Shoulders", 175, L["UWD"] );
	addTradeSkill( "Barbaric Iron Helm", 175, "Reward from Horns of Frenzy, a Horde quest from Orokk Omosh (Orgrimmar)", BFAC["Horde"] );
	addTradeSkill( "Moonsteel Broadsword", 180, L["Vendor"] );
	addTradeSkill( "Green Iron Hauberk", 180, L["Trainer"] );
	addTradeSkill( "Barbaric Iron Boots", 180, "Reward from Trampled Under Foot, a Horde quest from Orokk Omosh (Orgrimmar)", BFAC["Horde"] );
	addTradeSkill( "Glinting Steel Dagger", 180, L["Trainer"] );
	addTradeSkill( "Massive Iron Axe", 185, L["Vendor"] );
	addTradeSkill( "Polished Steel Boots", 185, L["UWD"] );
	addTradeSkill( "Golden Scale Bracers", 185, L["Trainer"] );
	addTradeSkill( "Barbaric Iron Gloves", 185, "Quest reward from Horde Quest Joys of Omosh given by Omokk Omosh (Orgrimmar)", BFAC["Horde"] );
	addTradeSkill( "Golden Scale Coif", 190, L["Vendor"] );
	addTradeSkill( "Steel Weapon Chain", 190, L["UWD"] );
	addTradeSkill( "Searing Golden Blade", 190, L["UWD"] );
	addTradeSkill( "Edge of Winter", 190, "This is one of the rewards from the Christmas quests" );
	addTradeSkill( "Golden Scale Cuirass", 195, L["UWD"] );
	addTradeSkill( "Frost Tiger Blade", 200, L["UWD"] );
	addTradeSkill( "Shadow Crescent Axe", 200, L["UWD"] );
	addTradeSkill( "Golden Scale Boots", 200, L["UWD"] );
	addTradeSkill( "Steel Breastplate", 200, L["Trainer"] );
	addTradeSkill( "Solid Sharpening Stone", 200, L["Trainer"] );
	addTradeSkill( "Solid Weightstone", 200, L["Trainer"] );
	addTradeSkill( "Solid Grinding Stone", 200, L["Trainer"] );
	addTradeSkill( "Inlaid Mithril Cylinder", 200, "This recipe is made by Gnomish Engineers" );
	addTradeSkill( "Truesilver Rod", 200, L["Trainer"] );
	addTradeSkill( "Truesilver Skeleton Key", 200, L["Trainer"] );
	addTradeSkill( "Whirling Steel Axes", 200 );
	addTradeSkill( "Heavy Mithril Shoulder", 205, L["Trainer"] );
	addTradeSkill( "Heavy Mithril Gauntlet", 205, L["Trainer"] );
	addTradeSkill( "Golden Scale Gauntlets", 205, "Reward from Alliance Quest The Origins of Smithing from Hank the Hammer (Stormwind City)", BFAC["Alliance"] );
	addTradeSkill( "Mithril Scale Pants", 210, L["Trainer"] );
	addTradeSkill( "Heavy Mithril Pants", 210, L["UWD"] );
	addTradeSkill( "Heavy Mithril Axe", 210, L["Trainer"] );
	addTradeSkill( "Steel Plate Helm", 215, L["Trainer"] );
	addTradeSkill( "Mithril Scale Bracers", 215, L["Vendor"] );
	addTradeSkill( "Mithril Shield Spike", 215, L["UWD"] );
	addTradeSkill( "Ornate Mithril Pants", 220, "Quest reward from Smelt On, Smelt Off from Galvan the Ancient (Stranglethorn Vale)" );
	addTradeSkill( "Ornate Mithril Gloves", 220, "Reward from the quest The Great Silver Deceiver from Galvan the Ancient (Stranglethorn Vale)" );
	addTradeSkill( "Blue Glittering Axe", 220, L["UWD"] );
	addTradeSkill( "Ornate Mithril Shoulder", 225, "Reward from quest The Art of the Imbue from Galvan the Ancient (Stranglethorn Vale)" );
	addTradeSkill( "Wicked Mithril Blade", 225, L["UWD"] );
	addTradeSkill( "Heavy Mithril Breastplate", 230, L["Trainer"] );
	addTradeSkill( "Mithril Coif", 230, L["Trainer"] );
	addTradeSkill( "Big Black Mace", 230, L["Trainer"] );
	addTradeSkill( "Mithril Spurs", 235, L["UWD"] );
	addTradeSkill( "Mithril Scale Shoulders", 235, L["UWD"] );
	addTradeSkill( "Heavy Mithril Boots", 235, L["Trainer"] );
	addTradeSkill( "Ornate Mithril Breastplate", 235, L["Trainer"] );
	addTradeSkill( "Ornate Mithril Boots", 240, L["Trainer"] );
	addTradeSkill( "Dazzling Mithril Rapier", 240, L["UWD"] );
	addTradeSkill( "Heavy Mithril Helm", 245, L["UWD"] );
	addTradeSkill( "Ornate Mithril Helm", 245, "Reward from the quest A Good Head on Your Shoulders from Trenton Lighthammer (Tanaris).  You need to do to do the Galvan the Ancient quests first." );
	addTradeSkill( "Runed Mithril Hammer", 245, L["UWD"] );
	addTradeSkill( "Dense Sharpening Stone", 250, L["Trainer"] );
	addTradeSkill( "Dense Weightstone", 250, L["Trainer"] );
	addTradeSkill( "Dense Grinding Stone", 250, L["Trainer"] );
	addTradeSkill( "Thorium Armor", 250, L["UWD"] );
	addTradeSkill( "Thorium Belt", 250, L["UWD"] );
	addTradeSkill( "Orcish War Leggings", 250, "If anybody knows how they got this, let me (the mod author) know.  I'm surmising it is trained (there are no plans, since I can't find records of them) after you do the horde blacksmithing quest The Old Ways", BFAC["Horde"] );
	addTradeSkill( "Ebon Shiv", 255, L["Vendor"] );
	addTradeSkill( "Thorium Bracers", 255, L["UWD"] );
	addTradeSkill( "Radiant Belt", 260, L["UWD"] );
	addTradeSkill( "Imperial Plate Shoulders", 265, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Imperial Plate Belt", 265, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Dark Iron Mail", 270, "These can drop from Blacksmith Plans (scrolls you can click) in BRD.  Also (allegedly) an incredibly rare drop (less than 00.01%) from certain mobs in BRD/BRM" );
	addTradeSkill( "Radiant Breastplate", 270, L["UWD"] );
	addTradeSkill( "Imperial Plate Bracers", 270, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Thorium Shield Spike", 275, L["UWD"] );
	addTradeSkill( "Ornate Thorium Handaxe", 275, L["Vendor"] );
	addTradeSkill( "Arcanite Skeleton Key", 275, L["Trainer"] );
	addTradeSkill( "Arcanite Rod", 275, L["Trainer"] );
	addTradeSkill( "Dark Iron Shoulders", 280, "These can drop from Blacksmith Plans (scrolls you can click) in BRD.  Also (allegedly) an incredibly rare drop (less than 00.01%) from certain mobs in BRD/BRM" );
	addTradeSkill( "Thorium Boots", 280, L["UWD"] );
	addTradeSkill( "Thorium Helm", 280, L["UWD"] );
	addTradeSkill( "Huge Thorium Battleaxe", 280, L["Vendor"] );
	addTradeSkill( "Radiant Gloves", 285, L["UWD"] );
	addTradeSkill( "Radiant Boots", 290, L["UWD"] );
	addTradeSkill( "Volcanic Hammer", 290, "Frequent drop from Volchan, that big elite guy that wanders around Burning Steppes" );
	addTradeSkill( "Heavy Timbermaw Belt", 290, "You can buy this from Meilosh in Felwood when you are Honored with Timbermaw Furbolgs" );
	addTradeSkill( "Girdle of the Dawn", 290, "You can buy this from an Argent Quartermaster when you are Honored with Argent Dawn" );
	addTradeSkill( "Imperial Plate Boots", 295, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Imperial Plate Helm", 295, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Radiant Circlet", 295, L["UWD"] );
	addTradeSkill( "Thorium Leggings", 300, L["UWD"] );
	addTradeSkill( "Imperial Plate Chest", 300, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Runic Plate Shoulders", 300, "Mob Drop: from Strashaz Serpent Guards in Dustwallow Marsh (Alcaz Island)" );
	addTradeSkill( "Runic Plate Boots", 300, "Mob Drop: from Scarlet Cavaliers in Western Plaguelands (Hearthglen" );
	addTradeSkill( "Radiant Leggings", 300, L["UWD"] );
	addTradeSkill( "Runic Plate Helm", 300, "Mob Drop: from Strashaz Warriors in Dustwallow Marsh (Alcaz Island)" );
	addTradeSkill( "Imperial Plate Leggings", 300, "When you are at least level 50 and blacksmithing 265 you can obtain this quest from Derotain Mudsipper in Gadgetzan" );
	addTradeSkill( "Runic Breastplate", 300, "Mob Drop: from Strashaz Myrmidons in Dustwallow Marsh (Alcaz Island)" );
	addTradeSkill( "Runic Plate Leggings", 300, "Mob Drop: from Scarlet Smiths in Western Plaguelands (Hearthglen)" );
	addTradeSkill( "Sulfuron Hammer", 300, "Reward from the quest 'A Binding Contract' from Lokhtos Darkbargainer in BRD.  Oh, you'll need to give him a Sulfuron Ingot to complete the quest" );
	addTradeSkill( "Elemental Sharpening Stone", 300, "BoP Drop from certain Molten Core bosses" );
	addTradeSkill( "Heavy Timbermaw Boots", 300, "You can buy this from Meilosh in Felwood when you are honored with Timbermaw Furbolgs" );
	addTradeSkill( "Gloves of the Dawn", 300, "You can buy this from an Argent Quartermaster when you are revered with Argent Dawn" );
	addTradeSkill( "Bloodsoul Breastplate", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Bloodsoul Gauntlets", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Bloodsoul Shoulders", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Darksoul Breastplate", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Darksoul Leggings", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Darksoul Shoulders", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Darkrune Breastplate", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)"  );
	addTradeSkill( "Darkrune Gauntlets", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Darkrune Helm", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Heavy Obsidian Belt", 300, "Sold by Vargus in Cenarion Hold when you are friendly with Cenarion Circle" );
	addTradeSkill( "Light Obsidian Belt", 300, "Sold by Vargus in Cenarion Hold when you are honored with Cenarion Circle" );
	addTradeSkill( "Jagged Obsidian Shield", 300, "Sold by Vargus in Cenarion Hold when you are revered with Cenarion Circle" );
	addTradeSkill( "Black Grasp of the Destroyer", 300, "7% drop from Moam in AQ20" );
	addTradeSkill( "Obsidian Mail Tunic", 300, "Sold by Vargus in Cenarion Hold when you are exalted with Cenarion Circle" );
	addTradeSkill( "Thick Obsidian Breastplate", 300, "6% drop from The Prophet Skeram in AQ40" );
	addTradeSkill( "Ironvine Breastplate", 300, "Sold by Vargus in Cenarion Hold when you are revered with Cenarion Circle" );
	addTradeSkill( "Ironvine Gloves", 300, "Sold by Vargus in Cenarion Hold when you are honored with Cenarion Circle" );
	addTradeSkill( "Ironvine Belt", 300, "Sold by Vargus in Cenarion Hold when you are friendly with Cenarion Circle" );
	addTradeSkill( "Enchanted Thorium Blades", 300, L["Trainer"] );

	addTradeSkill( "The Shatterer", 235 , L["Trainer"] );
	addTradeSkill( "Phantom Blade", 245, L["Trainer"] );
	addTradeSkill( "Blight", 250, L["Trainer"] );

	addTradeSkill( "Truesilver Champion", 260, L["Trainer"] );
	addTradeSkill( "Earthforged Leggings", 260, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Windforged Leggings", 260, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Light Earthforged Blade", 260, "Weaponsmith", L["Trainer"] );
	addTradeSkill( "Light Emberforged Hammer", 260, "Weaponsmith", L["Trainer"] );
	addTradeSkill( "Light Skyforged Axe", 260, "Weaponsmith", L["Trainer"] );

	addTradeSkill( "Dark Iron Pulverizer", 265, "Weaponsmith", "Drops from Grizzle in BRD" ); -- specialty is probably a bliz mistake, might get fixed some day
	addTradeSkill( "Dark Iron Sunderer", 275, "Drops from Hammered Patrons or Ribbly's Crony in BRD" );
	addTradeSkill( "Heartseeker", 300, "Drops from Cannon Master Willey in Stratholme" );
	addTradeSkill( "Black Amnesty", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Blackfury", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
  
	addTradeSkill( "Truesilver Gauntlets", 225, L["Trainer"] );
	addTradeSkill( "Truesilver Breastplate", 245, L["Trainer"] );
	addTradeSkill( "Wildthorn Mail", 270, L["UWD"] );
	addTradeSkill( "Dark Iron Plate", 285, "Drops from Ribbly Screwspigot in BRD" );
	addTradeSkill( "Demon Forged Breastplate", 285, "Reward from the quest 'The Demon Forge' given by Lorax in Winterspring.  It requires that you kill a mob in UBRS, and there might be prereqs that I am unaware of"  );
	addTradeSkill( "Fiery Plate Gauntlets", 290, "Reward from the quest 'Fiery Plate Gauntlets'" );
	addTradeSkill( "Dawnbringer Shoulders", 290, L["UWD"] );
	addTradeSkill( "Storm Gauntlets", 295, L["Vendor"] );
	addTradeSkill( "Dark Iron Bracers", 295, "You can buy this from Lokhtos Darkbargainer in BRD when you are friendly with Thorium Brotherhood" );
	addTradeSkill( "Fiery Chain Girdle", 295, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Whitesoul Helm", 300, L["UWD"] );
	addTradeSkill( "Helm of the Great Chief", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );
	addTradeSkill( "Lionheart Helm", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)");
	addTradeSkill( "Stronghold Gauntlets", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );
	addTradeSkill( "Enchanted Thorium Helm", 300, "Turn in Enchanted Thorium Platemail Vol III (Top and bottom halves) to Athaeneum in the DM Library" );
	addTradeSkill( "Enchanted Thorium Leggings", 300, "Turn in Enchanted Thorium Platemail Vol II (Top and bottom halves) to Athaeneum in the DM Library" );
	addTradeSkill( "Enchanted Thorium Breastplate", 300, "Turn in Enchanted Thorium Platemail Vol I (Top and bottom halves) to Athaeneum in the DM Library" );
	addTradeSkill( "Invulnerable Mail", 300, "1% drop from Goraluk Anvilcrack in UBRS, also a world drop from high-level (60+) mobs pre-TBC" );
	addTradeSkill( "Dark Iron Leggings", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Fiery Chain Shoulders", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Dark Iron Helm", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Dark Iron Gauntlets", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Dark Iron Boots", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Titanic Leggings", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );

	addTradeSkill( "Blazing Rapier", 280, "A reward from the Corruption quest given in Everlook (Winterspring)" );
	addTradeSkill( "Corruption", 290, "These can drop from Blacksmith Plans (scrolls you can click) in Stratholme.  Also (allegedly) an incredibly rare drop ( 0.2% and less, depending on the mob) from certain undead guys in Stratholme" );
	addTradeSkill( "Arcanite Champion", 300, "5% drop from Goraluk Anvilcrack in UBRS" );
	addTradeSkill( "Frostguard", 300, "Drops from rare spawn Foreman Marcrid in WPL, roundabouts the lumber mill.  High frequency of getting this drop (85%+"  );
	addTradeSkill( "Dark Iron Reaver", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Blackguard", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Sageblade", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );

	addTradeSkill( "Enchanted Battlehammer", 280, "Quest reward from 'Sweet Serenity', given by Lilith the Lithe in Everlook (Winterspring)" );
	addTradeSkill( "Serenity", 285, "These can drop from Blacksmith Plans (scrolls you can click) in Stratholme.  Also (allegedly) an incredibly rare drop ( 0.2% and less, depending on the mob) from certain Crimson guys in Stratholme" );
	addTradeSkill( "Hammer of the Titans", 300, "6% drop from Maleki the Pallid in Stratholme" );
	addTradeSkill( "Masterwork Stormhammer", 300, "5% drop from Goraluk Anvilcrack in UBRS" );
	addTradeSkill( "Ebon Hand", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );
	addTradeSkill( "Persuader", 300, "This is a world drop but appears to mostly drop from mobs 60+ (pre-TBC).  (Buy on AH)" );

	addTradeSkill( "Dawn's Edge", 275, "Reward from quest Snakestone of the Shadow Huntress, given in Everlook (Winterspring)" );
	addTradeSkill( "Annihilator", 300, "9% drop from the Quartermaster in LBRS" );
	addTradeSkill( "Arcanite Reaper", 300, "6% drop from rare spawn in LBRS Bannok Grimaxe" );
	addTradeSkill( "Dark Iron Destroyer", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Nightfall", 300, "You can buy this from Lokhtos Darkbargainer in BRD when you are exalted with Thorium Brotherhood" );

	addTradeSkill( "Fel Sharpening Stone", 300, L["Trainer"] );
	addTradeSkill( "Fel Weightstone", 300, L["Trainer"] );
	addTradeSkill( "Fel Iron Rod", 300, L["Trainer"] );
	addTradeSkill( "Fel Iron Chain Coif", 300, L["Trainer"] );
	addTradeSkill( "Fel Iron Plate Gloves", 300, L["Trainer"] );
	addTradeSkill( "Fel Iron Plate Belt", 305, L["Trainer"] );
	addTradeSkill( "Fel Iron Hatchet", 310, L["Trainer"] );
	addTradeSkill( "Fel Iron Chain Gloves", 310, L["Trainer"] );

	addTradeSkill( "Fel Iron Plate Boots", 315, L["Trainer"] );
	addTradeSkill( "Fel Iron Plate Pants", 315, L["Trainer"] );
	addTradeSkill( "Fel Iron Chain Bracers", 315, L["Trainer"] );
	addTradeSkill( "Fel Iron Hammer", 315, L["Trainer"] );

	addTradeSkill( "Fel Iron Greatsword", 320, L["Trainer"] );
	addTradeSkill( "Fel Iron Chain Tunic", 320, L["Trainer"] );

	addTradeSkill( "Adamantite Maul", 325, L["Vendor"] );
	addTradeSkill( "Fel Iron Breastplate", 325, L["Trainer"] );
	addTradeSkill( "Lesser Rune of Warding", 325, L["Trainer"] );

	addTradeSkill( "Adamantite Cleaver", 330, L["Vendor"] );
	addTradeSkill( "Adamantite Dagger", 330, L["Vendor"] );
	addTradeSkill( "Heavy Earthforged Breastplate", 330, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Stormforged Hauberk", 330, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Windforged Rapier", 330, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Stoneforged Claymore", 330, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Stoneforged Claymore", 330, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Great Earthforged Hammer", 330, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Lavaforged Hammer", 330, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Skyforged Great Axe", 330, "Axesmith", L["Trainer"] );
	addTradeSkill( "Stormforged Axe", 330, "Axesmith", L["Trainer"] );

	addTradeSkill( "Adamantite Rapier", 335, L["Vendor"] );
	addTradeSkill( "Adamantite Plate Bracers", 335, L["Vendor"] );
	addTradeSkill( "Adamantite Plate Gloves", 335, L["Vendor"] );

	addTradeSkill( "Lesser Rune of Shielding", 340, L["Vendor"] );
	addTradeSkill( "Adamantite Breastplate", 340, L["Vendor"] );

	addTradeSkill( "Felsteel Whisper Knives", 350, L["Trainer"] );
	addTradeSkill( "Adamantite Sharpening Stone", 350, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Greater Rune of Warding", 350, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Adamantite Rod", 350, L["Vendor"] );
	addTradeSkill( "Adamantite Weightstone", 350, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Flamebane Bracers", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are friendly with Aldor" );
	addTradeSkill( "Nether Chain Shirt", 350, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Breastplate of Kings", 350, "Armorsmith", L["Trainer"] );
	addTradeSkill( "The Planar Edge", 350, "Axesmith", L["Trainer"] );
	addTradeSkill( "Drakefist Hammer", 350, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Fireguard", 350, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Lionheart Blade", 350, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Drakefist Hammer", 350, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Lunar Crescent", 350, "Axesmith", L["Trainer"] );

	addTradeSkill( "Enchanted Adamantite Belt", 355, "You can buy this from Quartermaster Enuril in Shattrath when you are friendly with Scryers" );
	addTradeSkill( "Enchanted Adamantite Boots", 355, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Flamebane Helm", 355, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );

	addTradeSkill( "Enchanted Adamantite Breastplate", 360, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Flamebane Gloves", 360, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Felsteel Gloves", 360, "BoP mob drop from Auchenai Monks in Auchenai Crypts.  Only blacksmiths can see this drop" );
	addTradeSkill( "Felsteel Leggings", 360, "BoP mob drop from Unchained Doombringer in The Arcatraz.  Only blacksmiths can see this drop" );
	addTradeSkill( "Khorium Belt", 360, "BoP mob drop from Murkblood Raiders in Nagrand" );
	addTradeSkill( "Khorium Pants", 360, "BoP mob drop from Deathforge Guardians in Shadowmoon Valley" );
	addTradeSkill( "Felsteel Shield Spike", 360, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are exalted with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are exalted with Thrallmar" );

	addTradeSkill( "Enchanted Adamantite Leggings", 365, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Flamebane Breastplate", 365, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Felsteel Helm", 365, "BoP mob drop from Cabal Fanatic in Shadow Labyrinth" );
	addTradeSkill( "Gauntlets of the Iron Tower", 365, L["UWD"] );
	addTradeSkill( "Khorium Boots", 365, "BoP mob drop from Disembodied Protector in Netherstorm" );
	addTradeSkill( "Ragesteel Gloves", 365, "BoP mob drop from Boulderfist Warrior in Nagrand" );
	addTradeSkill( "Felfury Gauntlets", 365, L["UWD"] );
	addTradeSkill( "Steelgrip Gauntlets", 365, L["UWD"] );
	addTradeSkill( "Storm Helm", 365, L["UWD"] );
	addTradeSkill( "Helm of the Stalwart Defender", 365, L["UWD"] );
	addTradeSkill( "Oathkeeper's Helm", 365, L["UWD"] );
	addTradeSkill( "Black Felsteel Bracers", 365, L["UWD"] );
	addTradeSkill( "Bracers of the Green Fortress", 365, L["UWD"] );
	addTradeSkill( "Blessed Bracers", 365, L["UWD"] );
	addTradeSkill( "Felsteel Longblade", 365, L["UWD"] );
	addTradeSkill( "Khorium Champion", 365, L["UWD"] );
	addTradeSkill( "Fel Edged Battleaxe", 365, L["UWD"] );
	addTradeSkill( "Felsteel Reaper", 365, L["UWD"] );
	addTradeSkill( "Runic Hammer", 365, L["UWD"] );
	addTradeSkill( "Fel Hardened Maul", 365, L["UWD"] );
	addTradeSkill( "Eternium Runed Blade", 365, L["UWD"] );
	addTradeSkill( "Dirge", 365, L["UWD"] );
	addTradeSkill( "Hand of Eternity", 365, L["UWD"] );
	addTradeSkill( "Ragesteel Helm", 365, "BoP mob drop from Anger Guards in Blade's Edge Mountains" );

	addTradeSkill( "Ragesteel Breastplate", 370, "BoP mob drop from Ashtongue Warrior in Shadowmoon Valley" );
	addTradeSkill( "Swiftsteel Gloves", 370, "BoP mob drop from Nexus Stalkers in Mana-Tombs" );
 
	addTradeSkill( "Earthpeace Breastplate", 370, "BoP mob drop from High Botanist Freywinn in The Botanica" );

	addTradeSkill( "Greater Rune of Shielding", 375, "BoP mob drop from Sunfury Bloodwarders in Netherstorm" );
	addTradeSkill( "Eternium Rod", 375, L["Vendor"] );
	addTradeSkill( "Twisting Nether Chain Shirt", 375, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Embrace of the Twisting Nether", 375, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Bulwark of Kings", 375, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Bulwark of the Ancient Kings", 375, "Armorsmith", L["Trainer"] );
	addTradeSkill( "Wildguard Breastplate", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	addTradeSkill( "Wildguard Leggings", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "Wildguard Helm", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "Iceguard Breastplate", 375, "You can purchase this from Koren in Karazhan when you are honored with The Violet Eye" );
	addTradeSkill( "Iceguard Leggings", 375, "You can purchase this from Koren in Karazhan when you are revered with The Violet Eye" );
	addTradeSkill( "Iceguard Helm", 375, "You can purchase this from Koren in Karazhan when you are honored with The Violet Eye" );
	addTradeSkill( "Black Planar Edge", 375, "Axesmith", L["Trainer"] );
	addTradeSkill( "Blazefury", 375, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Blazeguard", 375, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Bloodmoon", 375, "Axesmith", L["Trainer"] );
	addTradeSkill( "Deep Thunder", 375, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Dragonmaw", 375, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Dragonstrike", 375, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Lionheart Champion", 375, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Lionheart Executioner", 375, "Swordsmith", L["Trainer"] );
	addTradeSkill( "Mooncleaver", 375, "Axesmith", L["Trainer"] );
	addTradeSkill( "Stormherald", 375, "Hammersmith", L["Trainer"] );
	addTradeSkill( "Wicked Edge of the Planes", 375, "Axesmith", L["Trainer"] );
	
end

-- Initializes the array adding all Cooking recipes.  As of 2.2 there are 106 recipes.

local function ARL_InitCooking()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Brilliant Smallfish", 1, L["Vendor"] );
	addTradeSkill( "Crispy Bat Wing", 1, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Charred Wolf Meat", 1, L["Trainer"] );
	addTradeSkill( "Gingerbread Cookie", 1, L["WintersVeil"], L["Seasonal"] );
	addTradeSkill( "Herb Baked Egg", 1, L["Trainer"] );
	addTradeSkill( "Lynx Steak", 1, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Roasted Boar Meat", 1, L["Trainer"] );
	addTradeSkill( "Slitherskin Mackerel", 1, L["Vendor"] );
	addTradeSkill( "Spice Bread", 1, L["Trainer"] );
	addTradeSkill( "Roasted Moongraze Tenderloin", 1, "Quest Reward: The Great Moongraze Hunt", BFAC["Alliance"]);
	addTradeSkill( "Kaldorei Spider Kabob", 10, "Quest Reward: Recipe of the Kaldorei", BFAC["Alliance"] );
	addTradeSkill( "Spiced Wolf Meat", 10, L["Trainer"] );
	addTradeSkill( "Scorpid Surprise", 20, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Beer Basted Boar Ribs", 25, "Quest Reward: Beer Basted Boar Ribs\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Roasted Kodo Meat", 35, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Egg Nog", 35, L["WintersVeil"], L["Seasonal"] );
	addTradeSkill( "Smoked Bear Meat", 40, L["Vendor"], BFAC["Alliance"]);
	addTradeSkill( "Fillet of Frenzy", 50, L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Strider Stew", 50, "Quest Reward: Easy Strider Living\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Boiled Clams", 50, L["Trainer"] );
	addTradeSkill( "Longjaw Mud Snapper", 50, L["Vendor"] );
	addTradeSkill( "Loch Frenzy Delight", 50, L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Rainbow Fin Albacore", 50, L["Vendor"] );
	addTradeSkill( "Coyote Steak", 50, L["Trainer"] );
	addTradeSkill( "Goretusk Liver Pie", 50, "Quest Reward: Goretusk Liver Pie\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Bat Bites", 50, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Blood Sausage", 60, "Quest Reward: Thelsamar Blood Sausages\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Thistle Tea", 60, "(A): Quest Reward: Klaven's Tower\n" .. TabSpace .. "(H): Quest Reward: Mission: Possible But Not Probable\n" .. TabSpace .. "Vendor: Smudge Thunderwood, Alterac Mountains", BCLASS["Rogue"]);
	addTradeSkill( "Crunchy Spider Surprise", 60, "(H): Quest Reward: Culinary Crunch\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Westfall Stew", 75, "Quest Reward: Westfall Stew\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Crab Cake", 75, L["Trainer"] );
	addTradeSkill( "Crocolisk Steak", 80, "Quest Reward: Crocolisk Hunting\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Smoked Sagefish", 80, L["Vendor"] );
	addTradeSkill( "Dry Pork Ribs", 80, L["Trainer"] );
	addTradeSkill( "Savory Deviate Delight", 85, "Uncommon Drop: The Barrens" );
	addTradeSkill( "Cooked Crab Claw", 85, L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Murloc Fin Soup", 90, "Quest Reward: Selling Fish\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Dig Rat Stew", 90, "Quest Reward: Dig Rat Stew", BFAC["Horde"] );
	addTradeSkill( "Clam Chowder", 90, L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Crispy Lizard Tail", 100, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Bristle Whisker Catfish", 100, L["Vendor"] );
	addTradeSkill( "Redridge Goulash", 100, "Quest Reward: Redridge Goulash\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Seasoned Wolf Kabob", 100, "Quest Reward: Seasoned Wolf Kabobs\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Gooey Spider Cake", 110, "Quest Reward: Dusky Crab Cakes\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Big Bear Steak", 110, "(H): Quest Reward: The Rescue\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Lean Venison", 110, L["Vendor"] );
	addTradeSkill( "Succulent Pork Ribs", 110, L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Crocolisk Gumbo", 120, "Quest Reward: Apprentice's Duties\n" .. TabSpace .. L["Vendor"], BFAC["Alliance"] );
	addTradeSkill( "Hot Lion Chops", 125, "(H): Quest Reward: Elixir of Pain\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Goblin Deviled Clams", 125, L["Trainer"] );
	addTradeSkill( "Lean Wolf Steak", 125, L["Vendor"] );
	addTradeSkill( "Curiously Tasty Omelet", 130, "(A): Quest Reward: Ormer's Revenge\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Tasty Lion Steak", 150, "Quest Reward: Costly Menace", BFAC["Alliance"] );
	addTradeSkill( "Heavy Crocolisk Stew", 150, L["Vendor"], BFAC["Horde"] );
	addTradeSkill( "Soothing Turtle Bisque", 175, "Quest Reward: Soothing Turtle Bisque" );
	addTradeSkill( "Barbecued Buzzard Wing", 175, "Quest Reward: Barbecued Buzzard Wings\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Giant Clam Scorcho", 175, L["Vendor"] );
	addTradeSkill( "Rockscale Cod", 175, L["Vendor"] );
	addTradeSkill( "Roast Raptor", 175, L["Vendor"] );
	addTradeSkill( "Hot Wolf Ribs", 175, L["Vendor"] );
	addTradeSkill( "Jungle Stew", 175, L["Vendor"] );
	addTradeSkill( "Carrion Surprise", 175, L["Vendor"] );
	addTradeSkill( "Mystery Stew", 175, L["Vendor"] );
	addTradeSkill( "Mithril Headed Trout", 175, L["Vendor"] );
	addTradeSkill( "Sagefish Delight", 175, L["Vendor"] );
	addTradeSkill( "Goldthorn Tea", 175, "Talk to Henry Stern in RFD" );
	addTradeSkill( "Dragonbreath Chili", 200, L["Vendor"] );
	addTradeSkill( "Heavy Kodo Stew", 200, L["Vendor"] );
	addTradeSkill( "Spider Sausage", 200, L["Trainer"] );
	addTradeSkill( "Spiced Chili Crab", 225, L["Vendor"] );
	addTradeSkill( "Monster Omelet", 225, L["Vendor"] );
	addTradeSkill( "Cooked Glossy Mightfish", 225, L["Vendor"] );
	addTradeSkill( "Spotted Yellowtail", 225, L["Vendor"] );
	addTradeSkill( "Filet of Redgill", 225, L["Vendor"] );
	addTradeSkill( "Undermine Clam Chowder", 225, L["Vendor"] );
	addTradeSkill( "Tender Wolf Steak", 225, L["Vendor"] );
	addTradeSkill( "Grilled Squid", 240, L["Vendor"] );
	addTradeSkill( "Hot Smoked Bass", 240, L["Vendor"] );
	addTradeSkill( "Nightfin Soup", 250, L["Vendor"] );
	addTradeSkill( "Poached Sunscale Salmon", 250, L["Vendor"] );
	addTradeSkill( "Lobster Stew", 275, L["Vendor"] );
	addTradeSkill( "Mightfish Steak", 275, L["Vendor"] );
	addTradeSkill( "Baked Salmon", 275, L["Vendor"] );
	addTradeSkill( "Runn Tum Tuber Surprise", 275, "BoP Mod Drop: Pusillin, Dire Maul" );
	addTradeSkill( "Smoked Desert Dumplings", 285, "Quest Reward: Desert Recipe" );
	addTradeSkill( "Dirge's Kickin' Chimaerok Chops", 300, "Quest Reward: Dirge's Kickin' Chimaerok Chops", "Raid" );
	
	-- Burning Crusade Recipes
	addTradeSkill( "Buzzard Bites", 300, "Quest Reward: Smooth as Butter" );
	addTradeSkill( "Ravager Dog", 300, L["Vendor"] );
	addTradeSkill( "Blackened Trout", 300, L["Vendor"] );
	addTradeSkill( "Feltail Delight", 300, L["Vendor"] );
	addTradeSkill( "Clam Bar", 300, "Friendly: Sporeggar", "Sporeggar" );
	addTradeSkill( "Sporeling Snack", 310, "Friendly: Sporeggar", "Sporeggar" );
	addTradeSkill( "Blackened Sporefish", 310, L["Vendor"] );
	addTradeSkill( "Blackened Basilisk", 310, L["Vendor"] );
	addTradeSkill( "Stewed Trout", 310, "Trainer: Kylene" );
	addTradeSkill( "Grilled Mudfish", 320, L["Vendor"] );
	addTradeSkill( "Poached Bluefish", 320, L["Vendor"] );
	addTradeSkill( "Roasted Clefthoof", 325, L["Vendor"] );
	addTradeSkill( "Warp Burger", 325, L["Vendor"] );
	addTradeSkill( "Talbuk Steak", 325, L["Vendor"] );
	addTradeSkill( "Golden Fish Sticks", 325, L["Vendor"] );
	addTradeSkill( "Crunchy Serpent", 335, "(H): Quest Reward: Mok'Nathal Treats\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Mok'Nathal Shortribs", 335, "(H): Quest Reward: Mok'Nathal Treats\n" .. TabSpace .. L["Vendor"] );
	addTradeSkill( "Spicy Crawdad", 350, L["Vendor"] );
	addTradeSkill( "Fisherman's Feast", 350, "Trainer: Kylene" );
	addTradeSkill( "Hot Buttered Trout", 350, "Trainer: Kylene" );
  
end

-- Initializes the array adding all Enchanting recipes.  As of 2.2 there are 215 recipes.

local function ARL_InitEnchanting()

	ARL_InitializeRecipeArray();

	-- Original Game Recipes
	addTradeSkill( "Enchant Bracer - Minor Health", 1, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Minor Deflection", 1, L["Trainer"] );
	addTradeSkill( "Runed Copper Rod", 1, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Minor Health", 15, L["Trainer"] );
	addTradeSkill( "Lesser Magic Wand", 15, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Minor Mana", 20, L["Vendor"] );
	addTradeSkill( "Enchant Chest - Minor Absorption", 40, L["Trainer"] );
	addTradeSkill( "Enchant Cloak - Minor Resistance", 45, L["Trainer"] );
	addTradeSkill( "Minor Wizard Oil", 45, L["Vendor"] );
	addTradeSkill( "Enchant Bracer - Minor Stamina", 50, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Lesser Health", 60, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Minor Spirit", 60, L["UWD"] );
	addTradeSkill( "Enchant Cloak - Minor Protection", 70, L["Trainer"] );
	addTradeSkill( "Greater Magic Wand", 70, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Lesser Mana", 80, L["Vendor"]);
	addTradeSkill( "Enchant Bracer - Minor Agility", 80, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Minor Strength", 80, L["UWD"]  );
	addTradeSkill( "Enchant Weapon - Minor Beastslayer", 90, L["UWD"]  );
	addTradeSkill( "Enchant Weapon - Minor Striking", 90, L["Trainer"] );
	addTradeSkill( "Enchant 2H Weapon - Minor Impact", 100, L["Trainer"] );
	addTradeSkill( "Enchant 2H Weapon - Lesser Intellect", 100, L["Vendor"] );
	addTradeSkill( "Runed Silver Rod", 100, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Minor Stamina", 105, L["Trainer"] );
	addTradeSkill( "Enchant 2H Weapon - Lesser Spirit", 110, L["UWD"] );
	addTradeSkill( "Enchant Cloak - Minor Agility", 110, L["Vendor"] );
	addTradeSkill( "Enchant Cloak - Lesser Protection", 115, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Lesser Protection", 115, L["UWD"] );
	addTradeSkill( "Enchant Chest - Health", 120, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Lesser Spirit", 120, L["UWD"] );
	addTradeSkill( "Enchant Cloak - Lesser Fire Resistance", 125, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Minor Stamina", 125, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Minor Agility", 125, L["Vendor"]) ;
	addTradeSkill( "Enchant Bracer - Lesser Stamina", 130, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Lesser Spirit", 130, L["Trainer"] );
	addTradeSkill( "Enchant Cloak - Lesser Shadow Resistance", 135, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Lesser Striking", 140, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Lesser Strength", 140, L["Vendor"] );
	addTradeSkill( "Enchant Chest - Lesser Absorption", 140, L["Trainer"] );
	addTradeSkill( "Enchant 2H Weapon - Lesser Impact", 145, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Mana", 145, L["Trainer"] );
	addTradeSkill( "Enchant Gloves - Mining", 145, "Mob Drop: Dark Iron Dwarf, Dark Iron Demonlitionist, Dark Iron Tunneler, Dark Iron Saboteur, Balgaras the Foul, Wetlands" );
	addTradeSkill( "Enchant Gloves - Herbalism", 145, "Mob Drop: Vengeful Ancient, Blackened Ancient, Charred Ancient, Stonetalon Mountaions, Crazed Ancient, Withered Ancient, Ashenvale" );
	addTradeSkill( "Enchant Gloves - Fishing", 145, "Mob Drop:  Scargil, Torn Fin Coastrunner, Torn Fin Oracle, Torn Fin Muckdweller, Torn Fin Tidehunter, Hillsbrad Foothills" );
	addTradeSkill( "Enchant Chest - Minor Stats", 150, L["Trainer"] );
	addTradeSkill( "Runed Golden Rod", 150, L["Trainer"] );
	addTradeSkill( "Lesser Mystic Wand", 155, L["Trainer"] );
	addTradeSkill( "Minor Mana Oil", 150, L["Vendor"] );
	addTradeSkill( "Enchant Bracer - Lesser Intellect", 150, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Lesser Stamina", 155, L["Trainer"] );
	addTradeSkill( "Enchant Cloak - Defense", 155, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Lesser Agility", 160, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Greater Health", 160, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Spirit", 165, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Lesser Stamina", 170, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Lesser Deflection", 170, L["Vendor"] );
	addTradeSkill( "Enchant Bracer - Stamina", 170, L["Trainer"] );
	addTradeSkill( "Enchant Weapon - Lesser Beastslayer", 175, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Lesser Elemental Slayer", 175, L["UWD"] );
	addTradeSkill( "Enchant Cloak - Fire Resistance", 175, L["Trainer"] );
	addTradeSkill( "Greater Mystic Wand", 175, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Spirit", 180, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Strength", 180, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Greater Mana", 185, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Lesser Spirit", 190, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Winter's Might", 190, L["WintersVeil"], L["Seasonal"] );
	addTradeSkill( "Enchant Shield - Lesser Block", 195, L["UWD"]  );
	addTradeSkill( "Enchant Weapon - Striking", 195, L["Trainer"] );
	addTradeSkill( "Enchant 2H Weapon - Impact", 200, L["Trainer"] );
	addTradeSkill( "Enchant Gloves - Skinning", 200, "Mob Drop: Nimar the Slayer, Witherbark Berserker, Witherbark Headhunter, Witherbark Shadow Hunter, Arathi Highlands" );
	addTradeSkill( "Enchant Chest - Lesser Stats", 200, L["Trainer"] );
	addTradeSkill( "Runed Truesilver Rod", 200, L["Trainer"] );
	addTradeSkill( "Lesser Wizard Oil", 200, L["Vendor"] );
	addTradeSkill( "Enchant Cloak - Greater Defense", 205, L["Trainer"] );
	addTradeSkill( "Enchant Cloak - Resistance", 205, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Stamina", 210, L["UWD"] );
	addTradeSkill( "Enchant Bracer - Intellect", 210, L["Trainer"] );
	addTradeSkill( "Enchant Gloves - Agility", 210, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Stamina", 215, L["Trainer"] );
	addTradeSkill( "Enchant Gloves - Advanced Mining", 215, "Mob Drop: Venture Co. Strip Miner, STV" );
	addTradeSkill( "Enchant Bracer - Greater Spirit", 220, L["UWD"] );
	addTradeSkill( "Enchant Chest - Superior Health", 220, L["Trainer"] );
	addTradeSkill( "Enchant Gloves - Advanced Herbalism", 225, "Mob Drop: Mire Lord, Molt Thorn, Swampwalker, Swampwalker Elder, Tangled Horror, Swamp of Sorrows" );
	addTradeSkill( "Enchant Cloak - Lesser Agility", 225, "Mob Drop: Syndicate Assassin, Alterac Mountains, Wastewander Assassin, Wastewander Scofflaw, Tanaris" );
	addTradeSkill( "Enchant Gloves - Strength", 225, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Minor Speed", 225, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Greater Spirit", 230, L["Trainer"] );
	addTradeSkill( "Enchant Weapon - Demonslaying", 230, L["UWD"] );
	addTradeSkill( "Enchant Chest - Superior Mana", 230, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Deflection", 235, L["Vendor"] );
	addTradeSkill( "Enchant Shield - Frost Resistance", 235, L["UWD"] );
	addTradeSkill( "Enchant Boots - Agility", 235, L["Trainer"] );
	addTradeSkill( "Enchant 2H Weapon - Greater Impact", 240, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Greater Strength", 240, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Stats", 245, L["Trainer"] );
	addTradeSkill( "Enchant Weapon - Greater Striking", 245, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Greater Stamina", 245, L["UWD"] );
	addTradeSkill( "Enchant Gloves - Riding Skill", 250, L["UWD"] );
	addTradeSkill( "Enchant Gloves - Minor Haste", 250, L["Trainer"] );
	addTradeSkill( "Enchanted Leather", 250, L["Trainer"] );
	addTradeSkill( "Enchanted Thorium", 250, L["Trainer"] );
	addTradeSkill( "Lesser Mana Oil", 250, L["Vendor"] );
	addTradeSkill( "Enchant Bracer - Greater Intellect", 255, "Trainer -- (Formerly Mob Drop: Vilebranch Shadowcaster (The Hinterlands))" );
	addTradeSkill( "Enchant Boots - Greater Stamina", 255, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Fiery Weapon", 265, "Mob Drop: Pyromancer Loregrain, BRD" );
	addTradeSkill( "Smoking Heart of the Mountain", 265, "Mob Drop: Lord Roccor BRD" );
	addTradeSkill( "Enchant Cloak - Greater Resistance", 265, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Greater Stamina", 265, L["Vendor"] );
	addTradeSkill( "Enchant Bracer - Superior Spirit", 270, L["Trainer"] );
	addTradeSkill( "Enchant Gloves - Greater Agility", 270, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Spirit", 275, L["UWD"] );
	addTradeSkill( "Enchant Chest - Major Health", 275, L["Vendor"] );
	addTradeSkill( "Wizard Oil", 275, L["Vendor"] );
	addTradeSkill( "Enchant Shield - Superior Spirit", 280, L["Trainer"] );
	addTradeSkill( "Enchant Weapon - Icy Chill", 285, "Mob Drop: Anguished Highborne, Winterspring" );
	addTradeSkill( "Enchant Cloak - Superior Defense", 285, L["Vendor"] );
	addTradeSkill( "Enchant Chest - Major Mana", 290, L["Trainer"] );
	addTradeSkill( "Runed Arcanite Rod", 290, L["Vendor"] );
	addTradeSkill( "Enchant Weapon - Strength", 290, "Friendly: Thorium Brotherhood", "Thorium Brotherhood" );
	addTradeSkill( "Enchant Weapon - Agility", 290, "Honored: Timbermaw Hold", "Timbermaw Hold" );
	addTradeSkill( "Enchant Bracer - Mana Regeneration", 290, "Honored: Argent Dawn", "Argent Dawn" );
	addTradeSkill( "Enchant 2H Weapon - Agility", 290, "Friendly: Timbermaw Hold", "Timbermaw Hold" );
	addTradeSkill( "Enchant Gloves - Greater Strength", 295, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Greater Agility", 295, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Superior Strength", 295, "Mob Drop: Deadwind Warlock, Deadwind Pass" );
	addTradeSkill( "Enchant 2H Weapon - Superior Impact", 295, "Mob Drop: Blackhand Elite, LBRS" );
	addTradeSkill( "Enchant Weapon - Unholy Weapon", 295, "Mob Drop: Thuzadin Shadowcaster, Stratholme" );
	addTradeSkill( "Enchant 2H Weapon - Major Intellect", 300, "Mob Drop: Crimson Sorcerer, Stratholme" );
	addTradeSkill( "Enchant Weapon - Superior Striking", 300, "Mob Drop: Spirestone Warlord, LBRS" );
	addTradeSkill( "Enchant Bracer - Superior Stamina", 300, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Crusader", 300, "Mob Drop: Scarlet Spellbinder, Western Plaguelands" );
	addTradeSkill( "Enchant Chest - Greater Stats", 300, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Lifestealing", 300, "Mob Drop: Spectral Researcher, Scholomance" );
	addTradeSkill( "Enchant 2H Weapon - Major Spirit", 300, "Drops from Scholomance Adept, Scholomance" );
	addTradeSkill( "Enchant Weapon - Spell Power", 300, "BoP Mob Drop: Random bosses in MC", "Raid" );
	addTradeSkill( "Enchant Weapon - Healing Power", 300, "BoP Mob Drop: Random bosses in MC", "Raid" );
	addTradeSkill( "Enchant Bracer - Healing Power", 300, "Revered: Argent Dawn", "Argent Dawn" );
	addTradeSkill( "Enchant Weapon - Mighty Spirit", 300, "Honored: Thorium Brotherhood", "Thorium Brotherhood" );
	addTradeSkill( "Enchant Weapon - Mighty Intellect", 300, "Revered: Thorium Brotherhood", "Thorium Brotherhood" );
	addTradeSkill( "Enchant Gloves - Shadow Power", 300, "BoP Mob Drop: Random bosses in AQ20/AQ40", "Raid" );
	addTradeSkill( "Enchant Gloves - Frost Power", 300, "BoP Mob Drop: Random bosses in AQ20/AQ40", "Raid" );
	addTradeSkill( "Enchant Gloves - Fire Power", 300, "BoP Mob Drop: Random bosses in AQ20/AQ40", "Raid" );
	addTradeSkill( "Enchant Gloves - Healing Power", 300, "BoP Mob Drop: Random bosses in AQ20/AQ40", "Raid" );
	addTradeSkill( "Enchant Cloak - Greater Fire Resistance", 300, "Friendly: Cenarion Circle", "Cenarion Circle" );
	addTradeSkill( "Enchant Cloak - Greater Nature Resistance", 300, "Honored: Cenarion Circle", "Cenarion Circle" );
	addTradeSkill( "Brilliant Wizard Oil", 300, "Honored: Zandalar Tribe", "Zandalar" );
	addTradeSkill( "Brilliant Mana Oil", 300, "Friendly: Zandalar Tribe", "Zandalar" );

	-- Burning Crusade Recipes
	addTradeSkill( "Enchant Gloves - Superior Agility", 300, "Exalted: Keepers of Time", "Keepers of Time" );
	addTradeSkill( "Enchant Gloves - Threat", 300, "Exalted: The Sha'tar", "The Sha'tar" );
	addTradeSkill( "Enchant Cloak - Stealth", 300, "Exalted: Cenarion Expedition", "Cenarion Expedition" );
	addTradeSkill( "Enchant Cloak - Subtlety", 300, "(A): Exalted: Honor Hold\n(H): Exalted Thrallmar", "Thrallmar" );
	addTradeSkill( "Enchant Cloak - Dodge", 300, "Exalted: Lower City", "Lower City" );
	addTradeSkill( "Runed Fel Iron Rod", 300, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Restore Mana Prime", 300, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Assault", 300, L["Trainer"] );
	addTradeSkill( "Enchant Boots - Vitality", 305, L["UWD"] );
	addTradeSkill( "Enchant Gloves - Blasting", 305, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Brawn", 305, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Major Intellect", 305, L["Trainer"] );
	addTradeSkill( "Superior Mana Oil", 310, L["Vendor"] );
	addTradeSkill( "Enchant Gloves - Assault", 310, L["Trainer"] );
	addTradeSkill( "Enchant Shield - Tough Shield", 310, L["Trainer"] );
	addTradeSkill( "Enchant Cloak - Greater Agility", 310, L["Trainer"] );
	addTradeSkill( "Enchant Cloak - Major Armor", 310, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Stats", 315, L["Trainer"] );
	addTradeSkill( "Enchant Chest - Exceptional Health", 315, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Major Defense", 320, "BoP Mob Drop: Ethereum Nullifier, Netherstorm" );
	addTradeSkill( "Enchant Boots - Fortitude", 320, "BoP Mob Drop: Ethereal Priest, Mana-Tombs" );
	addTradeSkill( "Enchant Chest - Major Spirit", 320, L["Trainer"] );
	addTradeSkill( "Prismatic Sphere", 325, L["Trainer"] );
	addTradeSkill( "Enchant Bracer - Superior Healing", 325, "(A): Friendly: Honor Hold\n(H): Friendly Thrallmar", "Thrallmar" );
	addTradeSkill( "Enchant Shield - Intellect", 325, L["Vendor"] );
	addTradeSkill( "Enchant Cloak - Spell Penetration", 325, "Friendly: The Consortium", "Consortium" );
	addTradeSkill( "Enchant Shield - Major Stamina", 325, L["Vendor"] );
	addTradeSkill( "Enchant Cloak - Major Resistance", 330, L["UWD"] );
	addTradeSkill( "Large Prismatic Shard", 325, L["Vendor"] );
	addTradeSkill( "Enchant Bracer - Restore Mana Prime", 335, L["UWD"] );
	addTradeSkill( "Superior Wizard Oil", 340, L["Vendor"] );
	addTradeSkill( "Enchant Shield - Shield Block", 340, L["UWD"] );
	addTradeSkill( "Enchant Boots - Dexterity", 340, "BoP Mob Drop: Raging Skeletons, Auchenai Crypts" );
	addTradeSkill( "Enchant Weapon - Major Intellect", 340, "BoP Mob Drop: Sunfury Researchers, Netherstorm" );
	addTradeSkill( "Enchant Gloves - Major Strength", 340, L["Trainer"] );
	addTradeSkill( "Enchant Weapon - Major Striking", 340, "Honored: The Consortium", "Consortium" );
	addTradeSkill( "Enchant Chest - Exceptional Stats", 345, "(A): Revered: Honor Hold\n(H): Revered Thrallmar", "Thrallmar" );
	addTradeSkill( "Enchant Chest - Major Resilience", 345, L["UWD"] );
	addTradeSkill( "Enchant Bracer - Fortitude", 350, "BoP Mob Drop: Coilfang Oracles, The Steamvault" );
	addTradeSkill( "Enchant 2H Weapon - Savagery", 350, "BoP Mob Drop: Shattered Hand Centurions, The Shattered Halls" );
	addTradeSkill( "Enchant Weapon - Potency", 350, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Major Spellpower", 350, "BoP Mob Drop: Bash'ir Spell-Thief, Blade's Edge Mountains" );
	addTradeSkill( "Void Sphere", 350, L["Trainer"] );
	addTradeSkill( "Nexus Transformation", 350, L["Trainer"] );
	addTradeSkill( "Small Prismatic Shard", 350, L["Trainer"] );
	addTradeSkill( "Runed Adamantite Rod", 350, L["Vendor"] );
	addTradeSkill( "Enchant Gloves - Major Healing", 350, "Honored: The Sha'tar", "Sha'tar" );
	addTradeSkill( "Enchant Weapon - Greater Agility", 350, "Exalted: Violet Eye", "Violet Eye" );
	addTradeSkill( "Enchant Cloak - Greater Arcane Resistance", 350, "BoP Mob Drop: Eclipsion Archmages, SMV" );
	addTradeSkill( "Enchant Cloak - Greater Shadow Resistance", 350, "BoP Mob Drop: Voidshriekers, Netherstorm" );
	addTradeSkill( "Enchant Weapon - Major Healing", 350, "Revered: The Sha'tar", "Sha'tar" );
	addTradeSkill( "Enchant Bracer - Spellpower", 360, "BoP mob drop from Bloodmaul Geomancers in Blade's Edge Mountains" );
	addTradeSkill( "Enchant Ring - Striking", 360, "Revered: The Consortium", "Raid" );
	addTradeSkill( "Enchant Ring - Spellpower", 360, "Honored: Keepers of Time" );
	addTradeSkill( "Enchant Shield - Resistance", 360, L["UWD"] );
	addTradeSkill( "Enchant 2H Weapon - Major Agility", 360, "BoP Mob Drop: Eredar Deathbringer, The Arcatraz" );
	addTradeSkill( "Enchant Weapon - Spellsurge", 360, L["UWD"] );
	addTradeSkill( "Enchant Weapon - Battlemaster", 360, L["UWD"] );
	addTradeSkill( "Enchant Gloves - Spell Strike", 360, "Revered: Cenarion Expedition", "Cenarion Expedition" );
	addTradeSkill( "Enchant Gloves - Major Spellpower", 360, "Honored: Keepers of Time", "Keepers of Time" );
	addTradeSkill( "Enchant Boots - Cat's Swiftness", 360, L["UWD"] );
	addTradeSkill( "Enchant Boots - Boar's Speed", 360, L["UWD"] );
	addTradeSkill( "Enchant Ring - Healing Power", 370, "Revered: The Sha'tar", "Sha'tar" );
	addTradeSkill( "Enchant Boots - Surefooted", 370, "Karazhan: Enchanted Stagehands", "Raid" );
	addTradeSkill( "Runed Eternium Rod", 375, L["Vendor"] );
	addTradeSkill( "Enchant Ring - Stats", 375, "Revered: Scale of the Sands", "Raid" );
	addTradeSkill( "Enchant Weapon - Sunfire", 375, "Karazhan: Shade of Aran", "Raid" );
	addTradeSkill( "Enchant Weapon - Soulfrost", 375, "Karazhan: Illhoof", "Raid" );
	addTradeSkill( "Enchant Weapon - Mongoose", 375, "Karazhan: Moroes", "Raid" );

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Engineering recipes.  As of 2.2 there are 

local function ARL_InitEngineering()

	ARL_InitializeRecipeArray();

	addTradeSkill( L["Rough Blasting Powder"], 1, L["Trainer"] );
	addTradeSkill( L["Rough Dynamite"], 1, L["Trainer"] );
	addTradeSkill( L["Crafted Light Shot"], 1, L["Trainer"] );
	addTradeSkill( L["Handful of Copper Bolts"], 30, L["Trainer"] );
	addTradeSkill( L["Rough Copper Bomb"], 30, L["Trainer"] );
	addTradeSkill( L["Copper Tube"], 50, L["Trainer"] );
	addTradeSkill( L["Rough Boomstick"], 50, L["Trainer"] );
	addTradeSkill( L["Arclight Spanner"], 50, L["Trainer"] );
	addTradeSkill( L["Crude Scope"], 60, L["Trainer"] );
	addTradeSkill( L["Copper Modulator"], 65, L["Trainer"] );
	addTradeSkill( L["Mechanical Squirrel"], 75, L["UWD"] );
	addTradeSkill( L["Coarse Blasting Powder"], 75, L["Trainer"] );
	addTradeSkill( L["Crafted Heavy Shot"], 75, L["Trainer"] );
	addTradeSkill( L["Coarse Dynamite"], 75, L["Trainer"] );
	addTradeSkill( L["Target Dummy"], 85, L["Trainer"] );
	addTradeSkill( L["Silver Contact"], 90, L["Trainer"] );
	addTradeSkill( L["Small Seaforium Charge"], 100, L["UWD"] );
	addTradeSkill( L["Flying Tiger Goggles"], 100, L["Trainer"] );
	addTradeSkill( L["Practice Lock"], 100, L["Trainer"] );
	addTradeSkill( L["EZ-Thro Dynamite"], 100, L["UWD"] );
	addTradeSkill( L["Deadly Blunderbuss"], 105, L["Trainer"] );
	addTradeSkill( L["Large Copper Bomb"], 105, L["Trainer"] );
	addTradeSkill( L["Bronze Tube"], 105, L["Trainer"] );
	addTradeSkill( L["Standard Scope"], 110, L["Trainer"] );
	addTradeSkill( L["Lovingly Crafted Boomstick"], 120, L["Vendor"] );
	addTradeSkill( L["Shadow Goggles"], 120, L["UWD"] );
	addTradeSkill( L["Small Bronze Bomb"], 120, L["Trainer"] );
	addTradeSkill( L["Whirring Bronze Gizmo"], 125, L["Trainer"] );
	addTradeSkill( L["Flame Deflector"], 125, L["Flame Detector Obt"] );
	addTradeSkill( L["Heavy Blasting Powder"], 125, L["Trainer"] );
	addTradeSkill( L["Heavy Dynamite"], 125, L["Trainer"] );
	addTradeSkill( L["Crafted Solid Shot"], 125, L["Trainer"] );
	addTradeSkill( L["Gnomish Universal Remote"], 125, L["Vendor"] );
	addTradeSkill( L["Small Blue Rocket"], 125, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Small Green Rocket"], 125, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Small Red Rocket"], 125, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Silver-plated Shotgun"], 130, L["Trainer"] );
	addTradeSkill( L["Ornate Spyglass"], 135, L["Trainer"] );
	addTradeSkill( L["Big Bronze Bomb"], 140, L["Trainer"] );
	addTradeSkill( L["Minor Recombobulator"], 140, L["Vendor"] );
	addTradeSkill( L["Bronze Framework"], 140, L["Trainer"] );
	addTradeSkill( L["Moonsight Rifle"], 145, L["UWD"] );
	addTradeSkill( L["Explosive Sheep"], 150, L["Trainer"] );
	addTradeSkill( L["Green Tinted Goggles"], 150, L["Trainer"] );
	addTradeSkill( L["Aquadynamic Fish Attractor"], 150, L["Trainer"] );
	addTradeSkill( L["Gold Power Core"], 150, L["Trainer"] );
	addTradeSkill( L["Red Firework"], 150, L["Vendor"] );
	addTradeSkill( L["Green Firework"], 150, L["Vendor"] );
	addTradeSkill( L["Blue Firework"], 150, L["Vendor"] );
	addTradeSkill( L["Ice Deflector"], 155, L["Vendor"] );
	addTradeSkill( L["Iron Strut"], 160, L["Trainer"] );
	addTradeSkill( L["Discombobulator Ray"], 160, L["Discombobulator Ray Obt"] );
	addTradeSkill( L["Portable Bronze Mortar"], 165, L["UWD"] );
	addTradeSkill( L["Goblin Jumper Cables"], 165, L["Vendor"] );
	addTradeSkill( L["Gyrochronatom"], 170, L["Trainer"] );
	addTradeSkill( L["Iron Grenade"], 175, L["Trainer"] );
	addTradeSkill( L["Compact Harvest Reaper Kit"], 175, L["Trainer"] );
	addTradeSkill( L["Solid Blasting Powder"], 175, L["Trainer"] );
	addTradeSkill( L["Solid Dynamite"], 175, L["Trainer"] );
	addTradeSkill( L["Bright-Eye Goggles"], 175, L["UWD"] );
	addTradeSkill( L["Gyromatic Micro-Adjustor"], 175, L["Trainer"] );
	addTradeSkill( L["Large Blue Rocket"], 175, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Large Green Rocket"], 175, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Large Red Rocket"], 175, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Accurate Scope"], 180, L["Vendor"] );
	addTradeSkill( L["Advanced Target Dummy"], 185, L["Trainer"] );
	addTradeSkill( L["Craftsman's Monocle"], 185, L["UWD"]  );
	addTradeSkill( L["Flash Bomb"], 185, L["Flash Bomb Obt"] );
	addTradeSkill( L["Big Iron Bomb"], 190, L["Trainer"] );
	addTradeSkill( L["SnowMaster 9000"], 190, L["WintersVeil"], L["Seasonal"] );
	addTradeSkill( L["Goblin Land Mine"], 195, L["UWD"] );
	addTradeSkill( L["Mithril Tube"], 195, L["Trainer"] );
	addTradeSkill( L["Mechanical Dragonling"], 200, L["Vendor"] );
	addTradeSkill( L["Gnomish Cloaking Device"], 200, L["Vendor"] );
	addTradeSkill( L["Large Seaforium Charge"], 200, L["UWD"] );
	addTradeSkill( L["Unstable Trigger"], 200, L["Trainer"] );
	addTradeSkill( L["Mechanical Repair Kit"], 200, L["Trainer"] );
	addTradeSkill( L["Inlaid Mithril Cylinder Plans"], 200, L["Trainer"] );
	addTradeSkill( L["EZ-Thro Dynamite II"], 200, L["Vendor"] );
	addTradeSkill( L["Fire Goggles"], 205, L["Trainer"] );
	addTradeSkill( L["Mithril Blunderbuss"], 205, L["Trainer"] );
	addTradeSkill( L["Hi-Impact Mithril Slugs"], 210, L["Trainer"] );
	addTradeSkill( L["Deadly Scope"], 210, L["Vendor"] );
	addTradeSkill( L["Mithril Casing"], 215, L["Trainer"] );
	addTradeSkill( L["Mithril Frag Bomb"], 215, L["Trainer"] );
	addTradeSkill( L["Catseye Ultra Goggles"], 220, L["UWD"] );
	addTradeSkill( L["Mithril Heavy-bore Rifle"], 220, L["UWD"] );
	addTradeSkill( L["Goblin Rocket Boots"], 225, L["Trainer"] );
	addTradeSkill( L["Spellpower Goggles Xtreme"], 225, L["UWD"] );
	addTradeSkill( L["Parachute Cloak"], 225, L["UWD"] );
	addTradeSkill( L["Blue Rocket Cluster"], 225, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Green Rocket Cluster"], 225, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Red Rocket Cluster"], 225, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Firework Launcher"], 225, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Deepdive Helmet"], 230, L["Vendor"] );
	addTradeSkill( L["Rose Colored Goggles"], 230, L["Trainer"] );
	addTradeSkill( L["Hi-Explosive Bomb"], 235, L["Trainer"] );
	addTradeSkill( L["Sniper Scope"], 240, L["UWD"] );
	addTradeSkill( L["Mithril Gyro-Shot"], 245, L["Trainer"] );
	addTradeSkill( L["Green Lens"], 245, L["Trainer"] );
	addTradeSkill( L["Mithril Mechanical Dragonling"], 250, L["Vendor"] );
	addTradeSkill( L["Salt Shaker"], 250, L["Trainer"] );
	addTradeSkill( L["Dense Blasting Powder"], 250, L["Trainer"] );
	addTradeSkill( L["Dense Dynamite"], 250, L["Trainer"] );
	addTradeSkill( L["Snake Burst Firework"], 250, L["Vendor"] );
	addTradeSkill( L["Tranquil Mechanical Yeti"], 250, L["Trainer"] );
	addTradeSkill( L["Thorium Grenade"], 260, L["Vendor"] );
	addTradeSkill( L["Thorium Rifle"], 260, L["UWD"] );
	addTradeSkill( L["Thorium Widget"], 260, L["Vendor"] );
	addTradeSkill( L["Truesilver Transformer"], 260, L["Vendor"] );
	addTradeSkill( L["Gyrofreeze Ice Reflector"], 260, L["Vendor"] );
	addTradeSkill( L["Lifelike Mechanical Toad"], 265, L["UWD"] );
	addTradeSkill( L["Spellpower Goggles Xtreme Plus"], 270, L["Spellpower Goggles Xtreme Plus Obt"] );
	addTradeSkill( L["Dark Iron Rifle"], 275, L["Dark Iron Rifle Obt"] );
	addTradeSkill( L["Masterwork Target Dummy"], 275, L["Vendor"] );
	addTradeSkill( L["Thorium Tube"], 275, L["Vendor"] );
	addTradeSkill( L["Major Recombobulator"], 275, L["Major Recombobulator Obt"] );
	addTradeSkill( L["Powerful Seaforium Charge"], 275, L["Vendor"] );
	addTradeSkill( L["Large Blue Rocket Cluster"], 275, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Large Green Rocket Cluster"], 275, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Large Red Rocket Cluster"], 275, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Firework Cluster Launcher"], 275, L["Lunar Festival"], L["Seasonal"] );
	addTradeSkill( L["Steam Tonk Controller"], 275 );
	addTradeSkill( L["Delicate Arcanite Converter"], 285, L["Vendor"] );
	addTradeSkill( L["Dark Iron Bomb"], 285, L["Dark Iron Bomb Obt"] );
	addTradeSkill( L["Thorium Shells"], 285, L["UWD"] );
	addTradeSkill( L["Voice Amplification Modulator"], 290, L["Voice Amplification Modulator Obt"] );
	addTradeSkill( L["Master Engineer's Goggles"], 290, L["Master Engineer's Goggles Obt"] );
	addTradeSkill( L["Hyper-Radiant Flame Reflector"], 290, L["Hyper-Radiant Flame Reflector Pbt"] );
	addTradeSkill( L["Arcane Bomb"], 300, L["UWD"] );
	addTradeSkill( L["Arcanite Dragonling"], 300, L["Arcanite Dragonling Obt"] );
	addTradeSkill( L["Flawless Arcanite Rifle"], 300, L["Flawless Arcanite Rifle Obt"] );
	addTradeSkill( L["Field Repair Bot 74A"], 300, L["Field Repair Bot 74A Obt"] );
	addTradeSkill( L["Biznicks 247x128 Accurascope"], 300, L["Biznicks 247x128 Accurascope Obt"], L["Raid"] );
	addTradeSkill( L["Core Marksman Rifle"], 300, L["Core Marksman Rifle Obt"], L["Raid"] );
	addTradeSkill( L["Force Reactive Disk"], 300, L["Force Reactive Disk Obt"], L["Raid"] );
	addTradeSkill( L["Ultra-Flash Shadow Reflector"], 300, L["Ultra-Flash Shadow Reflector Obt"] );
	addTradeSkill( L["Bloodvine Goggles"], 300, ("%s: %s"):format( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"]  );
	addTradeSkill( L["Bloodvine Lens"], 300, ("%s: %s"):format( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] );

	addTradeSkill( L["Lil' Smoky"], 205, L["ENG_MEMBERSHIP_BENEFITS"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Shrink Ray"], 205, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Goggles"], 210, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Net-o-Matic Projector"], 210, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Harm Prevention Belt"], 215, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Rocket Boots"], 225, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Battle Chicken"], 230, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Mind Control Cap"], 235, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Death Ray"], 240, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["World Enlarger"], 260, L["World Enlarger Obt"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Ultrasafe Transporter - Gadgetzan"], 260, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Alarm-O-Bot"], 265, L["Alarm-O-Bot Obt"], BTS["Gnomish Engineering"] );

	addTradeSkill( L["Goblin Construction Helmet"], 205, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Mining Helmet"], 205, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Pet Bombling"], 205, L["ENG_MEMBERSHIP_BENEFITS"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Mortar"], 205, "Goblin",  L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["The Mortar: Reloaded"], 205, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Sapper Charge"], 205, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Rocket Boots"], 225, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Bomb Dispenser"], 230, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["The Big One"], 235,  L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Rocket Helmet"], 245, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Dimensional Ripper - Everlook"], 260,  L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Jumper Cables XL"], 265, L["Goblin Jumper Cables XL Obt"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Rocket Fuel Recipe"], 205, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Goblin Dragon Gun"], 240, L["Trainer"], BTS["Goblin Engineering"] );

	-- Burning Crusade Recipes
	addTradeSkill( L["Fel Iron Bomb"], 300, L["Trainer"] );
	addTradeSkill( L["Fel Iron Casing"], 300, L["Trainer"] );
	addTradeSkill( L["Elemental Blasting Powder"], 300, L["Trainer"] );
	addTradeSkill( L["Handful of Fel Iron Bolts"], 300, L["Trainer"] );
	addTradeSkill( L["Zapthrottle Mote Extractor"], 305, L["Zapthrottle Mote Extractor Obt"] );
	addTradeSkill( L["Fel Iron Shells"], 310, L["Trainer"] );
	addTradeSkill( L["Fel Iron Musket"], 320, L["Trainer"] );
	addTradeSkill( L["Fel Iron Toolbox"], 325, L["Vendor"] );
	addTradeSkill( L["Gnomish Flame Turret"], 325, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Crashin' Thrashin' Robot"], 325, L["UWD"] );
	addTradeSkill( L["Adamantite Frame"], 325, L["Trainer"] );
	addTradeSkill( L["The Bigger One"], 325, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Adamantite Grenade"], 325, L["Trainer"] );
	addTradeSkill( L["Healing Potion Injector"], 330, L["UWD"] );
	addTradeSkill( L["Adamantite Scope"], 335, L["Vendor"] );
	addTradeSkill( L["White Smoke Flare"], 335, L["Vendor"] );
	addTradeSkill( L["Green Smoke Flare"], 335, ("%s: %s"):format( BFAC["Friendly"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] );
	addTradeSkill( L["Adamantite Shells"], 335, L["Vendor"] );
	addTradeSkill( L["Purple Smoke Flare"], 335, L["UWD"] );
	addTradeSkill( L["Super Sapper Charge"], 340, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Cogspinner Goggles"], 340, L["Vendor"] );
	addTradeSkill( L["Power Amplification Goggles"], 340, L["UWD"] );
	addTradeSkill( L["Gnomish Poultryizer"], 340, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Mana Potion Injector"], 345, L["UWD"] );
	addTradeSkill( L["Adamantite Rifle"], 350, L["Vendor"] );
	addTradeSkill( L["Goblin Rocket Launcher"], 350, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Ultra-Spectropic Detection Goggles"], 350, L["Vendor"] );
	addTradeSkill( L["Khorium Power Core"], 350, L["Trainer"] );
	addTradeSkill( L["Felsteel Stabilizer"], 350, L["Trainer"] );
	addTradeSkill( L["Hardened Adamantite Tube"], 350, L["Trainer"] );
	addTradeSkill( L["Dimensional Ripper - Area 52"], 350, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Ultrasafe Transporter - Toshley's Station"], 260, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Rocket Boots Xtreme"], 355, L["Rocket Boots Xtreme Obt"] );
	addTradeSkill( L["Felsteel Boomstick"], 360, L["Felsteel Boomstick Obt"] );
	addTradeSkill( L["Hyper-Vision Goggles"], 360, L["Hyper-Vision Goggles Obt"] );
	addTradeSkill( L["Khorium Scope"], 360, L["Khorium Scope Obt"] );
	addTradeSkill( L["Foreman's Enchanted Helmet"], 375, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Foreman's Reinforced Helmet"], 375, L["Trainer"], BTS["Goblin Engineering"] );
	addTradeSkill( L["Gnomish Battle Goggles"], 375, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Gnomish Power Goggles"], 375, L["Trainer"], BTS["Gnomish Engineering"] );
	addTradeSkill( L["Ornate Khorium Rifle"], 375, L["UWD"] );
	addTradeSkill( L["Stabilized Eternium Scope"], 375, L["Stabilized Eternium Scope Obt"], L["Raid"] );

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all First Aid recipes.  As of 2.2 there are 15 recipes.

local function ARL_InitFirstAid()
  
	ARL_InitializeRecipeArray();
  
	-- Original Game Recipes
	addTradeSkill( L["Linen Bandage"], 1, L["Trainer"]);
	addTradeSkill( L["Heavy Linen Bandage"], 40, L["Trainer"]);
	addTradeSkill( L["Wool Bandage"], 80, L["Trainer"]);
	addTradeSkill( L["Anti-Venom"], 80, L["Trainer"]);
	addTradeSkill( L["Heavy Wool Bandage"], 115, L["Trainer"]);
	addTradeSkill( L["Strong Anti-Venom"], 130, L["UWD"]);
	addTradeSkill( L["Silk Bandage"], 150, L["Trainer"]);
	addTradeSkill( L["Heavy Silk Bandage"], 180, L["Vendor"] );
	addTradeSkill( L["Mageweave Bandage"], 210, L["Vendor"] );
	addTradeSkill( L["Heavy Mageweave Bandage"], 240, L["Trainer"]);
	addTradeSkill( L["Runecloth Bandage"], 260, L["Trainer"]);
	addTradeSkill( L["Heavy Runecloth Bandage"], 290, L["Trainer"]);
	addTradeSkill( L["Powerful Anti-Venom"], 300, ("%s: %s"):format( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"]);

	-- Burning Crusade Recipes
	addTradeSkill( L["Netherweave Bandage"], 330, L["Vendor"] );
	addTradeSkill( L["Heavy Netherweave Bandage"], 360, L["Vendor"] );

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Jewelcrafting recipes.  As of 2.2 there are

local function ARL_InitJewelcrafting()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Delicate Copper Wire", 1, L["Trainer"] );
	addTradeSkill( "Braided Copper Ring", 1, L["Trainer"] );
	addTradeSkill( "Woven Copper Ring", 1, L["Trainer"] );
	addTradeSkill( "Rough Stone Statue", 1, L["Trainer"] );
	addTradeSkill( "Heavy Copper Ring", 5, L["Trainer"] );
	addTradeSkill( "Malachite Pendant", 20, L["Trainer"] );
	addTradeSkill( "Tigerseye Band", 20, L["Trainer"] );
	addTradeSkill( "Inlaid Malachite Ring", 30, L["Trainer"] );
	addTradeSkill( "Ornate Tigerseye Necklace", 30, L["Trainer"] );
	addTradeSkill( "Bronze Setting", 50, L["Trainer"] );
	addTradeSkill( "Elegant Silver Ring", 50, L["Trainer"] );
	addTradeSkill( "Solid Bronze Ring", 50, L["Trainer"] );
	addTradeSkill( "Thick Bronze Necklace", 50, L["Trainer"] );
	addTradeSkill( "Coarse Stone Statue", 50, L["Trainer"] );
	addTradeSkill( "Simple Pearl Ring", 60, L["Trainer"] );
	addTradeSkill( "Bronze Band of Force", 65, L["Trainer"] );
	addTradeSkill( "Gloom Band", 70, L["Trainer"] );
	addTradeSkill( "Brilliant Necklace", 75, L["Trainer"] );
	addTradeSkill( "Bronze Torc", 80, L["Trainer"] );
	addTradeSkill( "Heavy Silver Ring", 90, L["Trainer"] );
	addTradeSkill( "Ring of Silver Might", 100, L["Trainer"] );
	addTradeSkill( "Ring of Twilight Shadows", 100, L["Trainer"] );
	addTradeSkill( "Heavy Jade Ring", 105, L["Trainer"] );
	addTradeSkill( "Amulet of the Moon", 110, L["Vendor"] );
	addTradeSkill( "Barbaric Iron Collar", 110, L["Trainer"] );
	addTradeSkill( "Heavy Stone Statue", 110, L["Trainer"] );
	addTradeSkill( "Moonsoul Crown", 120, L["Trainer"] );
	addTradeSkill( "Pendant of the Agate Shield", 120, L["Vendor"] );
	addTradeSkill( "Wicked Moonstone Ring", 125, L["Vendor"] );
	addTradeSkill( "Heavy Iron Knuckles", 125, L["Vendor"] );
	addTradeSkill( "Golden Dragon Ring", 135, L["Trainer"] );
	addTradeSkill( "Heavy Golden Necklace of Battle", 150, L["Vendor"] );
	addTradeSkill( "Mithril Filigree", 150, L["Trainer"] );
	addTradeSkill( "Blazing Citrine Ring", 150, L["Vendor"] );
	addTradeSkill( "Jade Pendant of Blasting", 160, L["UWD"] );
	addTradeSkill( "The Jade Eye", 170, L["Vendor"] );
	addTradeSkill( "Engraved Truesilver Ring", 170, L["Trainer"] );
	addTradeSkill( "Solid Stone Statue", 175, L["Trainer"] );
	addTradeSkill( "Citrine Ring of Rapid Healing", 180, L["Trainer"] );
	addTradeSkill( "Golden Ring of Power", 180, L["Trainer"] );
	addTradeSkill( "Citrine Pendant of Golden Healing", 190, L["UWD"] );
	addTradeSkill( "Figurine - Jade Owl", 200, L["Trainer"] );
	addTradeSkill( "Figurine - Golden Hare", 200, L["UWD"] );
	addTradeSkill( "Truesilver Commander's Ring", 200, L["Trainer"] );
	addTradeSkill( "Aquamarine Signet", 210, L["Trainer"] );
	addTradeSkill( "Figurine - Black Pearl Panther", 215, L["Vendor"] );
	addTradeSkill( "Aquamarine Pendant of the Warrior", 220, L["Trainer"] );
	addTradeSkill( "Ruby Crown of Restoration", 225, L["Vendor"] );
	addTradeSkill( "Thorium Setting", 225, L["Trainer"] );
	addTradeSkill( "Figurine - Truesilver Crab", 225, L["Vendor"] );
	addTradeSkill( "Dense Stone Statue", 225, L["Trainer"] );
	addTradeSkill( "Figurine - Truesilver Boar", 230, L["UWD"] );
	addTradeSkill( "Red Ring of Destruction", 230, L["Trainer"] );
	addTradeSkill( "Ruby Pendant of Fire", 235, L["Trainer"] );
	addTradeSkill( "Truesilver Healing Ring", 240, L["Trainer"] );
	addTradeSkill( "The Aquamarine Ward", 245, L["UWD"] );
	addTradeSkill( "Gem Studded Band", 250, L["UWD"] );
	addTradeSkill( "Opal Necklace of Impact", 250, L["Vendor"] );
	addTradeSkill( "Figurine - Ruby Serpent", 260, L["UWD"] );
	addTradeSkill( "Simple Opal Ring", 260, L["Trainer"] );
	addTradeSkill( "Diamond Focus Ring", 275, L["Trainer"] );
	addTradeSkill( "Sapphire Signet", 275, L["Trainer"] );
	addTradeSkill( "Emerald Crown of Destruction", 275, L["Vendor"] );
	addTradeSkill( "Onslaught Ring", 280, L["Trainer"] );
	addTradeSkill( "Sapphire Pendant of Winter Night", 280, L["Trainer"] );
	addTradeSkill( "Glowing Thorium Band", 280, L["Trainer"] );
	addTradeSkill( "Figurine - Emerald Owl", 285, "World Drop" );
	addTradeSkill( "Ring of Bitter Shadows", 285, L["Vendor"] );
	addTradeSkill( "Living Emerald Pendant", 290, L["Trainer"] );
	addTradeSkill( "Emerald Lion Ring", 290, L["Trainer"] );
	addTradeSkill( "Figurine - Black Diamond Crab", 300, L["UWD"] );
	addTradeSkill( "Figurine - Dark Iron Scorpid", 300, L["UWD"] );
	addTradeSkill( "Teardrop Blood Garnet", 300, L["Vendor"] );
	addTradeSkill( "Inscribed Flame Spessarite", 300, L["Vendor"] );
	addTradeSkill( "Radiant Deep Peridot", 300, L["Vendor"] );
	addTradeSkill( "Glowing Shadow Draenite", 300, L["Vendor"] );
	addTradeSkill( "Brilliant Golden Draenite", 300, L["Vendor"] );
	addTradeSkill( "Solid Azure Moonstone", 300, L["Vendor"] );
	addTradeSkill( "Necklace of the Diamond Tower", 305, L["Vendor"] );
	addTradeSkill( "Bold Blood Garnet", 305, L["Vendor"] );
	addTradeSkill( "Luminous Flame Spessarite", 305, "You can purchase this recipe from Karaaz in Netherstorm when you are friendly with The Consortium" );
	addTradeSkill( "Jagged Deep Peridot", 305, L["Vendor"] );
	addTradeSkill( "Royal Shadow Draenite", 305, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Gleaming Golden Draenite", 305, "You can purchase this from Quartermaster Endarin in Shattrath City when you are friendly with Aldor" );
	addTradeSkill( "Sparkling Azure Moonstone", 305, L["Vendor"] );
	addTradeSkill( "Bright Blood Garnet", 305, L["Vendor"] );
	addTradeSkill( "Band of Natural Fire", 310, L["Trainer"] );
	addTradeSkill( "Fel Iron Blood Ring", 310, L["Trainer"] );
	addTradeSkill( "Golden Draenite Ring", 310, L["Trainer"] );
	addTradeSkill( "Runed Blood Garnet", 315, "You can buy this from Quartermaster Enuril in Shattrath when you are friendly with Scryers" );
	addTradeSkill( "Glinting Flame Spessarite", 315, L["Vendor"] );
	addTradeSkill( "Enduring Deep Peridot", 315, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are friendly with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are friendly with Thrallmar" );
	addTradeSkill( "Thick Golden Draenite", 315, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Stormy Azure Moonstone", 315, L["UWD"] );
	addTradeSkill( "Azure Moonstone Ring", 320, L["Trainer"] );
	addTradeSkill( "Delicate Blood Garnet", 325, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Potent Flame Spessarite", 325, "You can buy this from Nakodu in Shattrath City when you are honored with Lower City" );
	addTradeSkill( "Dazzling Deep Peridot", 325, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Shifting Shadow Draenite", 325, "You can purchase this recipe from Karaaz in Netherstorm when you are friendly with The Consortium" );
  --addTrade( "Sovereign Shadow Draenite", 325, L["Vendor"] ); the correct spelling
	addTradeSkill( "Soveriegn Shadow Draenite", 325, L["Vendor"] ); -- the bliz spelling
	addTradeSkill( "Rigid Golden Draenite", 325, L["Vendor"] );
	addTradeSkill( "Lustrous Azure Moonstone", 325, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Smooth Golden Draenite", 325, L["Vendor"] );
	addTradeSkill( "Mercurial Adamantite", 325, L["Trainer"] );
	addTradeSkill( "Heavy Adamantite Ring", 335, L["Trainer"] );
	addTradeSkill( "Thick Adamantite Necklace", 335, L["Trainer"] );
	addTradeSkill( "Heavy Felsteel Ring", 345, L["UWD"] );
	addTradeSkill( "Bright Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Brilliant Dawnstone", 350, L["UWD"] );
	addTradeSkill( "Dazzling Talasite", 350, L["UWD"] );
	addTradeSkill( "Delicate Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Enduring Talasite", 350, L["UWD"] );
	addTradeSkill( "Inscribed Noble Topaz", 350, L["UWD"] );
	addTradeSkill( "Flashing Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Gleaming Dawnstone", 350, L["UWD"] );
	addTradeSkill( "Glinting Noble Topaz", 350, L["UWD"] );
	addTradeSkill( "Glowing Nightseye", 350, L["UWD"] );
	addTradeSkill( "Jagged Talasite", 350, L["UWD"] );
	addTradeSkill( "Luminous Noble Topaz", 350, L["UWD"] );
	addTradeSkill( "Lustrous Star of Elune", 350, L["UWD"] );
	addTradeSkill( "Potent Noble Topaz", 350, L["UWD"] );
	addTradeSkill( "Radiant Talasite", 350, L["UWD"] );
	addTradeSkill( "Rigid Dawnstone", 350, L["UWD"] );
	addTradeSkill( "Royal Nightseye", 350, L["UWD"] );
	addTradeSkill( "Runed Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Shifting Nightseye", 350, L["UWD"] );
	addTradeSkill( "Smooth Dawnstone", 350, L["UWD"] );
	addTradeSkill( "Sovereign Nightseye", 350, L["UWD"] );
	addTradeSkill( "Solid Star of Elune", 350, L["UWD"] );
	addTradeSkill( "Sparkling Star of Elune", 350, L["UWD"] );
	addTradeSkill( "Stormy Star of Elune", 350, L["UWD"] );
	addTradeSkill( "Subtle Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Teardrop Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Thick Dawnstone", 350, L["UWD"] );
	addTradeSkill( "Bold Living Ruby", 350, L["UWD"] );
	addTradeSkill( "Khorium Band of Shadows", 350, "BoP mob drop from Dark Conclave Shadowmancers in Shadowmoon Valley.  Only drops for jewelcrafters" );
	addTradeSkill( "Khorium Band of Frost", 355, "BoP mob drop from Coilfang Sorceresses in The Steamvault" );
	addTradeSkill( "Khorium Inferno Band", 355, "BoP mob drop from Darkweaver Syth in Sethekk Halls" );
	addTradeSkill( "Delicate Eternium Ring", 355, L["UWD"] );
	addTradeSkill( "Thick Felsteel Necklace", 355, L["UWD"] );
	addTradeSkill( "Living Ruby Pendant", 355, L["UWD"] );
	addTradeSkill( "Khorium Band of Leaves", 360, "BoP mob drop from Vekh'nir Dreadhawks in Blade's Edge Mountains" );
	addTradeSkill( "Pendant of Frozen Flame", 360, "You can buy this from Alurmi in Tanaris when you are revered with Keepers of Time" );
	addTradeSkill( "Pendant of Thawing", 360, "You can buy this from Nakodu in Shattrath City when you are revered with Lower City" );
	addTradeSkill( "Pendant of Withering", 360, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Pendant of Shadow's End", 360, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Pendant of the Null Rune", 360, "You can purchase this recipe from Karaaz in Netherstorm when you are revered with The Consortium" );
	addTradeSkill( "Braided Eternium Chain", 360, "World Drop (Buy on HA)" );
	addTradeSkill( "Eye of the Night", 360, "World Drop (Buy on HA)" );
	addTradeSkill( "Ring of Arcane Shielding", 360, "You can buy this from Almaador in Shattrath when you are honored with The Sha'tar" );
	addTradeSkill( "Arcane Khorium Band", 365, "BoP mob drop from Mageslayers in Netherstorm" );
	addTradeSkill( "Blazing Eternium Band", 365, L["UWD"] );
	addTradeSkill( "Embrace of the Dawn", 365, L["UWD"] );
	addTradeSkill( "Chain of the Twilight Owl", 365, L["UWD"] );
	addTradeSkill( "Bracing Earthstorm Diamond", 365, "You can purchase this recipe from Karaaz in Netherstorm when you are revered with The Consortium" );
	addTradeSkill( "Brutal Earthstorm Diamond", 365, L["UWD"] );
	addTradeSkill( "Insightful Earthstorm Diamond", 365, "You can buy this from Almaador in Shattrath when you are friendly with The Sha'tar" );
	addTradeSkill( "Powerful Earthstorm Diamond", 365, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Tenacious Earthstorm Diamond", 365, L["UWD"] );
	addTradeSkill( "Destructive Skyfire Diamond", 365, L["UWD"] );
	addTradeSkill( "Enigmatic Skyfire Diamond", 365, "You can buy this from Alurmi in Tanaris when you are honored with Keepers of Time" );
	addTradeSkill( "Mystical Skyfire Diamond", 365, L["UWD"] );
	addTradeSkill( "Swift Skyfire Diamond", 365, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Coronet of the Verdant Flame", 370, "BoP mob drop from Sunseeker Botanists in The Botanica" );
	addTradeSkill( "Circlet of Arcane Might", 370, "BoP mob drop from Epoch Hunter in Old Hillsbrad Foothills" );
	addTradeSkill( "Figurine - Felsteel Boar", 370, "You can buy this from Nakodu in Shattrath City when you are revered with Lower City" );
	addTradeSkill( "Figurine - Dawnstone Crab", 370, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are revered with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are revered with Thrallmar" );
	addTradeSkill( "Figurine - Living Ruby Serpent", 370, "You can buy this from Alurmi in Tanaris when you are revered with Keepers of Time" );
	addTradeSkill( "Figurine - Talasite Owl", 370, "You can buy this from Almaador in Shattrath when you are revered with The Sha'tar" );
	addTradeSkill( "Figurine - Nightseye Panther", 370, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are revered with Cenarion Expedition" );
	addTradeSkill( "The Frozen Eye", 375, "You can purchase this from Koren in Karazhan when you are honored with The Violet Eye" );
	addTradeSkill( "The Natural Ward", 375, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	
end

-- Initializes the array adding all LeatherWorking recipes.  As of 2.2 there are

local function ARL_InitLeatherWorking()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Handstitched Leather Boots", 1, L["Trainer"] );
	addTradeSkill( "Light Armor Kit", 1, L["Trainer"] );
	addTradeSkill( "Light Leather", 1, L["Trainer"] );
	addTradeSkill( "Handstitched Leather Vest", 1, L["Trainer"] );
	addTradeSkill( "Handstitched Leather Cloak", 1, L["Trainer"] );
	addTradeSkill( "Handstitched Leather Bracers", 1, L["Trainer"] );
	addTradeSkill( "Handstitched Leather Pants", 15, L["Trainer"] );
	addTradeSkill( "Handstitched Leather Belt", 25, L["Trainer"] );
	addTradeSkill( "Light Leather Quiver", 30, L["Trainer"] );
	addTradeSkill( "Small Leather Ammo Pouch", 30, L["Trainer"] );
	addTradeSkill( "Cured Light Hide", 35, L["Trainer"] );
	addTradeSkill( "Rugged Leather Pants", 35, L["UWD"] );
	addTradeSkill( "Kodo Hide Bag", 40, "Reward from quest (Kodo Hide Bag) obtained from Veren Tallstrider in Thunder Bluff", BFAC["Horde"] );
	addTradeSkill( "Embossed Leather Vest", 40, L["Trainer"] );
	addTradeSkill( "Embossed Leather Gloves", 55, L["Trainer"] );
	addTradeSkill( "Embossed Leather Boots", 55, L["Trainer"] );
	addTradeSkill( "Embossed Leather Cloak", 60, L["Trainer"] );
	addTradeSkill( "White Leather Jerkin", 60, L["UWD"] );
	addTradeSkill( "Embossed Leather Pants", 75, L["Trainer"] );
	addTradeSkill( "Fine Leather Gloves", 75, L["UWD"] );
	addTradeSkill( "Fine Leather Belt", 80, L["Trainer"] );
	addTradeSkill( "Fine Leather Cloak", 85, L["Trainer"] );
	addTradeSkill( "Fine Leather Tunic", 85, L["Trainer"] );
	addTradeSkill( "Murloc Scale Belt", 90, L["Vendor"] );
	addTradeSkill( "Deviate Scale Cloak", 90, L["Vendor"] );
	addTradeSkill( "Moonglow Vest", 90, "Reward from quest (Moonglow Vest) obtained from Lotherias in Darnassus", BFAC["Alliance"] );
	addTradeSkill( "Fine Leather Boots", 90, L["UWD"] );
	addTradeSkill( "Light Leather Bracers", 70, L["Trainer"] );
	addTradeSkill( "Murloc Scale Breastplate", 95, L["Vendor"] );
	addTradeSkill( "Light Leather Pants", 95, L["Trainer"] );
	addTradeSkill( "Hillman's Leather Vest", 100, L["UWD"] );
	addTradeSkill( "Cured Medium Hide", 100, L["Trainer"] );
	addTradeSkill( "Black Whelp Cloak", 100, L["Vendor"] );
	addTradeSkill( "Medium Leather", 100, L["Trainer"] );
	addTradeSkill( "Black Whelp Tunic", 100, L["Vendor"] );
	addTradeSkill( "Medium Armor Kit", 100, L["Trainer"] );
	addTradeSkill( "Dark Leather Boots", 100, L["Trainer"] );
	addTradeSkill( "Dark Leather Tunic", 100, L["UWD"] );
	addTradeSkill( "Fine Leather Pants", 105, L["UWD"] );
	addTradeSkill( "Deviate Scale Gloves", 105, L["Vendor"] );
	addTradeSkill( "Dark Leather Cloak", 110, L["Trainer"] );
	addTradeSkill( "Dark Leather Pants", 115, L["Trainer"] );
	addTradeSkill( "Deviate Scale Belt", 115, "Reward from quest (Deviate Eradication) obtained from Ebru in The Wailing Caverns" );
	addTradeSkill( "Dark Leather Gloves", 120, L["UWD"] );
	addTradeSkill( "Hillman's Belt", 120, L["UWD"] );
	addTradeSkill( "Red Whelp Gloves", 120, L["Vendor"]);
	addTradeSkill( "Nimble Leather Gloves", 120, L["Trainer"] );
	addTradeSkill( "Toughened Leather Armor", 120, L["Trainer"] );
	addTradeSkill( "Dark Leather Belt", 125, L["Trainer"] );
	addTradeSkill( "Fletcher's Gloves", 125, L["Trainer"] );
	addTradeSkill( "Hillman's Shoulders", 130, L["Trainer"] );
	addTradeSkill( "Toughened Leather Gloves", 135, L["Trainer"] );
	addTradeSkill( "Herbalist's Gloves", 135, L["Vendor"] );
	addTradeSkill( "Earthen Leather Shoulders", 135, L["Vendor"] );
	addTradeSkill( "Dark Leather Shoulders", 140, L["UWD"] );
	addTradeSkill( "Pilferer's Gloves", 140, L["UWD"] );
	addTradeSkill( "Hillman's Leather Gloves", 145, L["Trainer"] );
	addTradeSkill( "Heavy Earthen Gloves", 145, L["UWD"] );
	addTradeSkill( "Hillman's Cloak", 150, L["Trainer"] );
	addTradeSkill( "Barbaric Gloves", 150, L["UWD"] );
	addTradeSkill( "Cured Heavy Hide", 150, L["Trainer"] );
	addTradeSkill( "Heavy Armor Kit", 150, L["Trainer"] );
	addTradeSkill( "Heavy Quiver", 150, L["Trainer"] );
	addTradeSkill( "Heavy Leather Ammo Pouch", 150, L["Trainer"] );
	addTradeSkill( "Heavy Leather", 150, L["Trainer"] );
	addTradeSkill( "Heavy Leather Ball", 150, L["Vendor"] );
	addTradeSkill( "Green Leather Armor", 155, L["Vendor"] );
	addTradeSkill( "Barbaric Bracers", 155, L["Vendor"] );
	addTradeSkill( "Green Leather Belt", 160, L["Trainer"] );
	addTradeSkill( "Guardian Pants", 160, L["Trainer"] );
	addTradeSkill( "Raptor Hide Belt", 165, L["Vendor"] );
	addTradeSkill( "Raptor Hide Harness", 165, "Vendor - horde only" );
	addTradeSkill( "Dusky Leather Leggings", 165, L["UWD"] );
	addTradeSkill( "Guardian Belt", 170, L["UWD"] );
	addTradeSkill( "Thick Murloc Armor", 170, L["Vendor"] );
	addTradeSkill( "Barbaric Leggings", 170, L["Vendor"] );
	addTradeSkill( "Guardian Armor", 175, L["UWD"] );
	addTradeSkill( "Barbaric Shoulders", 175, L["Trainer"] );
	addTradeSkill( "Dusky Leather Armor", 175, L["Trainer"] );
	addTradeSkill( "Green Whelp Armor", 175, L["UWD"] );
	addTradeSkill( "Green Leather Bracers", 180, L["Trainer"] );
	addTradeSkill( "Frost Leather Cloak", 180, L["Trainer"] );
	addTradeSkill( "Gem-studded Leather Belt", 185, L["Vendor"] );
	addTradeSkill( "Guardian Cloak", 185, L["UWD"] );
	addTradeSkill( "Dusky Bracers", 185, L["Trainer"] );
	addTradeSkill( "Barbaric Harness", 190, L["Trainer"] );
	addTradeSkill( "Murloc Scale Bracers", 190, L["Vendor"] );
	addTradeSkill( "Guardian Gloves", 190, L["Trainer"] );
	addTradeSkill( "Green Whelp Bracers", 190, L["Vendor"] );
	addTradeSkill( "Gloves of the Greatfather", 190, "You can get this randomly as a reward from a Feast of Winter Veil quest." );
	addTradeSkill( "Guardian Leather Bracers", 195, L["UWD"] );
	addTradeSkill( "Dusky Belt", 195, L["Trainer"] );
	addTradeSkill( "Barbaric Belt", 200, L["UWD"] );
	addTradeSkill( "Dusky Boots", 200, L["UWD"] );
	addTradeSkill( "Swift Boots", 200, L["UWD"] );
	addTradeSkill( "Cured Thick Hide", 200, L["Trainer"] );
	addTradeSkill( "Thick Armor Kit", 200, L["Trainer"] );
	addTradeSkill( "Comfortable Leather Hat", 200, L["UWD"] );
	addTradeSkill( "Thick Leather", 200, L["Trainer"] );
	addTradeSkill( "Shadowskin Gloves", 200, L["Vendor"] );
	addTradeSkill( "Nightscape Tunic", 205, L["Trainer"] );
	addTradeSkill( "Nightscape Headband", 205, L["Trainer"] );
	addTradeSkill( "Turtle Scale Gloves", 205, L["Vendor"] );
	addTradeSkill( "Turtle Scale Breastplate", 210, L["Trainer"] );
	addTradeSkill( "Nightscape Shoulders", 210, L["Vendor"] );
	addTradeSkill( "Turtle Scale Bracers", 210, L["Trainer"] );
	addTradeSkill( "Big Voodoo Robe", 215 );
	addTradeSkill( "Tough Scorpid Breastplate", 220, "Mob Drop: Wastewander Bandit (Tanaris)" );
	addTradeSkill( "Wild Leather Shoulders", 220, "Reward from quest (Wild Leather Shoulders) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas");
	addTradeSkill( "Big Voodoo Mask", 220, L["UWD"] );
	addTradeSkill( "Tough Scorpid Bracers", 220, "Mob Drop: Wastewander Shadow Mage (Tanaris)" );
	addTradeSkill( "Tough Scorpid Gloves", 225, "Mob Drop: Wastewander Thief (Tanaris)" );
	addTradeSkill( "Wild Leather Vest", 225, "Reward from quest (Wild Leather Vest) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas");
	addTradeSkill( "Wild Leather Helmet", 225, "Reward from quest (Wild Leather Helmet) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas");
	addTradeSkill( "Quickdraw Quiver", 225, L["Trainer"] );
	addTradeSkill( "Thick Leather Ammo Pouch", 225, L["Trainer"] );
	addTradeSkill( "Nightscape Pants", 230, L["Trainer"] );
	addTradeSkill( "Turtle Scale Helm", 230, L["Trainer"] );
	addTradeSkill( "Tough Scorpid Boots", 235, "Mob Drop: Wastewander Rogue (Tanaris)" );
	addTradeSkill( "Turtle Scale Leggings", 235, L["Trainer"] );
	addTradeSkill( "Nightscape Boots", 235, L["Trainer"] );
	addTradeSkill( "Big Voodoo Pants", 240, L["UWD"] );
	addTradeSkill( "Big Voodoo Cloak", 240, L["UWD"] );
	addTradeSkill( "Tough Scorpid Shoulders", 240, "Mob Drop: Andre Firebeard and Wastewander Scofflaw (Tanaris)" );
	addTradeSkill( "Wild Leather Boots", 245, "Reward from quest (Wild Leather Boots) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas" );
	addTradeSkill( "Tough Scorpid Leggings", 245, "Mob Drop: Wastewander Rogue (Tanaris)" );
	addTradeSkill( "Tough Scorpid Helm", 250, "Mob Drop: Andre Firebeard and Wastewander Scofflaw (Tanaris)" );
	addTradeSkill( "Wild Leather Leggings", 250, "Reward from quest (Wild Leather Leggings) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas" );
	addTradeSkill( "Wild Leather Cloak", 250, "Reward from quest (Master of the Wild Leather) obtained from Jangdor Swiftstrider (Horde) and Pratt McGrubben (Alliance) in Feralas" );
	addTradeSkill( "Cured Rugged Hide", 250, L["Trainer"] );
	addTradeSkill( "Rugged Armor Kit", 250, L["Trainer"] );
	addTradeSkill( "Rugged Leather", 250, L["Trainer"] );
	addTradeSkill( "Heavy Scorpid Bracers", 255, L["Vendor"] );
	addTradeSkill( "Wicked Leather Gauntlets", 260, L["Vendor"]);  
	addTradeSkill( "Heavy Scorpid Vest", 265, "Mob Drop: Portal Seeker (Blasted Lands)");
	addTradeSkill( "Wicked Leather Bracers", 265, "Mob Drop: Legashi Rogue (Azshara)");
	addTradeSkill( "Runic Leather Gauntlets", 270, L["UWD"] );
	addTradeSkill( "Heavy Scorpid Gauntlets", 275, L["UWD"] );
	addTradeSkill( "Runic Leather Bracers", 275, "Mob Drop: Jaedenar Cultist (Felwood)" );
	addTradeSkill( "Heavy Scorpid Belt", 280, L["UWD"] );
	addTradeSkill( "Wicked Leather Headband", 280, "Mob Drop: JadefireTrickster (Felwood)" );
	addTradeSkill( "Runic Leather Belt", 280, L["UWD"] );
	addTradeSkill( "Heavy Scorpid Leggings", 285, "Mob Drop: Blackrock Slayer (Blackrock Mountain and Burning Steppes)" );
	addTradeSkill( "Runic Leather Headband", 290, L["Vendor"] );
	addTradeSkill( "Wicked Leather Pants", 290, L["UWD"] );
	addTradeSkill( "Might of the Timbermaw", 290, "You can buy this from Meilosh in Felwood when you are honored with Timbermaw Hold"  );
	addTradeSkill( "Dawn Treaders", 290, "You can buy this from an Argent Dawn Quartermaster when you are honored with Argent Dawn" );
	addTradeSkill( "Heavy Scorpid Helm", 295, L["Vendor"] );
	addTradeSkill( "Runic Leather Pants", 300, L["UWD"] );
	addTradeSkill( "Wicked Leather Belt", 300, "Mob Drop: Ghoul Ravener (Stratholme)" );
	addTradeSkill( "Heavy Scorpid Shoulders", 300, "Mob Drop: Blackrock Battlemaster (Burning Steppes)" );
	addTradeSkill( "Runic Leather Armor", 300, "Mob Drop: Scholomance Dark Summoner (Scholomance)" );
	addTradeSkill( "Wicked Leather Armor", 300, "Mob Drop: Spectral Researcher (Scholomance)" );
	addTradeSkill( "Runic Leather Shoulders", 300, "Mob Drop: Crimson Battle Mage (Stratholme)" );
	addTradeSkill( "Core Armor Kit", 300, "Mob Drop: Molten Core Bosses - binds when picked up" );
	addTradeSkill( "Girdle of Insight", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock, Gordok Bushwacker and Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Mongoose Boots", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock, Gordok Bushwacker and Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Swift Flight Bracers", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock, Gordok Bushwacker and Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Timbermaw Brawlers", 300, "You can buy this from Meilosh in Felwood when you are revered with Timbermaw Hold"  );
	addTradeSkill( "Golden Mantle of the Dawn", 300, "You can buy this from an Argent Dawn Quartermaster when you are revered with Argent Dawn"  );
	addTradeSkill( "Lava Belt", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Blood Tiger Breastplate", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Blood Tiger Shoulders", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Primal Batskin Bracers", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Primal Batskin Gloves", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Primal Batskin Jerkin", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Spitfire Bracers", 300, "You can buy this from Aendel Windspear in Silithus when you are friendly with Cenarion Circle" );
	addTradeSkill( "Spitfire Gauntlets", 300, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle" );
	addTradeSkill( "Spitfire Breastplate", 300, "You can buy this from Aendel Windspear in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Sandstalker Bracers", 300, "You can buy this from Aendel Windspear in Silithus when you are friendly with Cenarion Circle" );
	addTradeSkill( "Sandstalker Gauntlets", 300, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle" );
	addTradeSkill( "Sandstalker Breastplate", 300, "You can buy this from Aendel Windspear in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Onyxia Scale Cloak", 300, "Reward from followup quest (The Journey Has Just Begun) after turning in Head of Onyxia" );


	addTradeSkill( "Gordok Ogre Suit", 300, "Can learn recipe after completing quest (The Gordok Ogre Suit) obtained from Knot Thimblejack from Dire Maul" );
	addTradeSkill( "Icy Scale Bracers", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Icy Scale Breastplate", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Icy Scale Gauntlets", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Polar Bracers", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Polar Gloves", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Polar Tunic", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Bramblewood Belt", 300, "You can buy this from Aendel Windspear in Silithus when you are friendly with Cenarion Circle"  );
	addTradeSkill( "Bramblewood Boots", 300, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle"  );
	addTradeSkill( "Bramblewood Helm", 300, "You can buy this from Aendel Windspear in Silithus when you are revered with Cenarion Circle" );

	addTradeSkill( "Green Dragonscale Gauntlets", 280, L["Trainer"] );
	addTradeSkill( "Dragonscale Gauntlets", 225, L["Trainer"] );
	addTradeSkill( "Dragonscale Breastplate", 255, L["Trainer"] );
	addTradeSkill( "Green Dragonscale Breastplate", 260, L["Vendor"] );
	addTradeSkill( "Dragonstrike Leggings", 260, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Blackstorm Leggings", 260, "Elemental", L["Trainer"] );
	addTradeSkill( "Wildfeather Leggings", 260, "Tribal", L["Trainer"] );

	addTradeSkill( "Green Dragonscale Leggings" , 270, "Mob Drop: Murk Worm (The Temple of Atal'Hakkar)" );
	addTradeSkill( "Blue Dragonscale Breastplate", 285, L["Vendor"] );
	addTradeSkill( "Black Dragonscale Breastplate", 290, L["Vendor"] );
	addTradeSkill( "Blue Dragonscale Shoulders", 295, "Mob Drop: Cliff Breaker (Azshara)" );
	addTradeSkill( "Red Dragonscale Breastplate", 300, "Mob Drop: General Drakkisath (Hall of Blackhand)" );
	addTradeSkill( "Black Dragonscale Leggings", 300, "Mob Drop: Anvilrage Captain (Blackrock Depths)" );
	addTradeSkill( "Black Dragonscale Shoulders", 300, "Mob Drop : Anvilrage Captain (Blackrock Depths)" );
	addTradeSkill( "Black Dragonscale Boots", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Chromatic Cloak", 300, "Knot Thimblejack's Cache (Dire Maul)" );
	addTradeSkill( "Chromatic Gauntlets", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Blue Dragonscale Leggings", 300, L["Trainer"] );
	addTradeSkill( "Dreamscale Breastplate", 300, "You can buy this from Aendel Windspear in Silithus when you are exalted with Cenarion Circle"  );

	addTradeSkill( "Gauntlets of the Sea", 230, L["Trainer"] );
	addTradeSkill( "Helm of Fire", 250, L["Trainer"] );
	addTradeSkill( "Volcanic Leggings", 270, "Mob Drop: Firegut Brute (Burning Steppes)" );
	addTradeSkill( "Living Shoulders", 270, L["Vendor"] );
	addTradeSkill( "Stormshroud Pants", 275, L["Vendor"] );
	addTradeSkill( "Volcanic Breastplate", 285, "Mob Drop: Firebrand Grunt (Hall of Blackhand)" );
	addTradeSkill( "Living Leggings", 285, "Mob Drop: Deadwood Shaman (Felwood)" );
	addTradeSkill( "Stormshroud Armor", 285, "Mob Drop: Arkkoran Oracle (Azshara)" );
	addTradeSkill( "Stormshroud Shoulders", 295, "Son or Arkkoroc (Azshara)" );
	addTradeSkill( "Stormshroud Gloves", 300, "Mob Drop: The Windreaver (Silithus), Princess Tempestria (Winterspring)" );
	addTradeSkill( "Living Breastplate", 300, "Mob Drop: Decaying Horror (Western Plaguelands)" );
	addTradeSkill( "Volcanic Shoulders", 300, "Mob Drop: Firebrand Legionnaire (Hall of Blackhand)" );
	addTradeSkill( "Molten Helm", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are friendly with Thorium Brotherhood" );
	addTradeSkill( "Shifting Cloak", 300, "Knot Thimblejack's Cache (Dire Maul)" );
	addTradeSkill( "Molten Belt", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );

	addTradeSkill( "Wolfshead Helm", 225, L["Trainer"] );
	addTradeSkill( "Feathered Breastplate", 250, L["Trainer"] );
	addTradeSkill( "Chimeric Gloves", 265, L["Vendor"] );
	addTradeSkill( "Ironfeather Shoulders", 270, L["Vendor"] );
	addTradeSkill( "Chimeric Boots", 275, L["UWD"] );
	addTradeSkill( "Frostsaber Boots", 275, L["Vendor"] );
	addTradeSkill( "Warbear Harness", 275, "You can buy this from Meilosh in Felwood when you are friendly with Timbermaw Hold" );
	addTradeSkill( "Chimeric Leggings", 280, L["UWD"] );
	addTradeSkill( "Frostsaber Leggings", 285, "Mob Drop: Winterfall Den Watcher (Winterspring)" );
	addTradeSkill( "Warbear Woolies", 285, "You can buy this from Meilosh in Felwood when you are friendly with Timbermaw Hold" );
	addTradeSkill( "Chimeric Vest", 290, L["UWD"] );
	addTradeSkill( "Devilsaur Gauntlets", 290, L["Vendor"] );
	addTradeSkill( "Ironfeather Breastplate", 290, "Mob Drop: Vilebranch Hideskinner (The Hinterlands)" );
	addTradeSkill( "Frostsaber Gloves", 295, "Mob Drop: Winterfall Totemic (Winterspring)" );
	addTradeSkill( "Corehound Boots", 295, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are friendly with Thorium Brotherhood" );
	addTradeSkill( "Devilsaur Leggings", 300, "Mob Drop: Cloned Ooze and Muculent Ooze (Ungoro Crater)" );
	addTradeSkill( "Frostsaber Tunic", 300, "Mob Drop: Winterfall Ursa (Winterspring)" );
	addTradeSkill( "Hide of the Wild", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Corehound Belt", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );

	addTradeSkill( "Comfortable Insoles", 300, L["Vendor"] );
	addTradeSkill( "Felscale Gloves", 300, L["Trainer"] );
	addTradeSkill( "Knothide Armor Kit", 300, L["Trainer"] );
	addTradeSkill( "Knothide Leather", 300, L["Trainer"] );
	addTradeSkill( "Scaled Draenic Pants", 300, L["Trainer"] );
	addTradeSkill( "Thick Draenic Pants", 300, L["Trainer"] );
	addTradeSkill( "Wild Draenish Boots", 300, L["Trainer"] );
	addTradeSkill( "Felscale Boots", 310, L["Trainer"] );
	addTradeSkill( "Scaled Draenic Gloves", 310, L["Trainer"] );
	addTradeSkill( "Wild Draenish Gloves", 310, L["Trainer"] );
	addTradeSkill( "Thick Draenic Pants", 315, L["Trainer"] );
	addTradeSkill( "Felscale Pants", 320, L["Trainer"] );
	addTradeSkill( "Thick Draenic Boots", 320, L["Trainer"] );
	addTradeSkill( "Wild Draenish Leggings", 320, L["Trainer"] );
	addTradeSkill( "Heavy Knothide Leather", 325, L["Vendor"] );
	addTradeSkill( "Vindicator's Armor Kit", 325, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Magister's Armor Kit", 325, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Scaled Draenic Vest", 325, L["Trainer"] );
	addTradeSkill( "Reinforced Mining Bag", 325, "Alliance can buy this from Trader Narasu in Nagrand when they are honored with Kurenai, Horde from Provisioner Nasala when they are honored with Mag'har" );

	addTradeSkill( "Thick Draenic Vest", 330, L["Trainer"] );
	addTradeSkill( "Wild Draenish Vest", 330, L["Trainer"] );
	addTradeSkill( "Living Crystal Breastplate", 330, L["Trainer"] );
	addTradeSkill( "Golden Dragonstrike Breastplate", 330, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Primalstorm Breastplate", 330, "Elemental", L["Trainer"] );
	addTradeSkill( "Living Crystal Breastplate", 330, "Tribal", L["Trainer"] );

	addTradeSkill( "Felscale Breastplate", 335, L["Trainer"] );
	addTradeSkill( "Scaled Draenic Boots", 335, L["Trainer"] );
	addTradeSkill( "Cobrahide Leg Armor", 335, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Clefthide Leg Armor", 335, "You can buy this from Aendel Windspear in Silithus when you are honored with Cenarion Circle"  );
	addTradeSkill( "Fel Leather Gloves", 340, "You can purchase this recipe from Karaaz in Netherstorm when you are friendly with The Consortium" );
	addTradeSkill( "Netherfury Belt", 340, "Alliance can buy this from Trader Narasu in Nagrand when they are friendly with Kurenai, Horde from Provisioner Nasala when they are friendly with Mag'har" );
	addTradeSkill( "Netherfury Leggings", 340, "Alliance can buy this from Trader Narasu in Nagrand when they are honored with Kurenai, Horde from Provisioner Nasala when they are honored with Mag'har" );
	addTradeSkill( "Shadow Armor Kit", 340, "BoP mob drop from Time-Lost Shadowmages in Sethekk Halls" );
	addTradeSkill( "Flame Armor Kit", 340, "BoP mob drop from Gargantuan Abyssals in The Arcatraz" );
	addTradeSkill( "Nature Armor Kit", 340, "BoP mob drop from Mennu the Betrayer in The Slave Pens" );
	addTradeSkill( "Arcane Armor Kit", 340, "BoP mob drop from Chrono Lord Deja in The Black Morass" );
	addTradeSkill( "Frost Armor Kit", 340, "BoP mob drop from Hydromancer Thespia in The Steamvault" );
	addTradeSkill( "Drums of War", 340, L["Trainer"] );
	addTradeSkill( "Drums of Speed", 345, L["UWD"] );
	addTradeSkill( "Riding Crop", 350, L["Vendor"] );
	addTradeSkill( "Stylin' Purple Hat", 350, "BoP mob drop from Blackheart the Inciter in Shadow Labyrinth" );
	addTradeSkill( "Stylin' Adventure Hat", 350, "BoP mob drop from Durnholde Riflemen in Old Hillsbrad Foothills" );
	addTradeSkill( "Stylin' Jungle Hat", 350, "BoP mob drop from Rift Lords and Rift Keepers in The Black Morass" );
	addTradeSkill( "Stylin' Crimson Hat", 350, "BoP mob drop from Sethekk Ravenguard in Sethekk Halls" );
	addTradeSkill( "Fel Leather Boots", 350, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Fel Leather Leggings", 350, "You can purchase this recipe from Karaaz in Netherstorm when you are revered with The Consortium" );
	addTradeSkill( "Felstalker Belt", 350, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are friendly with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are friendly with Thrallmar" );
	addTradeSkill( "Netherfury Boots", 350, "Alliance can buy this from Trader Narasu in Nagrand when they are revered with Kurenai, Horde from Provisioner Nasala when they are revered with Mag'har" );
	addTradeSkill( "Enchanted Felscale Boots", 350, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Enchanted Felscale Gloves", 350, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Enchanted Felscale Leggings", 350, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Flamescale Belt", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Flamescale Boots", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Flamescale Leggings", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Enchanted Clefthoof Boots", 350, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Enchanted Clefthoof Gloves", 350, "You can buy this from Quartermaster Enuril in Shattrath when you are revered with Scryers" );
	addTradeSkill( "Enchanted Clefthoof Leggings", 350, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Blastguard Belt", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Blastguard Boots", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are revered with Aldor" );
	addTradeSkill( "Blastguard Pants", 350, 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Drums of Restoration", 350, L["UWD"] );
	addTradeSkill( "Heavy Clefthoof Leggings", 355, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Heavy Clefthoof Boots", 355, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are friendly with Cenarion Expedition" );
	addTradeSkill( "Heavy Clefthoof Vest", 360, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are honored with Cenarion Expedition" );
	addTradeSkill( "Felstalker Bracer", 360, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Felstalker Breastplate", 360, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are honored with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are honored with Thrallmar" );
	addTradeSkill( "Drums of Battle", 365, "You can buy this from Almaador in Shattrath when you are exalted with The Sha'tar" );
	addTradeSkill( "Nethercobra Leg Armor", 365, "Alliance can buy this from Logistics Officer Ulrike in Honor Hold when they are exalted with Honor Hold, Horde from Quartermaster Urgronn in Thrallmar when they are exalted with Thrallmar" );
	addTradeSkill( "Nethercleft Leg Armor", 365, "You can purchase this from Fedryen Swiftspear in Zangarmarsh when you are exalted with Cenarion Expedition" );
	addTradeSkill( "Cobrascale Gloves", 365, L["UWD"] );
	addTradeSkill( "Cobrascale Hood", 365, L["UWD"] );
	addTradeSkill( "Earthen Netherscale Boots", 365, L["UWD"] );
	addTradeSkill( "Gloves of the Living Touch", 365, L["UWD"] );
	addTradeSkill( "Hood of Primal Life", 365, L["UWD"] );
	addTradeSkill( "Living Dragonscale Helm", 365, L["UWD"] );
	addTradeSkill( "Netherdrake Gloves", 365, L["UWD"] );
	addTradeSkill( "Netherdrake Helm", 365, L["UWD"] );
	addTradeSkill( "Thick Netherscale Breastplate", 365, L["UWD"] );
	addTradeSkill( "Windslayer Wraps", 365, L["UWD"] );
	addTradeSkill( "Windscale Hood", 365, L["UWD"] );
	addTradeSkill( "Windstrike Gloves", 365, L["UWD"] );
	addTradeSkill( "Drums of Panic", 370, "You can buy this from Alurmi in Tanaris when you are exalted with Keepers of Time" );

	addTradeSkill( "Ebon Netherscale Belt", 375, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Ebon Netherscale Bracers", 375, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Ebon Netherscale Breastplate", 375, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Netherstrike Belt", 375, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Netherstrike Bracers", 375, "Dragonscale", L["Trainer"] );
	addTradeSkill( "Netherstrike Breastplate", 375, "Dragonscale", L["Trainer"] );

	addTradeSkill( "Primalstrike Belt", 375, "Elemental", L["Trainer"] );
	addTradeSkill( "Primalstrike Bracers", 375, "Elemental", L["Trainer"] );
	addTradeSkill( "Primalstrike Vest", 375, "Elemental", L["Trainer"] );

	addTradeSkill( "Windhawk Belt", 375, "Tribal", L["Trainer"] );
	addTradeSkill( "Windhawk Bracers", 375, "Tribal", L["Trainer"] );
	addTradeSkill( "Windhawk Hauberk", 375, "Tribal", L["Trainer"] );
end

-- Initializes the array adding all Rogue Poisons.  As of 2.2 there are 21 recipes.

local function ARL_InitRoguePoison()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Crippling Poison", 20, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Crippling Poison II", 50, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Mind-numbing Poison", 24, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Mind-numbing Poison II", 38, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Mind-numbing Poison III", 52, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Instant Poison", 20, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Instant Poison II", 28, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Instant Poison III", 36, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Instant Poison IV", 44, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Instant Poison V", 52, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Instant Poison VI", 60, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Deadly Poison", 30, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Deadly Poison II", 38, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Deadly Poison III", 46, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Deadly Poison IV", 54, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Deadly Poison V", 60, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Wound Poison", 32, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Wound Poison II", 40, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Wound Poison III", 48, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Wound Poison IV", 56, L["Trainer"], BCLASS["Rogue"] );
	addTradeSkill( "Blinding Powder", 34, L["Trainer"], BCLASS["Rogue"] );
	
end

-- Initializes the array adding all Tailoring recipes.  As of 2.2 there are

local function ARL_InitTailoring()

	ARL_InitializeRecipeArray();

	addTradeSkill( "Bolt of Linen Cloth", 1, L["Trainer"] );
	addTradeSkill( "Linen Cloak", 1, L["Trainer"] );
	addTradeSkill( "White Linen Shirt", 1, L["Trainer"] );
	addTradeSkill( "Brown Linen Shirt", 1, L["Trainer"] );
	addTradeSkill( "Simple Linen Pants", 1, L["Trainer"] );
	addTradeSkill( "Brown Linen Vest", 10, L["Trainer"] );
	addTradeSkill( "Linen Belt", 15, L["Trainer"] );
	addTradeSkill( "Simple Linen Boots", 20, L["Trainer"] );
	addTradeSkill( "Brown Linen Pants", 30, L["Trainer"] );
	addTradeSkill( "Brown Linen Robe", 30, L["Trainer"] );
	addTradeSkill( "White Linen Robe", 30, L["Trainer"] );
	addTradeSkill( "Heavy Linen Gloves", 35, L["Trainer"] );
	addTradeSkill( "Red Linen Robe", 40, L["UWD"] );
	addTradeSkill( "Red Linen Shirt", 40, L["Trainer"] );
	addTradeSkill( "Blue Linen Shirt", 40, L["Trainer"] );
	addTradeSkill( "Simple Dress", 40, L["Trainer"] );
	addTradeSkill( "Linen Bag", 45, L["Trainer"] );
	addTradeSkill( "Blue Linen Vest", 55, L["Vendor"] );
	addTradeSkill( "Red Linen Vest", 55, L["UWD"] );
	addTradeSkill( "Reinforced Linen Cape", 60, L["Trainer"] );
	addTradeSkill( "Green Linen Bracers", 60, L["Trainer"] );
	addTradeSkill( "Linen Boots", 65, L["Trainer"]);
	addTradeSkill( "Red Linen Bag", 70, L["Vendor"] );
	addTradeSkill( "Blue Linen Robe", 70, L["Vendor"] );
	addTradeSkill( "Bolt of Woolen Cloth", 75, L["Trainer"] );
	addTradeSkill( "Woolen Cape", 75, L["Trainer"] );
	addTradeSkill( "Simple Kilt", 75, L["Trainer"] );
	addTradeSkill( "Soft-soled Linen Boots", 80, L["Trainer"] );
	addTradeSkill( "Woolen Bag", 80, L["Trainer"] );
	addTradeSkill( "Green Woolen Vest", 85, L["Trainer"] );
	addTradeSkill( "Heavy Woolen Gloves", 85, L["Trainer"] );
	addTradeSkill( "Pearl-clasped Cloak", 90, L["Trainer"] );
	addTradeSkill( "Barbaric Linen Vest", 90, L["Trainer"] );
	addTradeSkill( "Green Linen Shirt", 90, L["Trainer"] );
	addTradeSkill( "Handstitched Linen Britches", 90, L["Trainer"] );
	addTradeSkill( "Woolen Boots", 95, L["Trainer"] );
	addTradeSkill( "Red Woolen Boots", 95, L["UWD"] );
	addTradeSkill( "Green Woolen Bag", 95, L["UWD"] );
	addTradeSkill( "Gray Woolen Shirt", 100, L["Trainer"] );
	addTradeSkill( "Heavy Woolen Cloak", 100, L["UWD"] );
	addTradeSkill( "Blue Overalls", 100, L["Vendor"] );
	addTradeSkill( "Gray Woolen Robe", 105, L["UWD"] );
	addTradeSkill( "Double-stitched Woolen Shoulders", 110, L["Trainer"] );
	addTradeSkill( "Heavy Woolen Pants", 110, L["Trainer"] );
	addTradeSkill( "White Woolen Dress", 110, L["Trainer"] );
	addTradeSkill( "Red Woolen Bag", 115, L["Vendor"] );
	addTradeSkill( "Greater Adept's Robe", 115, "Alliance - Limited Supply from Rann Flamespinner (Loch Modan [36,46])" );
	addTradeSkill( "Reinforced Woolen Shoulders", 120, L["UWD"] );
	addTradeSkill( "Stylish Blue Shirt", 120, L["UWD"] );
	addTradeSkill( "Stylish Green Shirt", 120, L["UWD"] );
	addTradeSkill( "Colorful Kilt", 120, L["UWD"] );
	addTradeSkill( "Bolt of Silk Cloth", 125, L["Trainer"] );
	addTradeSkill( "Phoenix Pants", 125, L["UWD"] );
	addTradeSkill( "Spidersilk Boots", 125, L["Trainer"] );
	addTradeSkill( "Stylish Red Shirt", 125, L["Trainer"] );
	addTradeSkill( "Phoenix Gloves", 125, L["UWD"] );
	addTradeSkill( "Gloves of Meditation", 130, L["Trainer"] );
	addTradeSkill( "Bright Yellow Shirt", 135, L["Vendor"] );
	addTradeSkill( "Lesser Wizard's Robe", 135, L["Trainer"] );
	addTradeSkill( "Spider Silk Slippers", 140, L["UWD"] );
	addTradeSkill( "Azure Silk Pants", 140, L["Trainer"] );
	addTradeSkill( "Azure Silk Gloves", 145, L["Vendor"] );
	addTradeSkill( "Azure Silk Hood", 145, L["Trainer"] );
	addTradeSkill( "Hands of Darkness", 145, L["UWD"] );
	addTradeSkill( "Azure Silk Vest", 150, L["Trainer"] );
	addTradeSkill( "Small Silk Pack", 150, L["Trainer"] );
	addTradeSkill( "Robes of Arcana", 150, "Mob Drop: Dark Strand Voidcaller (Darkshore, Defias Enchanter (Duskwood)" );
	addTradeSkill( "Truefaith Gloves", 150, L["UWD"] );
	addTradeSkill( "Dark Silk Shirt", 155, L["Vendor"] );
	addTradeSkill( "White Swashbuckler's Shirt", 160, L["Trainer"] );
	addTradeSkill( "Silk Headband", 160, L["Trainer"] );
	addTradeSkill( "Enchanter's Cowl", 165, L["Vendor"] );
	addTradeSkill( "Green Silk Armor", 165, L["UWD"] );
	addTradeSkill( "Shadow Hood", 170, L["UWD"] );
	addTradeSkill( "Formal White Shirt", 170, L["Trainer"] );
	addTradeSkill( "Earthen Vest", 170, L["Trainer"] );
	addTradeSkill( "Bolt of Mageweave", 175, L["Trainer"] );
	addTradeSkill( "Boots of the Enchanter", 175, L["UWD"] );
	addTradeSkill( "Green Silk Pack", 175, L["UWD"] );
	addTradeSkill( "Red Swashbuckler's Shirt", 175, L["Trainer"] );
	addTradeSkill( "Azure Silk Belt", 175, L["Trainer"] );
	addTradeSkill( "Crimson Silk Belt", 175, L["Trainer"] );
	addTradeSkill( "Azure Silk Cloak", 175, L["Vendor"] );
	addTradeSkill( "Spider Belt", 180, L["UWD"] );
	addTradeSkill( "Green Silken Shoulders", 180, L["Trainer"] );
	addTradeSkill( "Crimson Silk Cloak", 180, L["Vendor"] );
	addTradeSkill( "Long Silken Cloak", 185, L["Trainer"] );
	addTradeSkill( "Rich Purple Silk Shirt", 185, L["UWD"] );
	addTradeSkill( "Black Silk Pack", 185, "Mob Drop: Syndicate Spy (Alterac Mountains), Theramore Infiltrator (Dustwallow Marsh), Shadowy Assassin (Hillsbrad Foothills)" );
	addTradeSkill( "Crimson Silk Vest", 185, L["Trainer"] );
	addTradeSkill( "Robe of Power", 190, L["Trainer"] );
	addTradeSkill( "Crimson Silk Shoulders", 190, L["UWD"] );
	addTradeSkill( "Azure Shoulders", 190, L["UWD"] );
	addTradeSkill( "Green Holiday Shirt", 190, "You can get this randomly as a reward from a Christmas quest.  It's also a drop from Father Winter" );
	addTradeSkill( "Earthen Silk Belt", 195, L["UWD"] );
	addTradeSkill( "Crimson Silk Pantaloons", 195, L["Trainer"] );
	addTradeSkill( "Icy Cloak", 200, L["Vendor"] );
	addTradeSkill( "Star Belt", 200, L["UWD"] );
	addTradeSkill( "Black Swashbuckler's Shirt", 200, L["Vendor"] );
	addTradeSkill( "Crimson Silk Robe", 205, L["Vendor"] );
	addTradeSkill( "Black Mageweave Vest", 205, L["Trainer"] );
	addTradeSkill( "Black Mageweave Leggings", 205, L["Trainer"] );
	addTradeSkill( "Crimson Silk Gloves", 210, L["Trainer"] );
	addTradeSkill( "Black Mageweave Robe", 210, L["Trainer"] );
	addTradeSkill( "Shadoweave Pants", 210, L["Trainer"] );
	addTradeSkill( "Black Mageweave Gloves", 215, L["Trainer"] );
	addTradeSkill( "Shadoweave Robe", 215, L["Trainer"] );
	addTradeSkill( "Red Mageweave Vest", 215, L["UWD"] );
	addTradeSkill( "White Bandit Mask", 215, L["UWD"] );
	addTradeSkill( "Red Mageweave Pants", 215, L["UWD"] );
	addTradeSkill( "Orange Mageweave Shirt", 215, L["Trainer"] );
	addTradeSkill( "Orange Martial Shirt", 220, L["Vendor"] );
	addTradeSkill( "Mageweave Bag", 225, L["Trainer"] );
	addTradeSkill( "Red Mageweave Gloves", 225, L["UWD"] );
	addTradeSkill( "Dreamweave Gloves", 225, L["Trainer"] );
	addTradeSkill( "Cindercloth Robe", 225, L["Trainer"] );
	addTradeSkill( "Dreamweave Vest", 225, L["Trainer"] );
	addTradeSkill( "Shadoweave Gloves", 225, L["Trainer"] );
	addTradeSkill( "Enchanted Mageweave Pouch", 225, L["Vendor"] );
	addTradeSkill( "Black Mageweave Headband", 230, L["Trainer"] );
	addTradeSkill( "Black Mageweave Boots", 230, L["Trainer"] );
	addTradeSkill( "Black Mageweave Shoulders", 230, L["Trainer"] );
	addTradeSkill( "Lavender Mageweave Shirt", 230, L["Vendor"] );
	addTradeSkill( "Shadoweave Shoulders", 235, L["Trainer"] );
	addTradeSkill( "Simple Black Dress", 235, L["Trainer"] );
	addTradeSkill( "Red Mageweave Shoulders", 235, L["UWD"] );
	addTradeSkill( "Red Mageweave Bag", 235, L["Trainer"] );
	addTradeSkill( "Pink Mageweave Shirt", 235, L["Vendor"] );
	addTradeSkill( "Admiral's Hat", 240, L["Vendor"] );
	addTradeSkill( "Shadoweave Boots", 240, L["Trainer"] );
	addTradeSkill( "Red Mageweave Headband", 240, L["UWD"] );
	addTradeSkill( "Tuxedo Shirt", 240, L["Vendor"] );
	addTradeSkill( "Shadoweave Mask", 245, "Reward from quest (The Undermarket) that starts from Nilith Lokrav (Searing Gorge)");
	addTradeSkill( "Cindercloth Boots", 245, L["Trainer"] );
	addTradeSkill( "Tuxedo Pants", 245, L["Vendor"] );
	addTradeSkill( "White Wedding Dress", 250, L["Vendor"] );
	addTradeSkill( "Dreamweave Circlet", 250, L["Trainer"] );
	addTradeSkill( "Tuxedo Jacket", 250, L["Vendor"] );
	addTradeSkill( "Bolt of Runecloth", 250, L["Trainer"] );
	addTradeSkill( "Mooncloth", 250, L["Vendor"] );
	addTradeSkill( "Festive Red Dress", 250, "Reward from quest during Lunar Festival that starts in Moonglade" );
	addTradeSkill( "Festival Dress", 250, "Reward from quest during Lunar Festival that starts in Moonglade" );
	addTradeSkill( "Festive Red Pant Suit", 250, "Reward from quest during Lunar Festival that starts in Moonglade" );
	addTradeSkill( "Runecloth Belt", 255, L["Trainer"] );
	addTradeSkill( "Frostweave Tunic", 255, L["UWD"] );
	addTradeSkill( "Frostweave Robe", 255, L["UWD"] );
	addTradeSkill( "Runecloth Robe", 260, L["Vendor"] );
	addTradeSkill( "Runecloth Bag", 260, L["Vendor"] );
	addTradeSkill( "Runecloth Tunic", 260, L["UWD"] );
	addTradeSkill( "Cindercloth Vest", 260, "Mob Drop: Twilight Fire Guard (Searing Gorge)" );
	addTradeSkill( "Soul Pouch", 260, L["Vendor"] );
	addTradeSkill( "Runecloth Cloak", 265, L["Vendor"] );
	addTradeSkill( "Ghostweave Belt", 265, "Mob Drop: Lingering Highborne (Azshara)" );
	addTradeSkill( "Frostweave Gloves", 265, L["UWD"] );
	addTradeSkill( "Cindercloth Gloves", 270, "Mob Drop: Twilight Fire Guard (Searing Gorge)" );
	addTradeSkill( "Brightcloth Gloves", 270, L["UWD"] );
	addTradeSkill( "Ghostweave Gloves", 270, "Mob Drop: Lingering Highborne (Azshara), Unseen Servant (Eastern Plaguelands)" );
	addTradeSkill( "Brightcloth Robe", 270, L["UWD"] );
	addTradeSkill( "Ghostweave Vest", 275, "Mob Drop: Unseen Servant (Eastern Plaguelands)" );
	addTradeSkill( "Runecloth Gloves", 275, L["Vendor"] );
	addTradeSkill( "Cindercloth Cloak", 275, "Mob Drop: Thaurissan Firewalker (Burning Steppes)" );
	addTradeSkill( "Felcloth Pants", 275, L["Vendor"] );
	addTradeSkill( "Brightcloth Cloak", 275, L["UWD"] );
	addTradeSkill( "Wizardweave Leggings", 275, "Mob Drop: Dark Summoner (Eastern Plaguelands and Stratholme)" );
	addTradeSkill( "Cloak of Fire", 275, "Mob Drop: Overmaster Pyron (Blackrock Mountain) - Binds when picked up" );
	addTradeSkill( "Enchanted Runecloth Bag", 275, L["Vendor"] );
	addTradeSkill( "Cenarion Herb Bag", 275, L["Vendor"] );
	addTradeSkill( "Runecloth Boots", 280, L["Vendor"] );
	addTradeSkill( "Frostweave Pants", 280, L["UWD"] );
	addTradeSkill( "Cindercloth Pants", 280, "Mob Drop: Thaurissan Firewalker (Burning Steppes)" );
	addTradeSkill( "Robe of Winter Night", 285, "Mob Drop: Cobalt Mageweaver (Winterspring)" );
	addTradeSkill( "Felcloth Boots", 285, L["UWD"] );
	addTradeSkill( "Runecloth Pants", 285, L["UWD"] );
	addTradeSkill( "Felcloth Bag", 285, "Book spawns after defeating Jandice in Scholomance.  Must have skill level 285 to learn."  );
	addTradeSkill( "Brightcloth Pants", 290, L["UWD"] );
	addTradeSkill( "Mooncloth Leggings", 290, L["UWD"] );
	addTradeSkill( "Mooncloth Boots", 290, "Reward from quest (Sacred Cloth).  Receive quest from Meilosh in Timbermaw Hold.  Requires friendly reputation with Timbermaw Hold."  );
	addTradeSkill( "Ghostweave Pants", 290, "Mob Drop: Spectral Citizen (Stratholme)" );
	addTradeSkill( "Felcloth Hood", 290, L["UWD"] );
	addTradeSkill( "Wisdom of the Timbermaw", 290, "You can buy this from Meilosh in Felwood when you are honoroed with Timbermaw Hold" );
	addTradeSkill( "Argent Boots", 290, "You can buy this from an Argent Dawn Quartermaster when you are honored with Argent Dawn" );
	addTradeSkill( "Runecloth Headband", 295, L["UWD"] );
	addTradeSkill( "Mooncloth Bag", 300, L["UWD"] );
	addTradeSkill( "Wizardweave Robe", 300, "Mob Drop: Dark Caster (Eastern Plaguelands)" );
	addTradeSkill( "Mooncloth Vest", 300, L["UWD"] );
	addTradeSkill( "Mooncloth Shoulders", 300, L["UWD"] );
	addTradeSkill( "Runecloth Shoulders", 300, L["UWD"] );
	addTradeSkill( "Wizardweave Turban", 300, "Mob Drop: Dark Caster (Eastern Plaguelands)" );
	addTradeSkill( "Felcloth Robe", 300, L["UWD"] );
	addTradeSkill( "Mooncloth Circlet", 300 );
	addTradeSkill( "Gordok Ogre Suit", 300, "Can learn recipe after completing quest (The Gordok Ogre Suit) obtained from Knot Thimblejack from Dire Maul" );
	addTradeSkill( "Felcloth Shoulders", 300, L["UWD"] );
	addTradeSkill( "Gloves of Spell Mastery", 300 );
	addTradeSkill( "Bottomless Bag", 300 );
	addTradeSkill( "Truefaith Vestments", 300, "Mob Drop: Balnazzar (Stratholme)", "Priest" );
	addTradeSkill( "Robe of the Archmage", 300, "Mob Drop: Firebrand Pyromancer (Hall of Blackhand)", "Mage" );
	addTradeSkill( "Robe of the Void", 300, "Mob Drop: Darkmaster Gandling (Scholomance)", "Warlock" );
	addTradeSkill( "Flarecore Mantle", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood"  );
	addTradeSkill( "Flarecore Gloves", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are friendly with Thorium Brotherhood"  );
	addTradeSkill( "Flarecore Wraps", 300, "Mob Drop: Molten Core bosses" );
	addTradeSkill( "Belt of the Archmage", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Felcloth Gloves", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Bushwacker, Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Inferno Gloves", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Guard Slip'kik, Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Mooncloth Gloves", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Bushwacker, Gordok Reaver and Gordok Warlock (Dire Maul)" );
	addTradeSkill( "Cloak of Warding", 300, "Knot Thimblejack's Cache (Dire Maul) and Mob Drop: Gordok Reaver (Dire Maul)" );
	addTradeSkill( "Mooncloth Robe", 300, L["Vendor"] );
	addTradeSkill( "Mantle of the Timbermaw", 300, "You can buy this from Meilosh in Felwood when you are revered with Timbermaw Hold" );
	addTradeSkill( "Argent Shoulders", 300, "You can buy this from an Argent Dawn Quartermaster when you are revered with Argent Dawn" );
	addTradeSkill( "Flarecore Robe", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are honored with Thorium Brotherhood" );
	addTradeSkill( "Flarecore Leggings", 300, "You can buy this from Lokhtos Darkbargainer in Blackrock Depths when you are revered with Thorium Brotherhood" );
	addTradeSkill( "Bloodvine Boots", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are friendly with Zandalar Tribe" );
	addTradeSkill( "Bloodvine Leggings", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are honored with Zandalar Tribe" );
	addTradeSkill( "Bloodvine Vest", 300, "You can buy this from Rin'wosho the Trader in Stranglethorn Vale when you are revered with Zandalar Tribe" );
	addTradeSkill( "Runed Stygian Belt", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Runed Stygian Boots", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Runed Stygian Leggings", 300, "Rare quest reward for completing True Believers quest from Hermit Ortell (Silithus)" );
	addTradeSkill( "Core Felcloth Bag", 300, "Mob Drop: Lord Kazzok (Blasted Lands) and Molten Core bosses" );
	addTradeSkill( "Big Bag of Enchantment", 300, "Mob Drop: Magister Kalendris (Dire Maul)" );
	addTradeSkill( "Satchel of Cenarius", 300, "You can buy this from Mishta in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Gaea's Embrace", 300, "You can buy this from Mishta in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Sylvan Crown", 300, "You can buy this from Mishta in Silithus when you are honored with Cenarion Circle" );
	addTradeSkill( "Sylvan Shoulders", 300, "You can buy this from Mishta in Silithus when you are friendly with Cenarion Circle" );
	addTradeSkill( "Sylvan Vest", 300, "You can buy this from Mishta in Silithus when you are revered with Cenarion Circle" );
	addTradeSkill( "Glacial Cloak", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Glacial Gloves", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );
	addTradeSkill( "Glacial Vest", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are exalted with Argent Dawn" );
	addTradeSkill( "Glacial Wrists", 300, "You can learn this from Master Craftsman Omarion in Naxxramas when you are revered with Argent Dawn" );

	addTradeSkill( "Netherweave Net", 300, L["Trainer"] );
	addTradeSkill( "Bolt of Netherweave", 300, L["Trainer"] );
	addTradeSkill( "Netherweave Bracers", 310, L["Trainer"] );
	addTradeSkill( "Netherweave Belt", 310, L["Trainer"] );
	addTradeSkill( "Netherweave Bag", 315, L["Trainer"] );
	addTradeSkill( "Netherweave Gloves", 320, L["Trainer"] );
	addTradeSkill( "Bolt of Imbued Netherweave", 325, L["Vendor"] );
	addTradeSkill( "Netherweave Pants", 325, L["Trainer"] );
	addTradeSkill( "Netherweave Boots", 335, L["Trainer"] );
	addTradeSkill( "Mystic Spellthread", 335, "You can buy this from Quartermaster Enuril in Shattrath when you are honored with Scryers" );
	addTradeSkill( "Silver Spellthread", 335, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Imbued Netherweave Bag", 340, L["Vendor"] );
	addTradeSkill( "Netherweave Robe", 340, L["Vendor"] );
	addTradeSkill( "Imbued Netherweave Pants", 340, L["Vendor"] );
	addTradeSkill( "Bag of Jewels", 340, "You can purchase this recipe from Karaaz in Netherstorm when you are honored with The Consortium" );
	addTradeSkill( "Bolt of Soulcloth", 345, L["Vendor"] );
	addTradeSkill( "Netherweave Tunic", 345, L["Vendor"] );
	addTradeSkill( "Primal Mooncloth", 350, L["Vendor"] );
	addTradeSkill( "Imbued Netherweave Boots", 350, L["Vendor"] );
	addTradeSkill( "Arcanoweave Bracers", 350, "BoP mob drop from Arcatraz Sentinels in The Arcatraz" );
	addTradeSkill( "Unyielding Bracers", 350, L["UWD"] );
	addTradeSkill( "Bracers of Havok", 350, L["UWD"] );
	addTradeSkill( "Blackstrike Bracers", 350, L["UWD"] );
	addTradeSkill( "Cloak of the Black Void", 350, L["UWD"] );
	addTradeSkill( "Cloak of Eternity", 350, L["UWD"] );
	addTradeSkill( "White Remedy Cape", 350, L["UWD"] );
	addTradeSkill( "Spellcloth", 350, L["Vendor"] );
	addTradeSkill( "Shadowcloth", 350, L["Vendor"] );
	addTradeSkill( "Cloak of Arcane Evasion", 350, "You can buy this from Nakodu in Shattrath City when you are honored with Lower City" );
	addTradeSkill( "Flameheart Bracers", 350, "You can purchase this from Quartermaster Endarin in Shattrath City when you are friendly with Aldor" );
	addTradeSkill( "Spellfire Belt", 355, "Spellfire", L["Vendor"] );
	addTradeSkill( "Frozen Shadoweave Shoulders", 355, "Shadoweave", L["Vendor"] );
	addTradeSkill( "Primal Mooncloth Belt", 355, "Mooncloth", L["Vendor"] );
	addTradeSkill( "Soulcloth Gloves", 355, L["Vendor"] );
	addTradeSkill( "Imbued Netherweave Robe", 360, L["Vendor"] );
	addTradeSkill( "Imbued Netherweave Tunic", 360, L["Vendor"] );
	addTradeSkill( "Arcanoweave Boots", 360, "BoP mob drop from Sunseeker Astromages in The Mechanar" );
	addTradeSkill( "Flameheart Gloves", 360, "You can purchase this from Quartermaster Endarin in Shattrath City when you are honored with Aldor" );
	addTradeSkill( "Spellfire Gloves", 365, "Spellfire", L["Vendor"] );
	addTradeSkill( "Frozen Shadoweave Boots", 365, "Shadoweave", L["Vendor"] );
	addTradeSkill( "Primal Mooncloth Shoulders", 365, "Mooncloth", L["Vendor"] );
	addTradeSkill( "Soulcloth Shoulders", 365, "BoP mob drop from Phantom Attendants in Karazhan" );
	addTradeSkill( "Unyielding Girdle", 365, L["UWD"] );
	addTradeSkill( "Girdle of Ruination", 365, L["UWD"] );
	addTradeSkill( "Black Belt of Knowledge", 365, L["UWD"] );
	addTradeSkill( "Resolute Cape", 365, L["UWD"] );
	addTradeSkill( "Vengeance Wrap", 365, L["UWD"] );
	addTradeSkill( "Manaweave Cloak", 365, L["UWD"] );
	addTradeSkill( "Arcanoweave Robe", 370, "BoP mob drop from Panthaleon the Calculator in The Mechanar" );
	addTradeSkill( "Flameheart Vest", 370, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Spellfire Vest", 370, "Spellfire", L["Trainer"] );
	addTradeSkill( "Spellfire Bag", 375, L["Vendor"] );
	addTradeSkill( "Frozen Shadoweave Vest", 375, "Shadoweave", L["Vendor"] );
	addTradeSkill( "Ebon Shadowbag", 375, "Mooncloth", L["Vendor"] );
	addTradeSkill( "Primal Mooncloth Robe", 375, "Mooncloth", L["Vendor"] );
	addTradeSkill( "Primal Mooncloth Bag", 375, L["Vendor"] );
	addTradeSkill( "Soulcloth Vest", 375, "BoP mob drop from Phantom Valet in Karazhan" );
	addTradeSkill( "Runic Spellthread", 375, "You can buy this from Quartermaster Enuril in Shattrath when you are exalted with Scryers" );
	addTradeSkill( "Golden Spellthread", 375, "You can purchase this from Quartermaster Endarin in Shattrath City when you are exalted with Aldor" );
	addTradeSkill( "Whitemend Pants", 375, "BoP mob drop from Dalliah the Doomsayer in The Arcatraz" );
	addTradeSkill( "Spellstrike Pants", 375, "BoP mob drop from Murmur in Shadow Labyrinth" );
	addTradeSkill( "Battlecast Pants", 375, "BoP mob drop from Thorngrin the Tender in The Botanica" );
	addTradeSkill( "Whitemend Hood", 375, "BoP mob drop from Warp Splinter in The Botanica" );
	addTradeSkill( "Spellstrike Hood", 375, "BoP mob drop from Grand Warlock Nethekurse in The Shattered Halls" );
	addTradeSkill( "Battlecast Hood", 375, "BoP mob drop from Warlord Kalithresh" );

end

-- Initializes the array adding all Smelting recipes.  As of 2.2 there are 20 recipes

local function ARL_InitSmelting()
  
	ARL_InitializeRecipeArray();

  	-- Original Game Recipes
	addTradeSkill( L["Smelt Copper"], 1, L["Trainer"] );
	addTradeSkill( L["Smelt Tin"], 65, L["Trainer"] );
	addTradeSkill( L["Smelt Bronze"], 65, L["Trainer"] );
	addTradeSkill( L["Smelt Silver"], 75, L["Trainer"] );
	addTradeSkill( L["Smelt Iron"], 125, L["Trainer"] );
	addTradeSkill( L["Smelt Gold"], 155, L["Trainer"] );
	addTradeSkill( L["Smelt Steel"], 165, L["Trainer"] );
	addTradeSkill( L["Smelt Mithril"], 175, L["Trainer"] );
	addTradeSkill( L["Smelt Dark Iron"], 230, L["Dark Iron Obt"] );
	addTradeSkill( L["Smelt Truesilver"], 230, L["Trainer"] );
	addTradeSkill( L["Smelt Thorium"], 250, L["Trainer"] );
	addTradeSkill( L["Smelt Elementium"], 270, L["Elementium Obt"], L["Raid"] );

	-- Burning Crusade Recipes
	addTradeSkill( L["Fire Sunder"], 300, L["Trainer"] );
	addTradeSkill( L["Earth Shatter"], 300, L["Trainer"] );
	addTradeSkill( L["Smelt Fel Iron"], 300, L["Trainer"] );
	addTradeSkill( L["Smelt Adamantite"], 350, L["Trainer"] );
	addTradeSkill( L["Smelt Felsteel"], 350, L["Trainer"] );
	addTradeSkill( L["Smelt Eternium"], 350, L["Trainer"] );
	addTradeSkill( L["Smelt Khorium"], 375, L["Trainer"] );
	addTradeSkill( L["Smelt Hardened Adamantite"], 375, L["Trainer"] );

	-- Wrath of the Litch King Recipes

end

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeTradeRecipes(CurrentProfession)

	if CurrentProfession == BTS["Alchemy"] then

		-- Add all alchemy recipes to the table
		ARL_InitAlchemy();
		
	elseif CurrentProfession == BTS["Blacksmithing"] then
		
		-- Add all blacksmithing recipes to the table
		ARL_InitBlackSmith();

	elseif CurrentProfession == BTS["Cooking"] then

		-- Add all cooking recipes to the table
		ARL_InitCooking();

	elseif CurrentProfession == BTS["Engineering"] then
		
		-- Add all engineering recipes to the table
		ARL_InitEngineering();
	
	elseif CurrentProfession == BTS["First Aid"] then

		-- Add all first aid recipes to the table
		ARL_InitFirstAid();

	elseif CurrentProfession == BTS["Leatherworking"] then

		-- Add all leatherworking recipes to the table		
		ARL_InitLeatherWorking();

	elseif CurrentProfession == BTS["Poisons"] then

		-- Add all rogue poisons recipes to the table
		ARL_InitRoguePoison();

	elseif CurrentProfession == BTS["Mining"] then

		-- Add all smelting recipes to the table
		ARL_InitSmelting();

	elseif CurrentProfession == BTS["Tailoring"] then

		-- Add all tailoring recipes to the table
		ARL_InitTailoring();

	-- Burning Crusade Professions
	elseif CurrentProfession == BTS["Jewelcrafting"] then

		-- Add all jewelcrafting recipes to the table
		ARL_InitJewelcrafting();

	else

		DEFAULT_CHAT_FRAME:AddMessage( L["UnknownTradeSkill"]:format( CurrentProfession ) );
		
	end

end

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeCraftRecipes(CurrentProfession)

	local CurrentProfessionLevel;

	if CurrentProfession == BTS["Enchanting"] then

		-- Get the current level of the craft.
		CurrentProfessionLevel = getglobal( "CraftRankFrame" ):GetValue(); --Better way to do this?

		-- Add all enchanting recipes to the table
		ARL_InitEnchanting();

	elseif CurrentProfession == L["Beast Training"] then

		-- Player level = profession level for beast training
		CurrentProfessionLevel = UnitLevel("player");

		-- Add all beast training recipes to the table
		ARL_InitBeastTraining();

		-- Scan for missing beast training
		AckisRecipeList:ScanBeastTraining(CurrentProfession);

	else

		CurrentProfessionLevel = 0;
		DEFAULT_CHAT_FRAME:AddMessage( L["UnknownTradeSkill"]:format( CurrentProfession ) );

	end

	return CurrentProfessionLevel;

end

--[[

	GUI functions

]]--

-- Function to run when the + is clicked in the frame.  Will expand the recipe name and print out how to obtain it.

local function AckisRecipeList_OnClickExpandRecipe()

	if ( this.IsPushed == false ) then

		local RecipeText = this:GetText();

		-- Changed the graphic of the + to a -
		this:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up");
		this:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down");
		this:SetDisabledTexture("Interface\\Buttons\\UI-MinusButton-Disabled");
		this:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight");

		-- Keep track of button state
		this.IsPushed = true;

		-- Show expanded text
		if ( MissingRecipeListing[ RecipeText ][ "Acquire" ] == nil ) then

			this.RecipeAquireText:SetText( "No acquisition information availible." );

		else

			this.RecipeAquireText:SetText( MissingRecipeListing[ RecipeText ][ "Acquire" ] );

		end

		-- Reposition the next recipe entry
		if ( this.NextRecipe ~= nil ) then

			local TempText = this.NextRecipe:GetText();

			this.NextRecipe:SetText("");
			this.NextRecipe:ClearAllPoints();
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, -10);
			this.NextRecipe:SetText(TempText);

		end

	else

		-- Changed the graphic of the - to a +
		this:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up");
		this:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down");
		this:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled");
		this:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight");

		-- Keep track of button state
		this.IsPushed = false;

		-- Hide expanded text
		this.RecipeAquireText:SetText("");

		-- Reposition the next recipe entry
		if ( this.NextRecipe ~= nil ) then

			this.NextRecipe:ClearAllPoints();
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, 0);

		end

	end

end

-- Sets variables for RecipeButtons

local function AckisRecipeList_SetRecipeListParams(frame)

	frame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up");
	frame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down");
	frame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled");
	frame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight");
	frame:SetTextColor(1, 1, 1);
	frame:SetScript("OnClick", AckisRecipeList_OnClickExpandRecipe);
	frame.IsPushed = false;

	frame.RecipeAquireText = frame:CreateFontString(frame:GetName() .. "Text", "DIALOG");

	frame.RecipeAquireText:ClearAllPoints();
	frame.RecipeAquireText:SetPoint("TOPLEFT", frame, "BOTTOMLEFT", 10, 0);
	frame.RecipeAquireText:SetFontObject("GameFontNormalSmall");
	frame.RecipeAquireText:SetTextColor(1, 1, 1);

end

-- Scrolls the frame up and down

local function AckisRecipeList_ScrollBar()

end

-- Closes the frame and cleans sets everything that was displayed to nil

local function AckisRecipeList_CloseFrame()

	-- Clean up recipe entries
	local RecipeFrame = AckisRecipeListRecipe1;

	-- Create x number of entries for all missing recipes
	while ( RecipeFrame ~= nil ) do

		RecipeFrame.RecipeAquireText:ClearAllPoints();
		RecipeFrame.RecipeAquireText:SetText("");
		RecipeFrame.RecipeAquireText:Hide();

		RecipeFrame:ClearAllPoints();
		RecipeFrame:SetText("");
		RecipeFrame:Hide();

		local NextRecipe = RecipeFrame.NextRecipe;
		RecipeFrame = nil;
		RecipeFrame = NextRecipe;
		NextRecipe = nil;

	end

	AckisRecipeListFrameCloseButton:ClearAllPoints();
	AckisRecipeListFrameCloseButton:SetText("");
	AckisRecipeListFrameCloseButton = nil;

	AckisRecipeListFrameXButton:ClearAllPoints();
	AckisRecipeListFrameXButton = nil;

	AckisRecipeListFrameScrollBar:ClearAllPoints();
	AckisRecipeListFrameScrollBar = nil;

	AckisRecipeListFrameHeaderFrame:ClearAllPoints();
	AckisRecipeListFrameHeaderFrame = nil;

	AckisRecipeListFrameHeaderFrameTexture:ClearAllPoints();
	AckisRecipeListFrameHeaderFrameTexture:Hide();
	AckisRecipeListFrameHeaderFrameTexture = nil;

	AckisRecipeListFrameHeaderFrameText:ClearAllPoints();
	AckisRecipeListFrameHeaderFrameText:SetText("");
	AckisRecipeListFrameHeaderFrameText = nil;

	AckisRecipeListFrame:ClearAllPoints();
	AckisRecipeListFrame:Hide();
	AckisRecipeListFrame = nil;

end

-- Creates the initial frame to display recipes into

function AckisRecipeList:AckisRecipeList_CreateFrame()

	-- Create the main frame
	AckisRecipeListFrame = CreateFrame("Frame", "AckisRecipeListFrame", UIParent);

	AckisRecipeListFrame:SetFrameStrata("DIALOG");
	AckisRecipeListFrame:SetWidth(384);
	AckisRecipeListFrame:SetHeight(430);
	AckisRecipeListFrame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		});
	AckisRecipeListFrame:SetBackdropColor(0, 0, 0);
	AckisRecipeListFrame:EnableMouse(true);
	AckisRecipeListFrame:SetMovable(true);
	AckisRecipeListFrame:ClearAllPoints();

	if ( SkillType == "Trade" ) then
	
		AckisRecipeListFrame:SetPoint("RIGHT", TradeSkillFrame, "RIGHT", 345, 30);
	
	else

		AckisRecipeListFrame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30);

	end

	AckisRecipeListFrame:SetScript("OnMouseDown", function() AckisRecipeListFrame:StartMoving() end);
	AckisRecipeListFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end);

	-- Add close button
	local AckisRecipeListFrameCloseButton = CreateFrame("Button", "AckisRecipeListFrameCloseButton", AckisRecipeListFrame, "UIPanelButtonTemplate");

	AckisRecipeListFrameCloseButton:SetFrameStrata("DIALOG");
	AckisRecipeListFrameCloseButton:SetWidth(100);
	AckisRecipeListFrameCloseButton:SetHeight(24);
	AckisRecipeListFrameCloseButton:ClearAllPoints();
	AckisRecipeListFrameCloseButton:SetPoint("BOTTOMRIGHT", AckisRecipeListFrame, -10, 10);
	AckisRecipeListFrameCloseButton:RegisterForClicks("LeftButtonUp");
	AckisRecipeListFrameCloseButton:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end);
	AckisRecipeListFrameCloseButton:SetFont("GameFontHighlightSmall",12);
	AckisRecipeListFrameCloseButton:Enable();
	AckisRecipeListFrameCloseButton:SetTextColor(1, 1, 1);
	AckisRecipeListFrameCloseButton:SetText("Close");

	-- Add a "close with x" button
	local AckisRecipeListFrameXButton = CreateFrame("Button", "AckisRecipeListFrameXButton", AckisRecipeListFrame, "UIPanelCloseButton");

	AckisRecipeListFrameXButton:ClearAllPoints();
	AckisRecipeListFrameXButton:SetPoint("TOPRIGHT", AckisRecipeListFrame, "TOPRIGHT", 0, 0);
	AckisRecipeListFrameXButton:RegisterForClicks("LeftButtonUp");
	AckisRecipeListFrameXButton:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end);
	AckisRecipeListFrameXButton:Enable();

	-- Add scroll bar
	local AckisRecipeListFrameScrollBar = CreateFrame("ScrollFrame", "AckisRecipeListFrameScrollBar", AckisRecipeListFrame);

	AckisRecipeListFrameScrollBar:ClearAllPoints();
	AckisRecipeListFrameScrollBar:SetPoint("TOPRIGHT", AckisRecipeListFrame, "TOPRIGHT", 0, 0);
	AckisRecipeListFrameScrollBar:SetWidth(16);
	AckisRecipeListFrameScrollBar:SetScript("OnVerticalScroll", AckisRecipeList_ScrollBar);
	AckisRecipeListFrameScrollBar:EnableMouseWheel(true);

	-- Add header frame
	local AckisRecipeListFrameHeaderFrame = CreateFrame("Frame", "AckisRecipeListFrameHeaderFrame", AckisRecipeListFrame);

	AckisRecipeListFrameHeaderFrame:SetWidth(192);
	AckisRecipeListFrameHeaderFrame:SetHeight(32);
	AckisRecipeListFrameHeaderFrame:ClearAllPoints();
	AckisRecipeListFrameHeaderFrame:SetPoint("TOP", AckisRecipeListFrame, "TOP", 0, 6);
	AckisRecipeListFrameHeaderFrame:EnableMouse(true);
	AckisRecipeListFrameHeaderFrame:SetMovable(true);
	AckisRecipeListFrameHeaderFrame:SetScript("OnMouseDown", function()	AckisRecipeListFrame:StartMoving()	end);
	AckisRecipeListFrameHeaderFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end);

	-- Add texture to the header frame
	local AckisRecipeListFrameHeaderFrameTexture = AckisRecipeListFrameHeaderFrame:CreateTexture("AckisRecipeListFrameHeaderFrameTexture", "ARTWORK");

	AckisRecipeListFrameHeaderFrameTexture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header");
	AckisRecipeListFrameHeaderFrameTexture:SetWidth(384);
	AckisRecipeListFrameHeaderFrameTexture:SetHeight(64);
	AckisRecipeListFrameHeaderFrameTexture:ClearAllPoints();
	AckisRecipeListFrameHeaderFrameTexture:SetPoint("TOP", AckisRecipeListFrameHeaderFrame, "TOP", 0, 5);
	AckisRecipeListFrameHeaderFrameTexture:Show();

	-- Add text to header frame
	local AckisRecipeListFrameHeaderFrameText = AckisRecipeListFrameHeaderFrame:CreateFontString("AckisRecipeListFrameHeaderFrameText", "ARTWORK");

	AckisRecipeListFrameHeaderFrameText:SetFontObject(GameFontNormal);
	AckisRecipeListFrameHeaderFrameText:ClearAllPoints();
	AckisRecipeListFrameHeaderFrameText:SetPoint("CENTER", AckisRecipeListFrameHeaderFrame, "CENTER", 0, 0);
	AckisRecipeListFrameHeaderFrameText:SetText("Ackis Recipe List v 0.5");

	-- Missing recipes entries

	local OldFrame = nil;
	local CurrentRecipe = next(MissingRecipeListing, nil);
	local i = 1;

	-- Create x number of entries for all missing recipes
	while ( CurrentRecipe ~= nil ) do

		local RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. i, AckisRecipeListFrame, "ClassTrainerSkillButtonTemplate");

		-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
		if ( OldFrame ~= nil ) then
		
			OldFrame.NextRecipe = RecipeFrame;

		end

		-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable
		if ( i == AckisRecipeList:GetNumMissingRecipes() ) then

			RecipeFrame.NextRecipe = nil;
		
		else

			OldFrame = RecipeFrame;

		end

		RecipeFrame:ClearAllPoints();

		-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
		if ( i == 1 ) then

			RecipeFrame:SetPoint("TOPLEFT", AckisRecipeListFrame, "TOPLEFT", 5, -30);

		else

			RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (i - 1), "BOTTOMLEFT", 0, -1);

		end

		RecipeFrame:SetText(CurrentRecipe);
		AckisRecipeList_SetRecipeListParams(RecipeFrame);
		RecipeFrame:Show();

		i = i + 1;
		CurrentRecipe = next(MissingRecipeListing, CurrentRecipe);

	end

end

--[[

	Scanning functions

]]--

-- Scans your recipe book for Trade Skill Recipes

function AckisRecipeList:ScanTradeSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumTradeSkills() do

		skillName, skillType, _, _ = GetTradeSkillInfo(i);

		-- Ignore all trade skill headers
		if (skillType ~= "header") then

			AckisRecipeList:CheckRecipe(skillName);

		-- If it is a header then expand it so scanning can continue
		else

			ExpandTradeSkillSubClass(i);
		
		end

	end
	
end

-- Scans the recipelisting adding all missing recipes to the MissingRecipeListing

function AckisRecipeList:ScanMissingRecipes()

	-- Parse the recipe listing table, adding entries to the MissingRecipeListing table
	if ( RecipeListing ~= nil ) then

		local RecipeName = next(RecipeListing, nil);

			while (RecipeName ~= nil) do

				-- If the recipe is not known then print out the info
				if ( RecipeListing[ RecipeName ][ "Known" ] == false ) then

					MissingRecipeListing[ RecipeName ] = {};
					MissingRecipeListing[ RecipeName ][ "Level" ] = RecipeListing[ RecipeName ][ "Level" ];
					MissingRecipeListing[ RecipeName ][ "Acquire" ] = RecipeListing[ RecipeName ][ "Acquire" ];
					MissingRecipeListing[ RecipeName ][ "Speciality" ] = RecipeListing[ RecipeName ][ "Speciality" ]

				end

				-- Move on to the next entry in the table
				RecipeName = next(RecipeListing, RecipeName);
	
			end

	end

	-- Done with RecipeList now, so I can empty the table to free up memory now
	ARL_ResetRecipeList();

end

-- Scans your recipe book for Craft Skill Recipes (enchanting is handled differently than other trade skills)

function AckisRecipeList:ScanCraftSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, _, skillType, _, isExpanded, _, _ = GetCraftInfo(i);

		-- Ignore all trade skill headers
		if (skillType ~= "header") then

			AckisRecipeList:CheckRecipe(skillName);

		-- If it is a header then expand it so scanning can continue
		else

			ExpandCraftSkillLine(i);

		end

	end

end

-- Scans your recipe book for beast training skills

function AckisRecipeList:ScanBeastTraining(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, skillRank, _, _, _, _, _ = GetCraftInfo(i); -- Don't need a lot of this information, what to do with it?

		local FullSkillName = skillName .. " (" .. skillRank .. ")";
		
		AckisRecipeList:CheckRecipe(FullSkillName);

	end

end

-- Function to be called when /arl guiscan is run.

function AckisRecipeList:AckisRecipeList_GUISCAN()

	AckisRecipeList:AckisRecipeList_Command( "GUI" );

end

-- Function to be called when /arl scan is run.

function AckisRecipeList:AckisRecipeList_SCAN()

	AckisRecipeList:AckisRecipeList_Command( "NOGUI" );

end

-- Main logic for add-on, will call all sub-functions

function AckisRecipeList:AckisRecipeList_Command(ARLGUICheck)

	local CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex;

	if ( SkillType == nil ) then

		DEFAULT_CHAT_FRAME:AddMessage( "Please open trade skill window to scan." );

	-- Trade type skills
	elseif ( SkillType == "Trade" ) then

		-- Get the name of the current trade skill opened, along with the current level of the skill. 
		CurrentProfession, CurrentProfessionLevel, _ = GetTradeSkillLine();

		ARL_InitializeTradeRecipes(CurrentProfession);

		if ( CurrentProfession == BTS["Poisons"] ) then

			-- Player level = profession level for rogue poisons
			CurrentProfessionLevel = UnitLevel("player");

		end

		AckisRecipeList:ScanTradeSkills(CurrentProfession);

		AckisRecipeList:ScanMissingRecipes();

		if ( AckisRecipeList:GetAllSorting() == "Skill" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingSkill);

		elseif ( AckisRecipeList:GetAllSorting() == "Name" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingName);

		end

		if ( ARLGUICheck == "NOGUI" ) then

			AckisRecipeList:InitiateScan(CurrentProfession, CurrentProfessionLevel);

			AckisRecipeList:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex);

		else

			AckisRecipeList:AckisRecipeList_CreateFrame();

		end

	-- Craft type skills
	elseif ( SkillType == "Craft" ) then

		-- Get the name of the current craft.
		CurrentProfession = GetCraftName();

		-- Get the name of the current craft.
		CurrentProfession = GetCraftName();

		CurrentProfessionLevel = ARL_InitializeCraftRecipes(CurrentProfession);

		if CurrentProfession == BTS["Enchanting"] then

			-- Scan for missing enchanting recipes
			AckisRecipeList:ScanCraftSkills(CurrentProfession);

		elseif CurrentProfession == L["Beast Training"] then

			-- Scan for missing beast training
			AckisRecipeList:ScanBeastTraining(CurrentProfession);

		end

		AckisRecipeList:ScanMissingRecipes();

		if ( AckisRecipeList:GetAllSorting() == "Skill" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingSkill);

		elseif ( AckisRecipeList:GetAllSorting() == "Name" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingName);

		end

		if ( ARLGUICheck == "NOGUI" ) then

			AckisRecipeList:InitiateScan(CurrentProfession, CurrentProfessionLevel);

			AckisRecipeList:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex);

		else

			AckisRecipeList:AckisRecipeList_CreateFrame();

		end	

	end

end
